/*******************************************************************************
MASTER DO FILE - RASKIN COMPETITION PAPER
August 2018

SUMMARY:
	This is the Master do file for the Raskin Competition paper. It starts from
	raw survey data, cleans everything, performs analyses, and produces all tables and figures.
	NOTE: In order to run this without randomization inference (and save a lot of time),
	set the do_RI local to "NO".

*******************************************************************************/

clear all
macro drop _all
cap log close
set more off
set matsize 800
pause off

** SET MAIN FILE PATH
global RASKIN "/Users/solomon6/Dropbox (MIT)/JPAL Indonesia Raskin/6Data/Competition Public Data/FINAL_Competition_Clean/Competition_Clean"

** set globals
global raskdat			 "$RASKIN/1Data/"
global TARGET2 			 "$RASKIN/1Data/originaldata/TargetingIIData"
global RASKIN_TABLES 	 "$RASKIN/2Output/tables"
global RASKIN_FIGURES 	 "$RASKIN/2Output/graphs"
global cards_path 		 "$RASKIN/1Data/dofiles/cards_paper/"
global prep_path 		 "$RASKIN/1Data/dofiles/prep/"
global analysis_path 	 "$RASKIN/1Data/dofiles/analysis/"

** graph font
graph set window fontface "Times New Roman"
graph set eps fontface "Times New Roman"

** install programs
cap ssc install xml_tab

** start log
cap log close
log using "$RASKIN/master_log $S_TIME", replace

** toggle which RI do files to run
local do_RI "NO" // set to "YES" if want to run RI do files and "NO" if you do not want to run RI do files (note: RI takes several days to run)

*******************************************************************************/
** PREP FROM RASKIN CARDS PAPER ************************************************
*******************************************************************************/

*******************************************************************************/
** ROUND 1 ************************************************
*******************************************************************************/

do "$cards_path/Round1/basic coding.do" // basic coding, weights, treatment status
	/*	use: 	"1Data/originaldata/TargetingIIData/Baseline/hh_ksr5.dta"
				"1Data/originaldata/0_Listing/l_location_clean"
				"1Data/originaldata/0_Listing/120828 randomization_raskin_master_all_clean.dta"
				"1Data/originaldata/1_CS1/NewUpdate/crosswalk_cs1_sw.dta"
				"1Data/originaldata/TargetingIIData/Baseline/coded_baseline_partV.dta"
				"1Data/originaldata/TargetingIIData/Baseline/coded_baseline_partV_hybrid.dta"
				"1Data/originaldata/1_CS1/NewUpdate/hh_cov.dta"
				"1Data/originaldata/0_Randomization/120716 randomization results for new TR2.dta"
				"1Data/originaldata/1_CS1/NewUpdate/crosswalk_cs1.dta"
		out:	"1Data/codeddata/cards_paper/crosswalk_SW.dta"
				"1Data/codeddata/cards_paper/TargetingIIRaskin.dta"
				"1Data/codeddata/cards_paper/beneficiaries and randomization.dta" */
				
do "$cards_path/Round1/leakages and targeting.do"
	/*	use: 	"1Data/codeddata/cards_paper/beneficiaries and randomization.dta"
				"1Data/originaldata/1_CS1/NewUpdate/k_cr.dta"
				"1Data/originaldata/1_CS1/NewUpdate/hh_c.dta"
				"1Data/originaldata/1_CS1/NewUpdate/hh_b2.dta"
		out:	"1Data/codeddata/cards_paper/bought_s.dta"
				"1Data/codeddata/cards_paper/marketprices.dta"
				"1Data/codeddata/cards_paper/leakagestargeting.dta" */
				
do "$cards_path/Round1/card receipt.do" // received and/or used card
	/*	use: 	"1Data/codeddata/cards_paper/beneficiaries and randomization.dta"
				"1Data/originaldata/1_CS1/NewUpdate/hh_rc.dta"
				"1Data/originaldata/1_CS1/NewUpdate/hh_b1.dta"
				"1Data/codeddata/cards_paper/bought_s.dta"
		out:	"1Data/codeddata/cards_paper/cardreceipt.dta" */
		
do "$cards_path/Round1/satisfaction.do" // satisfaction with the card
	/*	use: 	"1Data/codeddata/cards_paper/beneficiaries and randomization.dta"
				"1Data/originaldata/1_CS1/NewUpdate/hh_f.dta"
				"1Data/originaldata/1_CS1/NewUpdate/k_rc.dta"
		out:	"1Data/codeddata/cards_paper/satisfaction.dta" */
		
do "$cards_path/Round1/socialization.do" // social communication related to card
	/*	use: 	"1Data/codeddata/cards_paper/beneficiaries and randomization.dta"
				"1Data/originaldata/1_CS1/NewUpdate/k_sr.dta"
				"1Data/originaldata/1_CS1/NewUpdate/hh_sr.dta"
				"1Data/originaldata/1_CS1/NewUpdate/hh_sw4.dta"
				"1Data/codeddata/cards_paper/crosswalk_SW.dta"
		out:	"1Data/codeddata/cards_paper/socialization.dta" */
		
do "$cards_path/Round1/combining.do" // combine output dta files from previous 4 do files
	/*	use: 	"1Data/codeddata/cards_paper/cardreceipt.dta"
				"1Data/codeddata/cards_paper/socialization.dta"
				"1Data/codeddata/cards_paper/leakagestargeting.dta"
				"1Data/codeddata/cards_paper/satisfaction.dta"
		out:	"1Data/codeddata/cards_paper/CombinedVP.dta" */

*******************************************************************************/
** ROUND 2 ************************************************
*******************************************************************************/

do "$cards_path/Round2/basic_mid.do"
	/*	use: 	"1Data/originaldata/TargetingIIData/Baseline/hh_ksr5.dta"
				"1Data/originaldata/0_Listing/l_location_clean"
				"1Data/originaldata/0_Listing/120828 randomization_raskin_master_all_clean.dta"
				"1Data/originaldata/2_Midline/hh_cov.dta"
				"1Data/originaldata/0_Randomization/120716 randomization results for new TR2.dta"
				"1Data/originaldata/2_Midline/crosswalk_midline.dta"
				"1Data/originaldata/TargetingIIData/Endline2/ConsumptionAcrossWaves"
				"1Data/originaldata/2_Midline/crosswalk_midline_all.dta"
				"1Data/codeddata/cards_paper/beneficiaries and randomization.dta"
		out:	"1Data/codeddata/cards_paper/midline/TargetingIIRaskin_mid.dta" (not used)
				"1Data/codeddata/cards_paper/midline/beneficiaries_and_randomization_mid.dta" */
				
do "$cards_path/Round2/leakages_and_targeting_mid.do"
	/*	use: 	"1Data/codeddata/cards_paper/midline/beneficiaries_and_randomization_mid.dta"
				"1Data/originaldata/2_Midline/k_cr.dta"
				"1Data/originaldata/2_Midline/hh_c.dta"
				"1Data/originaldata/2_Midline/hh_b2.dta"
		out:	"1Data/codeddata/cards_paper/midline/bought_s.dta"
				"1Data/codeddata/cards_paper/midline/marketprices_mid.dta"
				"1Data/codeddata/cards_paper/midline/leakagestargeting_mid.dta" */
				
do "$cards_path/Round2/card_receipt_mid.do" // received and/or used card
	/*	use: 	"1Data/codeddata/cards_paper/midline/beneficiaries_and_randomization_mid.dta"
				"1Data/originaldata/2_Midline/hh_rc.dta"
				"1Data/originaldata/2_Midline/hh_b1.dta"
				"1Data/codeddata/cards_paper/midline/bought_s.dta"
		out:	"1Data/codeddata/cards_paper/midline/cardreceipt_mid.dta" */
		
do "$cards_path/Round2/satisfaction_mid.do" // satisfaction with the card
	/*	use: 	"1Data/codeddata/cards_paper/midline/beneficiaries_and_randomization_mid.dta"
				"1Data/originaldata/2_Midline/hh_f.dta"
				"1Data/originaldata/2_Midline/k_rc.dta"
		out:	"1Data/codeddata/cards_paper/midline/satisfaction_mid.dta" */
		
do "$cards_path/Round2/socialization_mid.do" // social communication related to card
	/*	use: 	"1Data/codeddata/cards_paper/midline/beneficiaries_and_randomization_mid.dta"
				"1Data/originaldata/2_Midline/k_sr.dta"
				"1Data/originaldata/2_Midline/hh_sr.dta"
				"1Data/originaldata/2_Midline/hh_sw3.dta"
				"1Data/originaldata/2_Midline/hh_sw4.dta"
		out:	"1Data/codeddata/cards_paper/midline/socialization_mid.dta" */
		
do "$cards_path/Round2/combining_mid.do" // combine output dta files from previous 4 do files
	/*	use: 	"1Data/codeddata/cards_paper/midline/cardreceipt_mid.dta"
				"1Data/codeddata/cards_paper/midline/socialization_mid.dta"
				"1Data/codeddata/cards_paper/midline/leakagestargeting_mid.dta"
				"1Data/codeddata/cards_paper/midline/satisfaction_mid.dta"
		out:	"1Data/codeddata/cards_paper/midline/combined_mid.dta" */

*******************************************************************************/
** PAPER ************************************************
*******************************************************************************/

do "$cards_path/Paper/fam relations baseline.do" // family, beliefs
	/*	use: 	"1Data/originaldata/2_Midline/crosswalk_midline_all.dta"
				"1Data/originaldata/TargetingIIData/Baseline/hh_cr01.dta"
				"1Data/originaldata/2_Midline/hh_sw4.dta"
		out:	"1Data/codeddata/cards_paper/paper/beliefs_family.dta" */
		
do "$cards_path/Paper/coding_extra_v3.do" //  Info on village officials, knowledge about Raskin eligibility status, and sample weights. 
	/*	use: 	"1Data/originaldata/2_Midline/crosswalk_midline_all.dta"
				"1Data/originaldata/TargetingIIData/Baseline/hh_cr00.dta"
				"1Data/originaldata/2_Midline/hh_pm2.dta"
				"1Data/originaldata/2_Midline/crosswalk_midline.dta"
				"1Data/originaldata/2_Midline/hh_sw4.dta"
				"1Data/codeddata/cards_paper/paper/beliefs_family.dta"
				"1Data/codeddata/cards_paper/midline/combined_mid.dta"
				"1Data/originaldata/2_midline/hh_ar1.dta"
				"1Data/codeddata/cards_paper/combinedVP.dta"
				"1Data/originaldata/1_CS1/NewUpdate/hh_pm2.dta"
				"1Data/originaldata/1_CS1/NewUpdate/crosswalk_cs1_sw.dta"
				"1Data/originaldata/1_CS1/NewUpdate/hh_sw4.dta"
				"1Data/originaldata/1_CS1/NewUpdate/hh_ar.dta"
		out:	"1Data/codeddata/cards_paper/paper/combined.dta"
				"1Data/codeddata/cards_paper/paper/combined_pooled.dta"
				"1Data/codeddata/cards_paper/paper/knowledge_pooled.dta" (not used) */
				
do "$cards_path/Paper/rand_check_prep.do" // data for randomization check
	/*	use: 	"1Data/codeddata/cards_paper/paper/combined.dta"
				"1Data/originaldata/0_Randomization/120716 randomization results for new TR2.dta"
				"1Data/originaldata/TargetingIIData/Baseline/hh_cov.dta"
				"1Data/originaldata/TargetingIIData/Baseline/hh_ksr5.dta"
				"1Data/originaldata/TargetingIIData/Baseline/hhhead.dta"
				"1Data/originaldata/TargetingIIData/Baseline/coding_suseti_pmt"
				"1Data/originaldata/TargetingIIData/Baseline/consumption.dta"
				"1Data/originaldata/TargetingIIData/coding_podes08.dta"
				"1Data/originaldata/TargetingIIData/Baseline/rthead"
				"1Data/originaldata/TargetingIIData/Baseline/distance"
				"1Data/originaldata/TargetingIIData/Baseline/pctagriculture"
		out:	"1Data/codeddata/cards_paper/paper/hhdata_for_randcheck" (not used)
				"1Data/codeddata/cards_paper/paper/village_data_for_randcheck" (not used)
				"1Data/codeddata/cards_paper/paper/T2_controls.dta" */
				
*******************************************************************************/				
** ROUND 3 ************************************************
*******************************************************************************/

do "$cards_path/Round3/basic_end.do"
	/*	use: 	"1Data/originaldata/TargetingIIData/Baseline/hh_ksr5.dta"
				"1Data/originaldata/0_Listing/l_location_clean"
				"1Data/originaldata/0_Listing/120828 randomization_raskin_master_all_clean"
				"1Data/originaldata/1_CS1/crosswalk_cs1.dta"
				"1Data/originaldata/3_Endline/hh_cov.dta"
				"1Data/originaldata/2_Midline/crosswalk_midline.dta"
				"1Data/originaldata/3_Endline/hh_cov.dta"
				"1Data/originaldata/0_Randomization/120716 randomization results for new TR2"
				"1Data/originaldata/2_Midline/crosswalk_midline.dta"
		out:	"1Data/originaldata/3_Endline/crosswalk_endline.dta" (not used)
				"1Data/codeddata/cards_paper/endline/beneficiaries_and_randomization_end" */

do "$cards_path/Round3/weights_end.do" // create weights
	/*	use: 	"1Data/codeddata/cards_paper/endline/beneficiaries_and_randomization_end"
				"1Data/originaldata/1_CS1/hh_ar.dta"
				"1Data/codeddata/cards_paper/midline/combined_mid.dta"
				"1Data/originaldata/2_midline/hh_ar1.dta"
		out:	"1Data/codeddata/cards_paper/endline/weights_end.dta" */
		
do "$cards_path/Round3/leakages_and_targeting_end.do"
	/*	use: 	"1Data/codeddata/cards_paper/endline/beneficiaries_and_randomization_end.dta"
				"1Data/originaldata/3_Endline/k_cr.dta"
				"1Data/originaldata/3_Endline/hh_c.dta"
				"1Data/originaldata/3_Endline/hh_b2.dta"
		out:	"1Data/codeddata/cards_paper/endline/bought_s.dta"
				"1Data/codeddata/cards_paper/endline/marketprices_end.dta"
				"1Data/codeddata/cards_paper/endline/leakagestargeting_end.dta" */
				
do "$cards_path/Round3/card_receipt_end.do" // received and/or used card
	/*	use: 	"1Data/codeddata/cards_paper/endline/beneficiaries_and_randomization_end.dta"
				"1Data/originaldata/3_Endline/hh_rc.dta"
				"1Data/originaldata/3_Endline/hh_b1.dta"
				"1Data/codeddata/cards_paper/endline/bought_s.dta"
		out:	"1Data/codeddata/cards_paper/endline/cardreceipt_end.dta" */
		
do "$cards_path/Round3/satisfaction_end.do" // satisfaction with the card
	/*	use: 	"1Data/codeddata/cards_paper/endline/beneficiaries_and_randomization_end.dta"
				"1Data/originaldata/3_Endline/hh_f.dta"
				"1Data/originaldata/3_Endline/k_rc.dta"
		out:	"1Data/codeddata/cards_paper/endline/satisfaction_end.dta" */
		
do "$cards_path/Round3/socialization_end.do" // social communication related to card
	/*	use: 	"1Data/codeddata/cards_paper/endline/beneficiaries_and_randomization_end.dta"
				"1Data/originaldata/3_Endline/k_sr.dta"
				"1Data/originaldata/3_Endline/hh_sr.dta"
				"1Data/originaldata/3_Endline/hh_sw3.dta"
				"1Data/originaldata/3_Endline/hh_sw4.dta"
		out:	"1Data/codeddata/cards_paper/endline/socialization_end.dta" */
		
do "$cards_path/Round3/combining_end.do" // combine output dta files from previous 4 do files
	/*	use: 	"1Data/codeddata/cards_paper/endline/cardreceipt_end.dta"
				"1Data/codeddata/cards_paper/endline/socialization_end.dta"
				"1Data/codeddata/cards_paper/endline/leakagestargeting_end.dta"
				"1Data/codeddata/cards_paper/endline/satisfaction_end.dta"
				"1Data/codeddata/cards_paper/endline/weights_end.dta"
		out:	"1Data/codeddata/cards_paper/endline/combined_end.dta" */

*******************************************************************************/
** LAST MONTH PRICE ************************************************
*******************************************************************************/

do "$cards_path/Round1/lastmonthprice.do" // price paid in last month (not average)
  /* use: "1Data/codeddata/cards_paper/beneficiaries and randomization.dta"
          "1Data/originaldata/1_CS1/NewUpdate/k_cr.dta"
		  "1Data/originaldata/1_CS1/NewUpdate/hh_c.dta"
		  "1Data/originaldata/1_CS1/NewUpdate/hh_b2.dta"	
	 out: "1Data/codeddata/competition/price_lastmonth_baseline.dta" */

do "$cards_path/Round2/lastmonthprice_mid.do" // price paid in last month (not average)
  /* use : "1Data/codeddata/cards_paper/midline/beneficiaries_and_randomization_mid.dta"
	       "1Data/originaldata/2_Midline/k_cr.dta"
		   "1Data/originaldata/2_Midline/hh_c.dta"
		   "1Data/originaldata/2_Midline/hh_b2.dta"	   
	out:   "1Data/codeddata/competition/price_lastmonth_midline.dta" */
	 
do "$cards_path/Round3/lastmonthprice_end.do" // price paid in last month (not average)
  /* use: "1Data/codeddata/cards_paper/endline/beneficiaries_and_randomization_end.dta"
          "1Data/originaldata/3_Endline/k_cr.dta"
          "1Data/originaldata/3_Endline/hh_c.dta"
          "1Data/originaldata/3_Endline/hh_b2.dta"	
     out: "1Data/codeddata/competition/price_lastmonth.dta" */
             		
*******************************************************************************/	
** PREP ************************************************************************
/* Much of the competition analysis relies on data we already used in the
		cards paper */
*******************************************************************************/

do "$prep_path/rand_check_prep.do" // prep variables for randomization check
	/*	use: 	"1Data/codeddata/cards_paper/paper/T2_controls.dta"
				"1Data/originaldata/1_CS1/NewUpdate/k_id.dta"
				"1Data/originaldata/2_Midline/k_id.dta"
				"1Data/originaldata/1_CS1/NewUpdate/k_kd.dta"
				"1Data/originaldata/2_Midline/k_kd.dta"
				"1Data/originaldata/2_Midline/k_rd1.dta"
		out: 	"1Data/codeddata/competition/rand_check_village.dta" */
		
do "$prep_path/cards_combine_all.do" // combined cards data
	/*	use:	"1Data/codeddata/cards_paper/paper/combined_pooled.dta"
				"1Data/codeddata/cards_paper/endline/combined_end.dta"
		out:	"1Data/codeddata/competition/cards_combined_all.dta" */
		
do "$prep_path/allwave_vars.do" // prep variables tha appear in all waves of survey (not prepared as part of cards analysis)
	/*	use:	"1Data/originaldata/1_CS1/NewUpdate/hh_b1"
				"1Data/originaldata/2_Midline/hh_b1"
				"1Data/originaldata/3_Endline/hh_b1"
				"1Data/originaldata/1_CS1/NewUpdate/hh_sr"
				"1Data/originaldata/2_Midline/hh_sr"
				"1Data/originaldata/3_Endline/hh_sr"
				"1Data/originaldata/1_CS1/NewUpdate/hh_f"
				"1Data/originaldata/2_Midline/hh_f"
				"1Data/originaldata/3_Endline/hh_f"
		out:	"1Data/codeddata/competition/allwave_vars.dta" */
		
do "$prep_path/cs1midline_vars.do" // prepare variables which are only in CS1 and midline
	/*	use:	"1Data/originaldata/1_CS1/NewUpdate/hh_ar"
				"1Data/originaldata/2_Midline/hh_ar1"
		out:	"1Data/codeddata/competition/cs1midline_vars.dta" */
		
do "$prep_path/endline_vars.do" // prepare variables which are only in the endline
	/*	use:	"1Data/originaldata/3_Endline/hh_b1"
				"1Data/originaldata/3_Endline/hh_sr"
				"1Data/originaldata/3_Endline/hh_f"
				"1Data/originaldata/3_Endline/hh_kp"
		out:	"1Data/codeddata/competition/endline_vars.dta" */
		
do "$prep_path/village_prices.do" // price data at the village level from all surveys
	/*	use:	"1Data/codeddata/cards_paper/paper/combined_pooled"
				"1Data/codeddata/competition/cards_combined_all"
		out:	"1Data/codeddata/competition/village_prices.dta" */
		
do "$prep_path/good_strata.do" // copy of randomization file, except only keeps strata variables and village IDs and saves file elsewhere
	/*	use:	"1Data/originaldata/0_Randomization/120716 randomization results for new TR2.dta"
				"1Data/originaldata/0_Partner_Intervention/120914 List of villages to drop.csv"
		out:	"1Data/codeddata/competition/good_strata.dta" */
		
do "$prep_path/treatments_prep.do" // prepare treatment variables for treatment
	/*	use:	"1Data/originaldata/0_Randomization/130405 final randomization"
		out:	"1Data/codeddata/competition/treatments.dta" */
		
do "$prep_path/consumption_cs1mid.do" // household consumption data at consumption baseline
	/*	use:	"1Data/originaldata/1_CS1/NewUpdate/hh_ks1.dta"
				"1Data/originaldata/1_CS1/NewUpdate/hh_ks1.dta"
				"1Data/originaldata/2_Midline/hh_ks2.dta"
				"1Data/originaldata/2_Midline/hh_ks2.dta"
		out:	"1Data/codeddata/competition/consumption_cs1mid.dta" */
		
do "$prep_path/old_dist_prep.do" // prepare variables from old distributor interview
	/*	use:	"1Data/originaldata/4_CE/f4_b1.dta"
				"1Data/codeddata/competition/treatments.dta"
		out:	"1Data/codeddata/competition/old_dist_vars.dta" */
		
do "$prep_path/rejection_prep.do" // code variables for villages that reject treatment at some point
	/*	use:	"1Data/codeddata/competition/treatments.dta"
				"1Data/originaldata/4_CE/f8a_f"
				"1Data/originaldata/4_CE/14.09.02 chk_sq_info.xlsx"
				"1Data/originaldata/3_Endline/k_rd1"
		out:	"1Data/codeddata/competition/biddingrejection.dta" */
		
do "$prep_path/bidding_meeting_prep.do"	// descriptive stats on bidding meetings for bidding villages
	/*	use:	"1Data/codeddata/competition/biddingrejection.dta"
				"1Data/originaldata/4_CE/f6a_b.dta"
				"1Data/originaldata/4_CE/f8a_a1.dta"
				"1Data/originaldata/4_CE/f8a_b.dta"
				"1Data/originaldata/4_CE/f8a_d.dta"
				"1Data/originaldata/4_CE/f8a_e.dta"
				"1Data/originaldata/4_CE/f8a_v1.dta"
				"1Data/codeddata/competition/treatments.dta"
		out:	"1Data/codeddata/competition/bidding_meeting.dta" */
		
do "$prep_path/bidding_prep.do"	// prepare bidding meeting data for analysis
	/*	use:	"1Data/originaldata/4_CE/f7a_b2.dta"
				"1Data/originaldata/4_CE/f7a_c.dta"
				"1Data/originaldata/4_CE/f8a_d.dta"
				"1Data/originaldata/4_CE/f8a_f.dta"
				"1Data/originaldata/4_CE/penyalur_sekarang.dta"
				"1Data/codeddata/competition/good_strata.dta"
				"1Data/originaldata/4_CE/14.09.02 chk_sq_info.xlsx"
		out:	"1Data/codeddata/competition/bidders.dta" */
		
do "$prep_path/winners_notdistributing.do" // look at winning bidders who end up not distributing
	/*	use:	"1Data/originaldata/4_CE/14.09.02 chk_sq_info.xlsx"
				"1Data/originaldata/4_CE/f8a_f.dta"
				"1Data/originaldata/4_CE/f7a_c.dta"
				"1Data/originaldata/4_CE/crosswalk_f8a_distributor_resp.dta"
				"1Data/originaldata/3_Endline/pr_pp1.dta"
				"1Data/originaldata/4_CE/penyalur_sekarang.dta"
				"1Data/codeddata/competition/treatments.dta"
				"1Data/originaldata/3_Endline/k_rd1.dta"
		out:	"1Data/codeddata/competition/winners_notdistributing.dta" */
		
do "$prep_path/info_meeting_prep.do" // descriptive stats on bidding meetings for information villages
	/*	use:	"1Data/originaldata/4_CE/f5b_a1"
				"1Data/originaldata/4_CE/f5b_b"
				"1Data/originaldata/4_CE/f5b_f"
				"1Data/codeddata/competition/treatments.dta"
		out:	"1Data/codeddata/competition/info_meeting.dta" */
		
do "$prep_path/current_distributor_costs.do" // data on costs of current distribution
	/*	use:	"1Data/originaldata/3_Endline/pr_pp1.dta"
				"1Data/originaldata/3_Endline/pr_pp3.dta"
				"1Data/originaldata/4_CE/penyalur_sekarang.dta"
				"1Data/codeddata/competition/treatments.dta"
		out:	"1Data/codeddata/competition/current_distributor_costs.dta" */
		
do "$prep_path/distributors_prep.do" // prepare distributor survey for analysis
	/*	use:	"1Data/originaldata/3_Endline/pr_id"
				"1Data/originaldata/3_Endline/pr_km"
				"1Data/originaldata/3_Endline/pr_pg"
				"1Data/originaldata/3_Endline/pr_pm2"
				"1Data/originaldata/3_Endline/pr_tm3"
				"1Data/originaldata/3_Endline/pr_dg1"
				"1Data/originaldata/3_Endline/pr_dg2"
				"1Data/originaldata/3_Endline/pr_dg3"
				"1Data/originaldata/3_Endline/pr_pp1"
				"1Data/originaldata/4_CE/penyalur_sekarang.dta"
				"1Data/codeddata/competition/village_prices"
				"1Data/codeddata/competition/good_strata"
		out:	"1Data/codeddata/competition/distributors.dta" */
		
do "$prep_path/bidders_form_survey_crosswalk.do" // combine form and survey data for bidders
	/*	use:	"1Data/codeddata/competition/bidders"
				"1Data/originaldata/4_CE/crosswalk_f8a_distributor_resp"
				"1Data/codeddata/competition/distributors"
				"1Data/codeddata/competition/biddingrejection"
		out:	"1Data/codeddata/competition/bid_dist_all.dta" */
		
do "$prep_path/baseline_village_controls.do" // merge baseline village controls
	/*	use:	"1Data/originaldata/0_Listing/l_location_clean.dta"
				"1Data/codeddata/competition/rand_check_village.dta"
		out:	"1Data/codeddata/competition/baseline_village_controls.dta" */
		
do "$prep_path/competition_prep.do" // combine all variables and create the final dataset which will be used in regressions
	/*	use:	"1Data/codeddata/cards_paper/marketprices.dta"
				"1Data/codeddata/cards_paper/midline/marketprices_mid.dta"
				"1Data/codeddata/cards_paper/endline/marketprices_end.dta"
				"1Data/codeddata/competition/cards_combined_all.dta"
				"1Data/codeddata/competition/allwave_vars.dta"
				"1Data/codeddata/competition/endline_vars.dta"
				"1Data/codeddata/competition/cs1midline_vars.dta"
				"1Data/codeddata/competition/consumption_cs1mid.dta"
				"1Data/codeddata/competition/village_prices.dta"
				"1Data/codeddata/competition/good_strata.dta"
				"1Data/codeddata/competition/treatments.dta"
		out:	"1Data/codeddata/competition/endmidcs1.dta" */
		
do "$prep_path/pricelastmonth_combined.do" // combine last month prices
       /*use:  "1Data/codeddata/competition/price_lastmonth.dta"
	           "1Data/codeddata/competition/price_lastmonth_baseline.dta"
			   "1Data/codeddata/competition/price_lastmonth_midline.dta
	    *out:  "1Data/codeddata/competition/price_lastmonth_combined.dta" */
		
do "$prep_path/old_dist_prep_win.do" // for winsorizing Table 6
	/*	use:	"1Data/originaldata/4_CE/f4_b1.dta"
				"1Data/codeddata/competition/treatments.dta"
		out:	"1Data/codeddata/competition/old_dist_vars_win.dta" */

if "`do_RI'" == "YES" do "$prep_path/randomization_inference.do". // run randomization inference (1000 iterations)
	/*	use:	"1Data/originaldata/0_Randomization/120716 randomization results for new TR2.dta"
				"1Data/originaldata/0_Partner_Intervention/120914 List of villages to drop.csv"
		out:	"1Data/codeddata/competition/rerandomization.dta" */

if "`do_RI'" == "YES" do "$prep_path/randomization_inference_5000.do" // run randomization inference (5000 iterations)
	/*use :"1Data/originaldata/0_Randomization/120716 randomization results for new TR2.dta"	
		   "1Data/originaldata/0_Partner_Intervention/120914 List of villages to drop.csv"
	  out: "1Data/codeddata/competition/rerandomization_part1.dta"
		   "1Data/codeddata/competition/rerandomization_part2.dta"
		   "1Data/codeddata/competition/rerandomization_5000.dta" */

*******************************************************************************/
** ANALYSIS ********************************************************************
*******************************************************************************/

*******************************************************************************/
** TABLES
*******************************************************************************/

	// Table 1: 			The Bidding Process
do "$analysis_path/table1.summ_meetings.do"

	// Table 2: 			Who Distributes Raskin Six Months After Intervention? 
if "`do_RI'" == "YES" do "$analysis_path/table2.who_distributes_ri_5k.do"
if "`do_RI'" == "NO"  do "$analysis_path/table2.who_distributes_NOri_5k.do"

	// Table 3: 			Raskin Distribution Process (also appendix tables 7, 8A, 8B)
if "`do_RI'" == "YES" do "$analysis_path/table3appendixtable78ab.effect_on_process_ri_5k.do"
if "`do_RI'" == "NO"  do "$analysis_path/table3appendixtable78ab.effect_on_process_NOri_5k.do"
	
	// Table 4: 			Endline Costs to Current Distributor	
if "`do_RI'" == "YES" do "$analysis_path/table4.distributor_cost_ri_5k.do" 
if "`do_RI'" == "NO"  do "$analysis_path/table4.distributor_cost_NOri_5k.do" 
		
	// Table 5: 			Where Did Old Distributor Win and Continue Distributing?
do "$analysis_path/table5.12.where_old_different.do"
do "$analysis_path/table5.34.where_old_different_cond_wins.do"
do "$analysis_path/table5.56.where_old_different_cond_corrupt.do"

   // Table 6: 			    Baseline Markup and Number of Bids
do "$analysis_path/table6.markup_bids.do"
		
   // Table 7: 			    Quantile Treatment Effects on Price Markup
do "$analysis_path/table7.quantiletreatmenteffects.do"
	
*******************************************************************************/
** APPENDIX TABLES
*******************************************************************************/

	// Appendix Table 1: 	Baseline Summary Statistics
do "$analysis_path/appendixtable1.summ_baseline.do"
	
	// Appendix Table 2: 	Characteristics of Sampled Localities
do "$analysis_path/appendixtable2.sample_vs_indo_comparison_podesscrambled.do"
	
	// Appendix Table 3: 	Number of Villages Randomly Assigned to Each Treatment
do "$analysis_path/appendixtable3.descriptive.do"
	
	// Appendix Table 4A: 	Who Distributes Raskin Six Months After Intervention, by Women Quota Subtreatment
do "$analysis_path/appendixtable4a.enhanced_women_who_distributes.do"

	// Appendix Table 4B: 	Raskin Distribution Process, by Women Quota Subtreatment
do "$analysis_path/appendixtable4b.enhanced_women_effect_on_process.do"

	// Appendix Table 5: 	Bidding vs. Info Meetings (Conditional on Meeting Overview)
do "$analysis_path/appendixtable5.summ_meetings_info.do"

	// Appendix Table 6A and 6B: 	Randomization Checks
if "`do_RI'" == "YES" do "$analysis_path/appendixtable6ab.rand_check_comp.do"
if "`do_RI'" == "NO"  do "$analysis_path/appendixtable6ab.rand_check_comp_NOri.do"

	// Appendix Tables 7: Raskin Distribution Process, Excluding Baseline Controls
* created above
	
	// Appendix Tables 8A and 8B: Raskin Distribution Process, Eligible Households Only and Ineligible Households Onluy
* created above
	
	// Appendix Table 9: 	Effects on Household Subsidy Receipt
if "`do_RI'" == "YES" do "$analysis_path/appendixtable9.effect_on_sub_ri_5k.do"
if "`do_RI'" == "NO"  do "$analysis_path/appendixtable9.effect_on_sub_NOri_5k.do"
	
	// Appendix Table 10: 	Bid Markups
do "$analysis_path/appendixtable10.bid_markups.do"

	// Appendix Table 11: 	Locality Price Markup vs. Corruption
do "$analysis_path/appendixtable11.corruption_markup.do"

	// Appendix Table 12: 	When Did Original Distributor Win and Continue Distributing?
do "$analysis_path/appendixtable12.where_old_different_cond_ctl_nodice_rd16dist_win.do"	
	
	// Appendix Table 13: 	Comparison of Winning and Losing Bids in Bidding Treatment Localities 
do "$analysis_path/appendixtable13.summ_bids_winner_loser.do"

	// Appendix Table 14 and 14a: 	Who was Selected in Bidding Localities?
do "$analysis_path/appendixtable14.a.who_selected.do"
	
	// Appendix Table 15 and 15a: 	Who was Selected in Bidding Localities, by Extended Bidding?
do "$analysis_path/appendixtable15.a.minbids_who_selected.do"

*******************************************************************************/
** FIGURES
*******************************************************************************/

version 13.1

	// Figure 1: Flow of Villages
do "$analysis_path/figure1.summ_rejection.do"

   // Figure 2:  CDF
do "$analysis_path/figure2.price_graph.do"

*******************************************************************************/
** APPENDIX FIGURES
*******************************************************************************/

	// Appendix Figure 1: 	Distribution of Baseline Raskin Markup
do "$analysis_path/appendixfigure1.fig_price_dispersion.do"
	
	// Appendix Figure 2: 	Project Timeline
* 	Project timeline made in excel
	
	// Appendix Figure 3: 	Why were you selected (or not) as winning distributor?
do "$analysis_path/appendixfigure3.fig_why_selected.do"
	
	// Appendix Figure 4: 	Winning price markup, by baseline price markup
do "$analysis_path/appendixfigure4.fig_winning_price.do"

*******************************************************************************/
** DONE WITH MASTER DO FILE!!!
*******************************************************************************/

disp "DONE WITH ENTIRE REPLICATION!!!"

cap log close
