/*******************************************************************************
Why Were You Selected (Or Not) As Winning Distributor?
1Data/dofiles/analysis/fig_why_selected.do

Bar graph with PP07 from distributor survey for the winners of the bidding process, 
	and PP10 for losers.
*******************************************************************************/

** SETUP AND MACROS *******************************************************

clear all
set more off

cd "$RASKIN"

****************************
* 1. Input data 
****************************
forv j=1/2 {

	u "1Data/codeddata/competition/bid_dist_all.dta", clear

	local var 		: word `j' of pp07 pp10
	local not 		: word `j' of "" "not"
	local condition : word `j' of "if winner_form==1" "if winner_form!=1"
	local title		: word `j' of "Panel A: Why were you selected as winner?" ///
					"Panel B: Why were you not selected as winner?"
	local n			: word `j' of 14 16
	forv i=1/9 {
		local letter : word `i' of "A" "B" "C" "D" "E" "F" "G" "H" "I"
		gen why`not'selected_`letter' = regexm(`var', "`letter'")
		la var why`not'selected_`letter' "`label'" 
	}
	
	** Recode "Other" Reasons (PP07)
	if "`j'"=="1" {
		replace whyselected_E = 1 if pr_id1 == "14321" & pr_id2 == "0"
		replace whyselected_E = 1 if pr_id1 == "35621" & pr_id2 == "0"
		replace whyselected_G = 1 if pr_id1 == "92321" & pr_id2 == "0"
		gen whyselected_J = inlist(pr_id1, "46021", "66021", "87321", "87521", "92521") & pr_id2 == "0"
		gen whyselected_K = pr_id1 == "79721" & pr_id2 == "0"
		gen whyselected_L = inlist(pr_id1, "46321", "48721", "80121", "93321") & pr_id2 == "0"
		gen whyselected_M = pr_id1 == "38221" & pr_id2 == "0"
		gen whyselected_N = pr_id1 == "84621" & pr_id2 == "0"
		}
	
	** Recode "Other" Reasons (PP10)
	else if "`j'"=="2" { 
		replace whynotselected_E = 1 if pr_id1 == "35631" & pr_id2 == "0"
		replace whynotselected_F = 1 if pr_id1 == "26731" & pr_id2 == "0"
		gen whynotselected_J = inlist(pr_id1, "51211", "51231", "87511") & pr_id2 == "0"
		gen whynotselected_K = inlist(pr_id1, "29331", "36811", "71631") & pr_id2 == "0"
		gen whynotselected_L = inlist(pr_id1, "41311", "67611") & pr_id2 == "0"
		gen whynotselected_M = inlist(pr_id1, "54331", "98231") & pr_id2 == "0"
		gen whynotselected_N = inlist(pr_id1, "41711") & pr_id2 == "0"
		gen whynotselected_O = inlist(pr_id1, "72631") & pr_id2 == "0"
		gen whynotselected_P = inlist(pr_id1, "96511") & pr_id2 == "0"
	}
	
	keep `condition' & tr_dist==1
	keep commid pr_id1 pr_id2 why`not'selected_*
	reshape long why`not'selected_, i(commid pr_id1 pr_id2) j(letter) string
	
	gen order = .
	
	//Only want to keep 10 most cited reasons
	bys letter : egen count = total(why`not'selected)
	gsort -count +letter, gen(ordered_count)
	gen drop = ordered_count > 10

	if "`j'"=="1" {
		forv i=1/`n' {
			local letter : word `i' of A B C D E F G H I J K L M N O P
			local label : word `i' of "Adequate capital" ///
					"Best purchase price" ///
					"Adequate transportation" ///
					"Storage space" ///
					"Supporting experience" ///
					"Support from leaders" /// 
					"Committed" ///
					"Good reputation" ///
					"Involves leaders" ///
					"Community support" ///
					"Distribution process" ///
					"Only candidate"  ///
					"Offer more Raskin" ///
					"Lower cost to RT" 
			replace letter = "`label'" if letter=="`letter'"
			replace order = `i' if letter=="`label'"
			qui summ why`not'selected_ if letter=="`label'"
			if `r(mean)'==0 {
				drop if letter=="`label'"
			}
		}
	}
	
	if "`j'"=="2" {
		forv i=1/`n' {
			local letter : word `i' of A B C D E F G H I J K L M N O P
			local label : word `i' of "Inadequate capital" ///
				"High purchase price" ///
				"Inadequate transportation" ///
				"Lack storage space" ///
				"Inexperience" ///
				"Lack support from leaders" /// 
				"Lack commitment" ///
				"Lack good reputation" ///
				"Do not involve leaders" ///
				"Lack community support" ///
				"Distribution process" ///
				"Not at bidding meeting" ///
				"Lack connections" ///
				"Age" ///
				"No education support" ///
				"People want new distributor" 
			replace letter = "`label'" if letter=="`letter'"
			replace order = `i' if letter=="`label'"
			qui summ why`not'selected_ if letter=="`label'"
			if `r(mean)'==0 {
				drop if letter=="`label'"
			}
		}
	}
	
	drop if drop==1

****************************
* 2. Output Figure
****************************
	graph bar (sum) why`not'selected_, over(letter, 	///
		sort(why`not'selected_) descending 				///
		label(angle(forty_five) labsize(small))) 		///
		ytitle(Frequency) subtitle(`title', size(medsmall)) ///
		graphregion(margin(vsmall))
	graph save "$RASKIN_FIGURES/why`not'selected.gph", replace
}

graph combine 	"$RASKIN_FIGURES/whyselected.gph" 		///
				"$RASKIN_FIGURES/whynotselected.gph" 	///
				, colfirst rows(2)  /*ysize(6) xsize(4.5) */
				
** Export panel
graph export "$RASKIN_FIGURES/appendixfigure3_whyselected_2panel.eps", replace

** Erase graphs no longer needed
erase "$RASKIN_FIGURES/whyselected.gph" 
erase "$RASKIN_FIGURES/whynotselected.gph" 


