/*******************************************************************************
Baseline Summary Statistics
1Data/dofiles/analysis/summ_baseline.do

Descriptive info on baseline distributor characteristics and Raskin purchase
*******************************************************************************/

** SETUP AND MACROS *******************************************************
clear all
set more off

cd "$RASKIN"

** DATA PREP *******************************************************************
forv i = 1/2 { //Panel B or Panel C
	u "1Data/codeddata/competition/endmidcs1", clear
	local condition : word `i' of "" "keep if eligible==1"
	local suffix 	: word `i' of all elig
	local suffix_lbl: word `i' of "" ", Eligible Only"
	
	`condition'
	
	keep markup_hh_f bought_last2m_f amtraskin_f subsidy_rcvd_kab_f hhid hhea
	forv j = 1/4 {
		local var : word `j' of markup bought amtraskin subsidy
		local lbl : word `j' of "Raskin Price Markup`suffix_lbl'" ///
						"Proportion that Purchased Raskin`suffix_lbl'" ///
						"Quantity Purchased`suffix_lbl'" ///
						"Subsidy`suffix_lbl'"
		rename `var'_ `var'_f_`suffix'
		la var `var'_f_`suffix' "`lbl'"
	}
	tempfile `suffix' 
	sa ``suffix''
}

** Merge
u `elig', clear
merge 1:1 hhid using `all'

drop _m
order *all *elig
gen commid = hhea

merge m:1 hhea using "1Data/codeddata/competition/treatments"
assert _m==3
drop _m

tempfile summ_bl
sa `summ_bl'

u "1Data/originaldata/2_Midline/k_rd1.dta", clear
gen village_official = regexm(rd05,"A|B|C|F")
la var village_official "Raskin Distributor is Village/District Official"
keep commid village_official

merge 1:m commid using `summ_bl'
assert _m==3
drop _m

bys commid : gen n = _n
replace village_official = . if n!=1
drop n

** REGRESSIONS AND TABLES ******************************************************

** Setup/Locals
est clear
local outfile "$RASKIN_TABLES/appendixtable1.summ_baseline"
local outcomes markup_f_all bought_f_all amtraskin_f_all markup_f_elig bought_f_elig amtraskin_f_elig 
local n : word count `outcomes'
format `outcomes' %10.2fc
	
** Run!
eststo all : estpost summ village_official `outcomes' 

foreach treat in tr_ctl tr_moni tr_dist tr_nomin tr_minbids {
	eststo `treat' : estpost summ village_official `outcomes' if `treat' == 1
}

** Create Table				
tempfile table
# delimit ;
esttab all 
	using `table',
	title("Descriptive statistics on baseline variables")
	cells(`"count(label("N") fmt(%10.0fc))
			mean(label("Mean") fmt(%10.2fc))
			sd(label("Std. Dev.") fmt(%10.2fc))"'
		)
	noobs nonum label replace csv
	;
# delimit cr

** Export
insheet using `table', comma clear

export excel "`outfile'", ///
  sheet("village_variables") sheetrep



  
