/*******************************************************************************
Bid Markups
1Data/dofiles/analysis/bid_markups.do

Impact of Min # Bids subtreatment on various bid markup characteristics.
*******************************************************************************/

** SETUP AND MACROS ************************************************************
clear all
set more off

cd "$RASKIN"

** PREP DATA *******************************************************************

** Baseline price data
use "1Data/codeddata/competition/endmidcs1", clear
keep hhea tr_dist markup_hhea_f*
keep if tr_dist==1
duplicates drop

// create and save temp file
tempfile baseprice
save	`baseprice', replace

** Endline price data
use "1Data/codeddata/competition/endmidcs1", clear
collapse (mean) markup_hh, by(hhea)
rename markup_hh markup_end

// create and save temp file
tempfile endprice
save	`endprice', replace

** End/bid price difference
/* Conditional on bidding winner being endline distributor */
use "1Data/codeddata/competition/bidders", clear
keep if winner==1 & current_dist==1
keep hhea markup_dist
isid hhea
merge 1:1 hhea using `endprice'
keep if _m==3
gen markup_dif = markup_end - markup_dist
keep hhea markup_dif

// create and save temp file
tempfile difprice
save	`difprice', replace

** Winning price 	
use "1Data/codeddata/competition/bidders", clear
keep if winner==1
keep hhea markup_dist
rename markup_dist markup_win

// create and save temp file
tempfile winprice
save	`winprice'

** Incumbent Bid
/* Conditional on incumbent bidding (obviously) */
u "1Data/codeddata/competition/bidders", clear
keep if old_dist==1
gen incumbent_bid = markup_dist
keep hhea incumbent_bid column
duplicates drop

// create and save temp file
tempfile incumbentprice
save	`incumbentprice'

** Merge all temp files together
u "1Data/codeddata/competition/bidders", clear

merge m:1 hhea using `baseprice'
assert _m!=1
drop _m

merge m:1 hhea using `endprice'
assert _m!=1
drop _m	

merge m:1 hhea using `difprice'
assert _m!=2
drop _m	

merge m:1 hhea using `winprice'
assert _m!=2
drop _m	

** Create  Locality-Level Outcome Variables
collapse (mean) markup_dist markup_dif ///
		tr_minbids markup_hhea_f2 markup_hhea_f_mis multiplebidders ///
		(min) markup_min = markup_dist, by(hhea)
merge 1:m hhea using `incumbentprice' //some villages have >1 incumbent
drop _m
bys hhea : gen n = _n
tab n
foreach x in markup_dist markup_dif markup_min {
	replace `x' = . if n>1 //1 obs per village for all characteristics EXCEPT incumbent bid
}

** Label
la var tr_minbids "Min # Bids"
la var markup_hhea_f2 "Baseline Markup"
		
** RUN AND EXPORT REGRESSIONS   ************************************************

** Incumbent's Bid
* control for baseline price	
reg incumbent_bid tr_minbids markup_hhea_f2 markup_hhea_f_mis, cl(hhea)
outreg2 using "$RASKIN_TABLES/appendixtable10.bid_markups", ///
	label keep(tr_minbids markup_hhea_f2) excel dec(3) replace

* multiple bidders only, control for baseline price
reg incumbent_bid tr_minbids markup_hhea_f2 markup_hhea_f_mis if multiplebidders==1, cl(hhea)
outreg2 using "$RASKIN_TABLES/appendixtable10.bid_markups", ///
	label keep(tr_minbids markup_hhea_f2) excel dec(3) append
	
** Average Bid	
* control for baseline price	
reg markup_dist tr_minbids markup_hhea_f2 markup_hhea_f_mis, robust
outreg2 using "$RASKIN_TABLES/appendixtable10.bid_markups", ///
	label keep(tr_minbids markup_hhea_f2) excel dec(3) append

* multiple bidders only, control for baseline price
reg markup_dist tr_minbids markup_hhea_f2 markup_hhea_f_mis if multiplebidders==1, robust
outreg2 using "$RASKIN_TABLES/appendixtable10.bid_markups", ///
	label keep(tr_minbids markup_hhea_f2) excel dec(3) append

** Minimum Bid	
* control for baseline price	
reg markup_min tr_minbids markup_hhea_f2 markup_hhea_f_mis, robust
outreg2 using "$RASKIN_TABLES/appendixtable10.bid_markups", ///
	label keep(tr_minbids markup_hhea_f2) excel dec(3) append

* multiple bidders only, control for baseline price
reg markup_min tr_minbids markup_hhea_f2 markup_hhea_f_mis if multiplebidders==1, robust
outreg2 using "$RASKIN_TABLES/appendixtable10.bid_markups", ///
	label keep(tr_minbids markup_hhea_f2) excel dec(3) append

** Endline Price - Winning Bid
* control for baseline price	
reg markup_dif tr_minbids markup_hhea_f2 markup_hhea_f_mis, robust
outreg2 using "$RASKIN_TABLES/appendixtable10.bid_markups", ///
	label keep(tr_minbids markup_hhea_f2) excel dec(3) append

* multiple bidders only, control for baseline price
reg markup_dif tr_minbids markup_hhea_f2 markup_hhea_f_mis if multiplebidders==1, robust
outreg2 using "$RASKIN_TABLES/appendixtable10.bid_markups", ///
	label keep(tr_minbids markup_hhea_f2) excel dec(3) append
	
	
	
	
