/*******************************************************************************
Corruption on Locality Price Markup
1Data/dofiles/analysis/corruption_markup.do

Corruption (as measured through HH perceptions and dice score) and Raskin price markup
*******************************************************************************/

** SETUP AND MACROS ************************************************************
clear all
set more off

cd "$RASKIN"

** DATA PREP *******************************************************************

** Endline HH Perception of Corruption -- locality head and endline Raskin distributor
u "1Data/originaldata/3_Endline/hh_kp", clear	
keep if inlist(kp1,"D","H") //D=village head, H=raskin coordinator
recode kp02 (6 7 8 =.)
replace kp02 = (kp02-1)/3
la drop KP02
reshape wide kp02, i(hhid) j(kp1) string
rename kp02D corruption_head
rename kp02H corruption_rask
gen hhea = substr(hhid,1,3)
collapse corruption*, by(hhea)
tempfile endline
sa `endline'

** Baseline HH Perception of Corruption -- only ask about locality head
use "$TARGET2/Baseline/hh_kpi.dta",clear
rename kpi02c corruption_head
recode corruption_head (7 8 =.)
replace corruption_head=(corruption_head-1)/3 
gen hhea = substr(hhid,1,3)
collapse corruption*, by(hhea)
tempfile baseline
sa `baseline'

** Current Distributor Dice Score (Control Villages Only)
u "1Data/codeddata/competition/distributors", clear
gen hhea1 = pr_id2
keep if current_dist==1
merge 1:m hhea hhea1 using "1Data/codeddata/competition/endmidcs1"
assert _m==3
drop _m

** Collapse
collapse markup_hh high_points tr_*, by(hhea)

** Add in baseline controls
merge 1:1 hhea using "1Data/codeddata/competition/baseline_village_controls"
assert _m==3
drop _m

** Add in corruption
merge 1:1 hhea using `endline'
drop _m

** Keep control villages only
keep if tr_any==0

tempfile current
sa `current'

** Old Distributor
u "1Data/codeddata/competition/distributors", clear
gen hhea1 = pr_id2
keep if pg04_olddist_any == 1
bys pr_ea pr_id2: gen n = _N
keep if current_dist==1 | n==1
tab current_dist  TR2_2013, mi
isid pr_ea pr_id2

merge 1:m hhea hhea1 using "1Data/codeddata/competition/endmidcs1"
drop if _m==2
drop _m

** Collapse
collapse markup_hh_f high_points tr_*, by(hhea)

** Add in baseline controls
merge 1:1 hhea using "1Data/codeddata/competition/baseline_village_controls"
drop _m

** Add in corruption
merge 1:1 hhea using `baseline'
drop if _m==2
drop _m

* add distance to distpoint
tempfile temp
save `temp'

*get the location of distribution point
use "1Data/originaldata/2_Midline/k_rd2.dta", clear 

gen     distance_to_distpoint=rd16
replace distance_to_distpoint=. if distance_to_distpoint== 999998 
replace distance_to_distpoint=distance_to_distpoint/1000  //change to KM

bys commid: egen num_dist_point=max(rd_no)

collapse distance_to_distpoint num_dist_point, by(commid)
ren commid hhea 

merge 1:1 hhea using `temp'
tab _merge
drop _m

tempfile old
sa `old'

ren distance_to_distpoint distpt

local controls 	=  "n_hamlets lognumberhh_f distance_kec_t2 distpt"
label var n_hamlets "Number of hamlets"
label var lognumberhh_f "Log Number of hh"
label var distance_kec_t2 "Distance to subdistrict"
label var distpt "Distance to distribution point"

cap la var high_points 		"Raskin Distributor's Dice Score Above Median"
cap la var corruption_head	"Perception of Local Head's Corruption" 
cap la var corruption_rask 	"Perception of Raskin Distributor's Corruption"

reg markup_hh_f corruption_head, cluster(hhea)
eststo head_noctl
reg markup_hh_f corruption_head `controls', cluster(hhea)
eststo head_ctl
reg markup_hh_f high_points , cluster(hhea)
eststo dice_noctl
reg markup_hh_f high_points `controls', cluster(hhea)
eststo dice_ctl

** Export sheets for each specification to one file using xml_tab **************

local outfile "$RASKIN_TABLES/appendixtable11.corruption_markup.xml"

# delimit ;
	xml_tab head_noctl head_ctl dice_noctl dice_ctl ,
		save("`outfile'") replace
		title("Locality Price Markup vs. Corruption")
		sheet("`All'")
		showeq
		below
		stats(N)
		drop(_cons)
		;
	# delimit cr				
	
	
	
