/*******************************************************************************
Who was Selected in Bidding Localities?
1Data/dofiles/analysis/who_selected.do

Who was selected as raskin distibutor in bidding villages? 
Based on both form and endline distributor data.
*******************************************************************************/

** SETUP AND MACROS *******************************************************
clear all
set more off

cd "$RASKIN"

** PREP DATA *******************************************************************

** Form Data (Column 2)
u "1Data/codeddata/competition/bidders", clear		
merge m:1 commid using "1Data/codeddata/competition/biddingrejection"
assert reject_bidding==1 if _m==2
drop _m
rename own_village_dist own

keep if reject_bidding+reject_nobids==0 //keep if there were bids

tempfile bidders
sa `bidders'

** All Data (Column 3)
u "1Data/codeddata/competition/bid_dist_all", clear		
drop if matched != 1
drop price_dist deliver_subvillage deliver_household dist_credit ///
	own_village_dist trader_dist vehicle_dist
				
foreach var in price_dist markup_dist deliver_subvillage deliver_household ///
		pay_before dist_credit own_village_dist trader_dist vehicle_dist {
	capture rename `var'_form `var'
}

rename own_village_dist own
rename relative_off_dist relative
rename off_dist off
rename n_employed_dist n_emp
rename savings_dist savings
	
keep if reject_bidding+reject_nobids==0 //keep if there were bids

tempfile bid_dist_all
sa `bid_dist_all'

** REGRESSIONS AND TABLES ******************************************************

** Setup/Locals
local outfile "$RASKIN_TABLES/appendixtable14.a.who_selected.xml"

** Run!
forv a = 1/2 { //Specification: main table or appendix table
	local type_fe		: word `a' of "clogit" "reg" 
	local type_title	: word `a' of "conditional logit with village fixed effects" ///
									  "OLS with village fixed effects" 
	local type			: word `a' of "clogit" "areg"
	local type_options  : word `a' of "group(hhea) cl(hhea)" "a(hhea) cl(hhea)"

	forv b = 1/2 { //column/data: form (column 2) or all (column 3)
		local data_source 		: word `b' of "bidders" "bid_dist_all"
		local dt_src			: word `b' of "form" 	 "all"
		local data_name 		: word `b' of "Bidding Process Forms" "Endline Distributor Survey"
		local person_outcomes 	: word `b' of "own old_dist 	 trader_dist vehicle_dist" ///
											  "own old_dist_form trader_dist vehicle_dist relative off high_points yred_dist savings"
		local winner 			: word `b' of "winner"	"winner_form"	
		local bid_outcomes 		"markup_dist pay_before dist_credit"
		local outcomes			"`bid_outcomes' `person_outcomes'"
		
		u ``data_source'', clear

		local names
		est clear
				
		** Run Regression: Joint (Columns 2 & 3)
		eststo `type_fe'`dt_src', title("(`num')") : ///
			`type' `winner' `outcomes' if multiplebidders==1, `type_options'
				
		** P-Values
		if `b' == 1 { //column 2
			test markup_dist 		= pay_before, 	notest 
			test pay_before 		= dist_credit, 	notest accum
			test dist_credit 		= own, 			notest accum
			test own 				= old_dist, 	notest accum
			test old_dist 			= trader_dist, 	notest accum
			test trader_dist 		= vehicle_dist, notest accum
			test vehicle_dist 		= 0, 			accum
			estadd scalar pval_joint = `r(p)'
		}
		
		if `b' == 2 { //column 3
			test markup_dist 		= pay_before, 		notest
			test pay_before 		= dist_credit, 		notest accum
			test dist_credit 		= own, 				notest accum
			test own 				= old_dist_form, 	notest accum
			test old_dist_form 		= trader_dist, 		notest accum
			test trader_dist 		= vehicle_dist, 	notest accum
			test vehicle_dist 		= relative, 		notest accum
			test relative 			= off, 				notest accum
			test off 				= high_points, 		notest accum
			test high_points 		= yred_dist, 		notest accum
			test yred_dist 			= savings, 			notest accum
			test savings			= 0, accum
			estadd scalar pval_joint = `r(p)'
		}
		
		** Formatting
		local dec = "3"
						
		** Replace or append
		if "`a'" == "1" & "`b'" == "1" {
			local apprep = "replace"
		}
		else local apprep = "append"

		** Export sheets for each specification to one file using xml_tab
		# delimit ;
		xml_tab *,
			save("`outfile'") 
			`apprep' sheet("`type_fe'_`dt_src'") 
			title("Who was selected in bidding localities?")
			showeq
			below
			rblanks(vehicle_dist)
			stats(pval_joint)
			;
		# delimit cr
				
		** Run Regression: 1-by-1 (Column 1)
		est clear
		foreach v of varlist `outcomes' {
			eststo `v'`dt_src' : ///
				`type' `winner' `v' if multiplebidders==1, `type_options'
		}
		
		* Export sheets for each specification to one file using xml_tab
		# delimit ;
		xml_tab *,
			save("`outfile'")
			append
			sheet("`type'_1by1_`dt_src'") 
			title("Who was selected in bidding villages,"
			"estimated via `type_title' using data from `data_name'")
			showeq
			below
		;
		# delimit cr	
		
	} //closes b loop (column/data)
} //closes a loop (main table or appendix table)





