/*******************************************************************************
Characteristics of Sampled Localities, Compared to Indonesia as a Whole
1Data/dofiles/analysis/sample_vs_indo_comparison_podesscrambled.do

Table shows characteristics of sample relative to Indonesia as a whole
*******************************************************************************/

** SETUP AND MACROS.     *******************************************************

clear all
set more off
set maxvar 32700

cd "$RASKIN"

** ANALYSIS.             *******************************************************

*all competition villages are here 
use "1Data/codeddata/competition/endmidcs1", clear

*keep desa id and drop duplicates
keep desa_id1
duplicates drop

*create and save temp file
tempfile sample
save `sample'

*get PODES data
use "1Data/originaldata/PodesData/podes_2011_competitionvil_scrambled.dta", clear

*merge in temp file
merge 1:1 desa_id1 using `sample'

gen competition= (_merge==3)
drop _merge

*drop these two provinces
drop if prov=="11" | prov=="94" 

*generate variables
gen  num_prim_sch      =r701bk2+r701bk3
gen  dis_subdistrict   =r1004ak2
gen  num_household     =r401c
gen  num_agri_hh       =r401d
gen  kelurahan         =(r301=="2")
gen  urban             =(statusdesa==1)

*generate agriculture variable
gen  agri_pct=num_agri_hh/num_household

*generate school variable
gen  prim_pct=num_prim_sch/(num_household / 1000)
gen  log_num_hh= log(num_household) 

*generate insurance variable
gen jamkesmas=r711
gen jamkesmas_pct=jamkesmas/num_household

*generate health variable
egen num_health_facilities=rowtotal (r704ak3 r704bk3 r704ck3 r704dk3 r704ek3 r704fk3 r704gk3 r704hk3 r704ik3 r704jk3) //excluding apotek and toko jamu
gen health_pct   =num_health_facilities/(num_household / 1000)

** Export to excel            **************************************************

local outcome log_num_hh agri_pct jamkesmas_pct prim_pct health_pct dis_subdistrict urban kelurahan 

foreach x of local outcome {
eststo `x'  : reg `x' competition [aweight=num_household], cluster(kabu_id) robust
}

esttab using "2Output/tables/appendixtable2.sample_vs_allindo_noFE_weight.csv", se replace


