/*******************************************************************************
Bidding vs Info Meetings (Conditional on Meetings Occuring) 
1Data/dofiles/analysis/summ_meetings_info.do

Compares information and bidding treatment meetings
*******************************************************************************/

** SETUP AND MACROS *******************************************************
clear all
set more off

cd "$RASKIN"

** PREP DATA **************************************************************

u "1Data/codeddata/competition/bidding_meeting", clear 
append using "1Data/codeddata/competition/info_meeting"
replace mtg_time = . if mtg_time > 9
recode tr_* (.=0)

la var mtg_total 	 	"Total Number of Meeting Attendees"
la var mtg_raskin	 	"Number Raskin Beneficiaries Attending"
la var mtg_official	 	"Number Village/Hamlet Officials Attending"
la var mtg_questions 	"Any Questions/Comments Left at Meeting?"
la var mtg_questions_n	"Number of Questions/Comments Left"

** ANALYSIS ***************************************************************

* Locals
local outfile "$RASKIN_TABLES/appendixtable5.bidding_info_meetings"
local group mtg_time mtg_total mtg_raskin mtg_official mtg_questions mtg_questions_n

* Setup
format `group' %10.2fc

* By Info/Bidding
forv i = 0/1 {
	eststo bidding_`i' : estpost summ `group' if tr_dist==`i'
}
eststo t : estpost ttest `group', by(tr_dist)

* By Open Bids/Min Bids
forv i = 0/1 {
	eststo biddingsub_`i' : estpost summ `group' if tr_dist==1 & TR2a==`i'
}
eststo tsub : estpost ttest `group' if tr_dist==1, by(TR2a)

* Create Table
tempfile table

# delimit ;
esttab bidding_0 bidding_1 biddingsub_0 biddingsub_1 t tsub
	using `table',
	title("Bidding vs Info Meetings (Conditional on Meeting Occuring)")
	starlevels(* 0.10 ** 0.05 *** 0.01) 
	cells(`"mean(label("Mean") fmt(%10.2fc))
			sd(label("Std. Dev.") fmt(%10.2fc))
			p(label("PVal") fmt(%10.2fc) star)
			count(label("Observations") fmt(%10.0fc))"'
		)
	mtitles("Info" "Bidding" "Open Bids" "Min # Bids" "P-Value")
	noobs nonum label replace csv
	;
# delimit cr

* Clean Table
insheet using `table', comma clear

foreach type in "Mean" "Std. Dev." "PVal" {
	foreach var of varlist _all {
		quietly count if `var' != "`type'" & `var' != ""
		if `r(N)' <= 1 {
			drop `var'
		}
	}
}

replace v20 = "P-Value" in 2

* Export to excel **************************************************************
export excel "`outfile'", sheetrep


