/*******************************************************************************
Flow of Localities through Bidding Process
1Data/dofiles/analysis/summ_rejection.do

Exports data used to create Figure 1
*******************************************************************************/

** SETUP AND MACROS *******************************************************
clear all
set more off

cd "$RASKIN"

* GET DATA, PREP VARIABLES *****************************************************

** Average Village Price Data

use "1Data/codeddata/competition/endmidcs1", clear
keep if tr_dist==1
bys hhea: gen n = _n == 1
rename markup_hh_f markup_base
rename markup_hh markup_end

** Merge with Rejection
merge m:1 hhea using "1Data/codeddata/competition/biddingrejection"
assert _m==3
drop _m

forv x = 1/5 {
	gen bids_`x' = n_bidders == `x'
}

summ  markup_base markup_end


** Create and save temp file
tempfile data
sa `data'

* CREATE TABLE *****************************************************************

local outfile "$RASKIN_FIGURES/figure1_summ_rejection"

est clear
u `data', clear
		
local outcomes tr_dist reject_bidding reject_nobids bids_1 bids_2 bids_3 bids_4 bids_5 ///
				old_win never_dist reject_blocked return_sq ///
				blocked_by_vill_forum blocked_by_vill_govt ///
				blocked_by_kec_govt blocked_by_kab_govt		
local n : word count `outcomes'
local m = `n'+1

gen var = ""
forv a = 0/1 {
	gen v`a'n = .
	
	gen v`a'base = .
	gen v`a'end = . 
	
	forv old = 0/1 {
	gen v`a'`old'n = .
	gen v`a'`old'base = .
	gen v`a'`old'end = .
	
		format v`a'n v`a'base v`a'end v`a'`old'n v`a'`old'base v`a'`old'end %10.0fc
		forv i = 1/`n' {
			local j = `i'+1
			local v : word `i' of `outcomes'
			
			replace var = "`v'" in `j'
			
			count if `v'==`a' & n==1
			local `v'`a'n = `r(N)'
			
			replace v`a'n = ``v'`a'n' in `j'
			
			foreach x in base end {
			summ markup_`x' if `v'==`a'
			if `r(N)' == 0 local `v'`a'`x' = 0
			else local `v'`a'`x' = `r(mean)'
			
			replace v`a'`x' = ``v'`a'`x'' in `j'
			}
			
			if inlist("`v'", "reject_nobids", "reject_blocked", "never_dist", "some_dist", "some_blocked") | ///
				inlist("`v'", "blocked_by_vill_forum", "blocked_by_vill_govt", "blocked_by_kec_govt", "blocked_by_kab_govt", "old_current", "new_current") | ///
				inlist("`v'", "months_4", "months_7", "months_8", "delay","return_sq") {
				count if `v'==`a' & old_win==`old' & n==1
				local `v'`a'`old'n = `r(N)'
				
				replace v`a'`old'n = ``v'`a'`old'n' in `j'
				
				foreach x in base end {
				summ markup_`x' if `v'==`a' & old_win==`old'
				if `r(N)' == 0 local `v'`a'`old'`x' = 0
				else local `v'`a'`old'`x' = `r(mean)'

				replace v`a'`old'`x' = ``v'`a'`old'`x'' in `j'
				}
			}
		}
		tostring v`a'`old'n, replace usedisplayformat force
		replace v`a'`old'n = "N if reject==`a'&old==`old'" in 1
		foreach x in base end {
		tostring v`a'`old'`x', replace usedisplayformat force
		replace v`a'`old'`x' = "Mean if reject==`a'&old==`old'&wave==`x'" in 1
		}
	}
		tostring v`a'n, replace usedisplayformat force
		replace v`a'n = "N if reject==`a'" in 1
		foreach x in base end {
		tostring v`a'`x', replace usedisplayformat force
		replace v`a'`x' = "Mean if reject==`a'&wave==`x'" in 1
		}
}

keep var-v11end
keep in f/`m'

** Export to excel.           **************************************************

export excel "`outfile'", sheet("markup") sheetrep


