** SETUP AND MACROS *******************************************************
clear all

set more off

cd "$RASKIN"

// add adopath for use of "fanreg.ado" file
adopath + "1Data/ado"

** VILLAGE-LEVEL VARIABLES *****************************************************
/* 	final price for raskin in endline (village-level), 
	dummy for distributor different than original (village-level)*/
	
** Get Data
	u "1Data/codeddata/competition/endmidcs1", clear
	keep meanmarkup_hhea markup_hhea_f hhea hhea1
	rename hhea pr_ea
	rename hhea1 pr_id2
	duplicates drop
	merge 1:m pr_ea pr_id2 using "1Data/codeddata/competition/distributors"
	assert _m==3
	drop _m
	keep if current_dist==1
	
** Create Graph
	gen treatment = 1 if tr_ctl==1|tr_moni==1
	replace treatment = 2 if tr_minbids==1
	replace treatment = 3 if tr_nomin==1
	drop if treatment == .
	la var markup_hhea_f "Baseline Markup"
	local x meanmarkup_hhea
	
	* make unique (not unique since there may be mult distribors
	codebook hhea if meanmarkup_hhea != .
	
	bys hhea: keep if _n == 1
	
	
	* cdfplot `x' , by(treatment) ///
		xlabel(0(500)3000,) ///
		legend(label(1 "Control/Info") label(2 "Extended Bidding") label(3 "Regular Bidding")) ///
		title("Endline Markup")
		*graph export "$RASKIN_FIGURES/endlinemarkup_cdf.pdf", replace
	
	rename tr_minbids tr_m
	rename tr_nomin tr_o
	replace meanmarkup_hhea = 2000 if meanmarkup_hhea>2000 & !mi(meanmarkup_hhea)
		
	cumul meanmarkup_hhea if tr_m == 1 & tr_o ==0, gen(c_m)
	cumul meanmarkup_hhea if tr_m == 0 & tr_o ==1, gen(c_o)
	cumul meanmarkup_hhea if tr_m == 0 & tr_o ==0, gen(c_nd)
	
	label var c_m "Extended Bidding"
	label var c_o "Regular Bidding"
	label var c_nd "Control/Info"
	
	* Make monotonic
	twoway (line  c_m meanmarkup_hhea, sort(meanmarkup_hhea c_m)) (line  c_o meanmarkup_hhea, sort(meanmarkup_hhea c_o)) (line  c_nd meanmarkup_hhea, sort(meanmarkup_hhea c_nd))
	
	graph export "$RASKIN_FIGURES/figure2_endlinemarkup_cdf.pdf", replace
		
	
