/*******************************************************************************
The Bidding Process
1Data/dofiles/analysis/table1.summ_meetings.do

Descriptive info on bidding meetings
*******************************************************************************/

** SETUP AND MACROS *******************************************************
clear all
set more off

cd "$RASKIN"

****************************
* 1. Input data 
****************************

//load in data, merge data
u "1Data/codeddata/competition/bidders", clear
merge m:1 commid using "1Data/codeddata/competition/biddingrejection"
drop _m

//create and save temp file
tempfile a 
sa `a'

preserve
	u "1Data/codeddata/competition/bidding_meeting", clear
	merge 1:m commid using `a'
	
	replace old_win = . if reject_bidding == 1 
	
	local panel_a n_bids n_bids_not_disqualified old_win 
	local panel_b mtg_total mtg_raskin mtg_official 
	local panel_c mtg_discuss_none mtg_discuss_slight mtg_discuss_majority mtg_discuss_vastmajority
	
	la var mtg_official "Village or Hamlet Officials"
	
	foreach var of varlist `panel_a' `panel_b' `panel_c' {
		local `var'_lbl : var la `var'
	}
	
	collapse tr_minbids tr_nomin TR2a TR2b TR2c `panel_a' `panel_b' `panel_c' dist_credit, by(commid)
	la var TR2a "Min # of bids subtreatment"
	la var TR2b "Women quota subtreatment"
	la var TR2c "Enhanced supervision subtreatment"
		
	foreach var of varlist `panel_a' `panel_b' `panel_c' {
		la var `var' "``var'_lbl'" 
	}

	la var n_bids "Number of Bids"
	la var n_bids_not_disqualified "Number of Bids, after Initial Screening"
	la var old_win "Old Distributor Wins"
	la var dist_credit "Bidder offers credit"
	tempfile comm_vars
	sa `comm_vars'
restore

//keep if winner not empty
keep if winner!=.

//create and save temp file
tempfile winners_losers
sa `winners_losers'

****************************
* 2. Output summary table - Info on Bidding Meetings
****************************

local group `panel_a' `panel_b' `panel_c'

* Setup
u `comm_vars', clear
format `group' %10.2fc
est clear

* Overall
eststo all : estpost summ `group'

* By Open Bids/Min Bids
foreach var of varlist TR2a {
	forv i = 0/1 {
	eststo `var'_`i' : estpost summ `group' if `var'==`i'
	}
	eststo `var'_t : estpost ttest `group', by(`var')
}

* Create Table
tempfile table

# delimit ;
esttab all TR2a_0 TR2a_1 TR2a_t
	using `table',
	title("The Bidding Process (Conditional on Bidding Meeting Occuring)")
	starlevels(* 0.10 ** 0.05 *** 0.01) 
	cells(`"mean(label("Mean") fmt(%10.2fc))
			sd(label("Std. Dev.") fmt(%10.2fc))
			p(label("Open Bids = Min # Bids") fmt(%10.2fc) star)
			count(label("Observations") fmt(%10.0fc))"'
		)
	mtitles("Overall" "Open Bids" "Min # Bids" "P-Value")
	noobs nonum label replace csv
	;
# delimit cr

* Clean Table
insheet using `table', comma clear

foreach type in "Mean" "Std. Dev." "Open Bids = Min # Bids" {
	foreach var of varlist _all {
		quietly count if `var' != "`type'" & `var' != ""
		if `r(N)' <= 1 {
			drop `var'
		}
	}
}

replace v16 = "P-Value" in 2

* Export table         *********************************************************
export excel "$RASKIN_TABLES/table1.summ_meetings", ///
  sheet("bidding_meetings") sheetrep

  
  
