/*******************************************************************************
Who Distributes Raskin Six Months After Intervention?
1Data/dofiles/analysis/who_distributes.do

Comparing characteristics of Raskin distributors
*******************************************************************************/

** SETUP AND MACROS *******************************************************
clear all
set more off
set maxvar 32700

cd "$RASKIN"

** INPUT DATA ******************************************************************

** Grab Data
u "1Data/codeddata/competition/distributors", clear
keep if current_dist==1
egen combined_sub_off = rowmax(relative_sub_off_dist sub_off_dist)

** Shortened Labels
la var pg04_olddist_any "In charge of any responsibilities before May 2013"
la var own_village_dist "Lives in village"
la var off_dist "Distributor/spouse is/was local official"
la var relative_off_dist "Distributor/spouse is related local village official"
la var combined_sub_off "Distributor/spouse is/was or is related to hamlet official"
la var trader_dist "Is a trader"
la var vehicle_dist "Owns truck and/or boat"
la var digitspan_hi "Avg Digit Span above median"
la var high_points "Raw dice score above median"
la var yred_dist "Years of education"
la var savings_dist "Has personal savings account for business"

** Treatment Variables
gen tr_monidist = tr_moni==1 | tr_dist==1
la var tr_monidist "Info or Bidding"
la var tr_dist "Bidding"
la var tr_minbids "Min # Bids"
la var tr_nomin "Regular Bids"

rename tr_nomin tr_nominbids

** REGRESSIONS AND TABLES ******************************************************

** Setup/Locals
*local outfile "$RASKIN_TABLES/who_distributes_ri.xml"

** Run!
forv i = 1/2 { //Table A or B
	local outcomes 	: word `i' of "pg04_olddist_any off_dist relative_off_dist combined_sub_off trader_dist own_village_dist" ///
						"vehicle_dist digitspan_hi high_points yred_dist savings_dist"
	*local outcomes 	: word `i' of "pg04_olddist_any" ///
						*"vehicle_dist"					
						
	local sheet		: word `i' of A B
		
	forv l = 1/2{ //Panel A or B
		local tr_dist		: word `l' of "tr_dist" "tr_nominbids tr_minbids"
		local tr_title		: word `l' of "Panel A: Combined Effect of Outsourcing" "Panel B: Estimating Additional Efect of Competition"
		local tr			: word `l' of MAIN MIN
		local rblanks 		: word `l' of "tr_dist P-Value" "tr_minbids P-Value"
		
		
		/** Ouput
		if `i'+`l' == 2 local apprep replace
		else local apprep append
		
		est clear
		local num = 0
		local names */
		
		if "`sheet'"=="B" {
		eststo clear
		}
		
		if "`tr'" == "MAIN" {
		
		foreach v of varlist `outcomes'{ 
		
		//Loop through outcomes
			*local ++num
			
			 //Panel A
			
			** Run Regression
			     eststo `v', title("`v'") : ///
				 areg `v' tr_monidist tr_dist, a(strata_simple)
				 scalar breg        =  _b[tr_monidist]
				 scalar breg_dist   =  _b[tr_dist]
			     
			*Add control mean
			    summ `v' if e(sample) == 1 & TR2_2013 == 1
				eststo `v', add(mean r(mean) sd r(sd))
						
			  lincom tr_monidist + tr_dist
						
			   			
			}
			
			esttab using "$RASKIN/2Output/tables/table2.who_distributes_NOri_`sheet'_`tr'_5k.csv", se keep(tr_monidist tr_dist) cells("b se pval") stat(pval_join mean sd N, labels("P value tr_monidist+tr_dist" "control mean") layout(@ "@ @" @)) replace csv mtitles
            
			}
						
			if "`tr'" == "MIN" { 
			//Panel B
			eststo clear 
			foreach v of varlist `outcomes'{
					
				** Run Regression
					
					eststo `v', title("`v'") : ///
					areg `v' tr_monidist tr_nominbids tr_minbids, a(strata_simple)
					  
					    scalar breg              =  _b[tr_monidist]
						scalar breg_nominbids    =  _b[tr_nominbids]
						scalar breg_minbids      =  _b[tr_minbids]
						
						summ `v' if e(sample) == 1 & TR2_2013 == 1
						eststo `v', add(mean r(mean) sd r(sd))
						
						lincom tr_minbids - tr_nominbids
						
						*matrix b = (r(estimate))
						*matrix se = (r(se))
						*eststo `v', add(onetwo r(estimate) se_1_2 r(se))
						
						lincom tr_minbids + tr_monidist 
						
						*matrix b = (r(estimate))
						*matrix se = (r(se))
						*eststo `v', add(onethree r(estimate) se_1_3 r(se))
						
						lincom tr_nominbids + tr_monidist
						
						*matrix b = (r(estimate))
						*matrix se = (r(se))
						*eststo `v', add(twothree r(estimate) se_2_3 r(se))
				
				}
				
			   esttab using "$RASKIN/2Output/tables/table2.who_distributes_NOri_`sheet'_`tr'_5k.csv", se keep(tr_monidist `tr_dist') cells("b se pval") stat(pval_1_2 pval_1_3 pval_2_3 mean sd N, labels("P value tr_minbids-tr_nominbids" "P value tr_minbids+tr_monidist" "P value tr_nominbids+tr_monidist" "control mean") layout(@ @ @ "@ @" @)) replace csv mtitles

				
				}	
					
				
				}
				
				
				}
				
				
				
		
				
				



