/*******************************************************************************
Endline Costs to Current Distributor
1Data\dofiles\analysis\distributor_cost.do

Does treatment decrease distributor costs?
*******************************************************************************/

** SETUP AND MACROS *******************************************************
clear all
set more off
set maxvar 32700

cd "$RASKIN"

** GET DATA ********************************************************************
** Grab Data
u "1Data/codeddata/competition/current_distributor_costs.dta", clear
merge m:1 hhea using "1Data/codeddata/competition/good_strata"
assert _m==3
drop _merge

** Treatment Variables
gen tr_monidist = tr_moni==1 | tr_dist==1
la var tr_monidist "Info or Bidding"
la var tr_dist "Bidding"
la var tr_minbids "Min # Bids"
la var tr_nomin "Regular Bids"

** Cost Coding

** Drop if Missing All Cost Data
egen rownonmiss = rownonmiss(total_transport_cost total_other_cost compensation_cost)
drop if rownonmiss == 0
drop rownonmiss

** Fill Missings with 0, if At Least One Cost Exists
foreach x in total_transport_cost total_other_cost compensation_cost {
	replace `x' = 0 if `x'==.
}

** Total Costs incurred by distributor
egen total_cost = rowtotal(total_transport_cost total_other_cost compensation_cost), missing
la var total_cost "Total costs of distribution (Rp)"

** Topcoding
foreach x in total_transport_cost total_other_cost compensation_cost total_cost {
	summ `x', d
	replace `x' = . if `x' > `r(p99)'
}

rename tr_nomin tr_nominbids

** REGRESSION ******************************************************************

** Setup/Locals
*local outfile "$RASKIN_TABLES/distributor_costs.xml"	
local outcomes total_transport_cost compensation_cost total_other_cost total_cost

** Run!
forv x = 1/2 { //Panel A or B
	local tr_dist	: word `x' of "tr_dist" "tr_nominbids tr_minbids"
	local tr	: word `x' of main minbids
	local apprep	: word `x' of replace append
	local rblanks	: word `x' of "tr_dist P-Value" "tr_nomin P-Value"
			
	est clear
	local num = 0
	local names
	
	
	if `x'==1 {
	
	foreach v of varlist `outcomes'{ //Loop through outcomes
		local ++num
		
		** Run Regression
		eststo `v', title("`v'") : ///
			areg `v' tr_monidist tr_dist, a(strata_simple) robust	
		    scalar breg        =  _b[tr_monidist]
			scalar breg_dist   =  _b[tr_dist]
		
		 *Add control mean
			    summ `v' if e(sample) == 1 & TR2_2013 == 1
				eststo `v', add(mean r(mean) sd r(sd))
						
			  lincom tr_monidist + tr_dist
			}
		
		
		esttab using "$RASKIN/2Output/tables/table4.distributor_cost_NOri_`tr'_5k.csv", se keep(tr_monidist tr_dist) cells("b se pval") stat(pval_join mean sd N, labels("P value tr_monidist+tr_dist" "control mean") layout(@ "@ @" @)) replace csv mtitles

	}
		
		if `x'==2 { //Panel B
			
		foreach v of varlist `outcomes' {
		local ++num 
			
				** Run Regression
					
					eststo `v', title("`v'") : ///
					areg `v' tr_monidist tr_nominbids tr_minbids, a(strata_simple) robust
					  
					    scalar breg              =  _b[tr_monidist]
						scalar breg_nominbids    =  _b[tr_nominbids]
						scalar breg_minbids      =  _b[tr_minbids]
						
						summ `v' if e(sample) == 1 & TR2_2013 == 1
						eststo `v', add(mean r(mean) sd r(sd))
						
						lincom tr_minbids - tr_nominbids
						
						*matrix b = (r(estimate))
						*matrix se = (r(se))
						*eststo `v', add(onetwo r(estimate) se_1_2 r(se))
						
						lincom tr_minbids + tr_monidist 
						
						*matrix b = (r(estimate))
						*matrix se = (r(se))
						*eststo `v', add(onethree r(estimate) se_1_3 r(se))
						
						lincom tr_nominbids + tr_monidist
						
						*matrix b = (r(estimate))
						*matrix se = (r(se))
						*eststo `v', add(twothree r(estimate) se_2_3 r(se))
				
				}
			
			
			
		esttab using "$RASKIN/2Output/tables/table4.distributor_cost_NOri_`tr'_5k.csv", se keep(tr_monidist `tr_dist') cells("b se pval") stat(pval_1_2 pval_1_3 pval_2_3 mean sd N, labels("P value tr_minbids-tr_nominbids" "P value tr_minbids+tr_monidist" "P value tr_nominbids+tr_monidist" "control mean") layout(@ @ @ "@ @" @)) replace csv mtitles


		}
					
		}

	
