/*******************************************************************************
Table 7: Baseline Markup and #of Bids
CR: For this table, we need : 1. number of bids (Table 1)
                              2. baseline controls --> 1Data/codeddata/competition/baseline_village_controls.dta
							  3. Baseline price markup --> 1Data/codeddata/competition/endmidcs1
*******************************************************************************/

** SETUP AND MACROS *******************************************************
clear all
set more off

cd "$RASKIN"

****************************
* 1. Input data (Table 1)
****************************

//load in data, merge data, save as temp file
u "1Data/codeddata/competition/bidders", clear
merge m:1 commid using "1Data/codeddata/competition/biddingrejection"
drop _m
tempfile a 
sa `a'

preserve
	u "1Data/codeddata/competition/bidding_meeting", clear
	merge 1:m commid using `a'
	
	replace old_win = . if reject_bidding == 1 
	
	local panel_a n_bids n_bids_not_disqualified old_win 
	local panel_b mtg_total mtg_raskin mtg_official 
	local panel_c mtg_discuss_none mtg_discuss_slight mtg_discuss_majority mtg_discuss_vastmajority
	
	la var mtg_official "Village or Hamlet Officials"
	
	foreach var of varlist `panel_a' `panel_b' `panel_c' {
		local `var'_lbl : var la `var'
	}
	
	collapse tr_minbids tr_nomin TR2a TR2b TR2c `panel_a' `panel_b' `panel_c' dist_credit, by(hhea) //CR 170130: old code use commid, but commid==hhea
	la var TR2a "Min # of bids subtreatment"
	la var TR2b "Women quota subtreatment"
	la var TR2c "Enhanced supervision subtreatment"
		
	foreach var of varlist `panel_a' `panel_b' `panel_c' {
		la var `var' "``var'_lbl'" 
	}

	la var n_bids "Number of Bids"
	la var n_bids_not_disqualified "Number of Bids, after Initial Screening"
	//la var n_bidders "# Bidders who were present in meeting"
	la var old_win "Old Distributor Wins"
	la var dist_credit "Bidder offers credit"
	tempfile comm_vars
	sa `comm_vars'
restore

******************************
* 2. Get the controls (TABLE 5)
******************************

*find the data which has baseline price markup	(from Table 5 do-file) 						  
use "1Data/codeddata/competition/endmidcs1", clear 
collapse markup_hh_f amtraskin_f, by(hhea) 						  
	
*add baseline controls (from Table 5 do-file) 
merge 1:1 hhea using "1Data/codeddata/competition/baseline_village_controls"
drop _m

* add distance to distpoint
tempfile temp
save `temp'

*get the location of distribution point
use "1Data/originaldata/2_Midline/k_rd2.dta", clear 

*generate distance to distpoint variable
gen     distance_to_distpoint=rd16
replace distance_to_distpoint=. if distance_to_distpoint== 999998 
replace distance_to_distpoint=distance_to_distpoint/1000  //change to KM

bys commid: egen num_dist_point=max(rd_no)

collapse distance_to_distpoint num_dist_point, by(commid)
ren commid hhea 

merge 1:1 hhea using `temp'
tab _merge
drop _m

*******************************
* 3. MERGE & REGRESS
******************************

merge 1:1 hhea using `comm_vars'
keep if _m==3	
tab TR2a //check if this is enhanced competition dummy

sum n_bids  //this has to match table 1 column 1&2 
sum n_bids if TR2a==1  // this has to match table 1 column 5 & 6

tempfile test
sa `test', replace
	
forv j = 1/2 {

local outcome n_bids
local controls 	: word `j' of "markup_hh_f TR2a" "markup_hh_f TR2a n_hamlets lognumberhh_f distance_kec_t2 distance_to_distpoint" 
local x         : word `j' of  replace append
est clear 

*regress 
use `test', clear
eststo: reg `outcome' `controls', robust

** Export to csv.             **************************************************
esttab using "$RASKIN_TABLES/table6.markup_enhanced.csv", se star(* 0.10 ** 0.05 *** 0.01)nomtitles nolegend nonotes `x'
	}

	
	
