
clear
set more off 

cd "$RASKIN"

** PREP DATA *******************************************************************

** Grab Data
use "1Data/codeddata/competition/endmidcs1", clear

** Construct fake baseline controls so loop will run (all the same--> omitted)
g satis_qual_cat01_f2 = 1
g satis_qual_cat01_f_mis = 1
	
** Shortened Labels
la var bought_last2m 	"Bought Raskin"
la var markup_hh 		"Price markup"
la var amtraskin 		"Amount purchased"
la var satis_qual_cat01 "Satisfied with rice quality"
la var distance 		"Distance to purchase point (meters)"
la var time 			"Time to purchase point (minutes)"
la var pay_adv 			"Paid for rice in advance" 
la var satis_prog_cat01	"Satisfied with Raskin program"

** Treatment Variables
gen tr_monidist = tr_moni==1 | tr_dist==1
la var tr_monidist "Info or Bidding"
la var tr_dist "Bidding"
la var tr_minbids "Min # Bids"
la var tr_nomin "Regular Bids"

** REGRESSIONS AND TABLES ******************************************************

local v = "markup_hh"
local tr_dist_a = "tr_dist"  // panel A
local tr_dist_b = "tr_nomin tr_minbids"  // panel B
local hhcontrol = "`v'_f2 `v'_f_mis"
local condition = ""

qui {
	tab sample, gen(sample_)
	drop sample_1
	tab strata_simple, gen(strata_simple_)
	drop strata_simple_1
}

areg `v' tr_monidist `tr_dist' `hhcontrol' i.sample `condition', cl(hhea) a(strata_simple)
reg `v' tr_monidist `tr_dist' `hhcontrol' i.sample `condition' i.strata_simple, cl(hhea)
reg `v' tr_monidist `tr_dist' `hhcontrol' sample_? `condition' strata_simple_*, cl(hhea)

capture ssc install qreg2
// qreg2 enables robust and clustered standard error

cap erase "$RASKIN_TABLES/table7a.quantiletreatmenteffects.xls"
cap erase "$RASKIN_TABLES/table7a.quantiletreatmenteffects.txt"
cap erase "$RASKIN_TABLES/table7b.quantiletreatmenteffects.xls"
cap erase "$RASKIN_TABLES/table7b.quantiletreatmenteffects.txt"

foreach q in 0.1 0.25 0.5 0.75 0.9 {
	qreg2 `v' tr_monidist `tr_dist_a' `hhcontrol' sample_? `condition' strata_simple_*, cl(hhea) q(`q')
	ttest tr_monidist = tr_dist
	outreg2 using "$RASKIN_TABLES/table7a.quantiletreatmenteffects.xls", excel append keep(tr_monidist `tr_dist_a') nor2 nocons title("Panel A: Combined Effect of Outsourcing")
}

foreach q in 0.1 0.25 0.5 0.75 0.9 {
	qreg2 `v' tr_monidist `tr_dist_b' `hhcontrol' sample_? `condition' strata_simple_*, cl(hhea) q(`q')
	test tr_monidist = tr_nomin
	ttest tr_monidist = tr_minbids
	ttest tr_minbids = tr_nomin
	outreg2 using "$RASKIN_TABLES/table7b.quantiletreatmenteffects.xls", excel append keep(tr_monidist `tr_dist_b') nor2 nocons title("Panel B: Estimating Additional Effect of Competition")
	
	
}
