** RANDOMIZATION CHECK

** SETUP AND MACROS *******************************************************

clear all

set more off
set mem 250m
set matsize 800
pause off
set seed 5757
set sortseed 5757

cd "$RASKIN"
	
** PREP ************************************************************************

* Raskin villages
u "1Data/codeddata/cards_paper/paper/combined.dta", clear
keep hhea CTL treatment STD ENH ALL B10 PRC NOP CPN NOC t2trm1 t2trm2 t2trm3 kecagroup
duplicates drop hhea, force

preserve
	rename hhea desa_id2
	merge m:1 desa_id2 using "1Data/originaldata/0_Randomization/120716 randomization results for new TR2.dta"
	assert _m != 1
	count if _m==2
	assert `r(N)'==28
	keep if _m==3
	rename desa_id2 hhea
	keep hhea desa_id1
	tempfile desa1
	sa `desa1'
restore

merge 1:1 hhea using `desa1'
assert _m==3
drop _m

tempfile villages
sa `villages'

** load T2 baseline basic data (interview date)
u "1Data/originaldata/TargetingIIData/Baseline/hh_cov.dta", clear
rename  hhivwdd1 int_day
rename  hhivwmm1 int_mth
rename  hhivwyy1 int_yr
keep hhid int_day int_mth int_yr
tempfile int_date
sa `int_date'

** load T2 baseline data on Raskin purchase (intensive)
u "1Data/originaldata/TargetingIIData/Baseline/hh_ksr5.dta", clear
keep if ksr3type=="a"

* Bought at least once in the past 12 months
recode ksr08 (8 = 0) (3 = 0)
rename ksr08 bought_lyr

* times bought in past 12 months
rename ksr09 times_bought

* code bought in last 2 months
merge 1:1 hhid using `int_date'
assert _m!=1
keep if _m==3
drop _m

* data cleaning - last date cannot be in the future
gen drop=0
replace drop=1 if  int_yr == ksr10_yy &  int_mth < ksr10_mm & ksr10_yy!=.
replace drop=1 if  int_yr < ksr10_yy  &  ksr10_yy!=.
replace drop=1 if  ksr10_mm==98

replace ksr10_yy=. if drop==1
replace ksr10_mm=. if drop==1
drop drop

replace int_yr=2011 if int_yr==2010 & int_mth<=2

* months since January 2010
gen int_time = (int_yr - 2010)*12 + int_mth
gen ras_time = (ksr10_yy - 2010) * 12 + ksr10_mm

assert int_time>=ras_time if ras_time!=.

* Has bought in the past 2 months
gen bought_last2m = 0
replace bought_last2m = 1 if (int_time-ras_time <=2)

* amount bought last time
replace ksr11_kg = ksr11_lt*.8 if ksr11_kg==.
replace ksr11_kg = 0 if bought_lyr==3

replace ksr11_kg = . if ksr11_kg > 100	// trimmed at 100

rename ksr11_kg amtraskin

keep hhid bought_lyr times_bought  bought_last2m amtraskin

la var bought_lyr "Purchased Raskin in the past 12 months"
la var times_bought "Number of time bought in the past 12 months"
la var bought_last2m "Purchased Raskin the past 2 months"
la var amtraskin "Raskin purchased (in kg)"

g hhea = substr(hhid,1,3)

merge m:1 hhea using `villages'
assert _m!=2
keep if _m==3
drop _m

tempfile baseline_raskin
sa `baseline_raskin'

* HH LEVEL ***************************************************************************
* Merging together HH-level files
use "1Data/originaldata/TargetingIIData/Baseline/hhhead.dta", clear
merge 1:1 hhid using "1Data/originaldata/TargetingIIData/Baseline/coding_suseti_pmt"
recode  educationhhhead (95 98=.)
assert _m==3
drop _m
merge 1:1 hhid using "1Data/originaldata/TargetingIIData/Baseline/consumption.dta"
assert _m==3
drop _m

drop kecagroup

merge 1:1 hhid using `baseline_raskin'
assert _m!=2
keep if _m==3
drop _m

rename yreducationhhhead yredhhhead
rename logconsumption logc
rename consumption    consump

keep hhid hhea CTL treatment STD ENH ALL B10 PRC NOP CPN NOC t2trm1 t2trm2 t2trm3 kecagroup ///
			   logc consump yredhhhead PMTSCORE PMTRANK ///
               bought_lyr times_bought  bought_last2m amtraskin
	  
saveold "1Data/codeddata/cards_paper/paper/hhdata_for_randcheck", replace
 
* VILLAGE LEVEL **********************************************************************
* PODES data preparation
u "1Data/originaldata/TargetingIIData/coding_podes08.dta", clear

forv x = 1/3 {
	tostring prov kab kec desa, replace
	foreach a in prov kab kec desa {
		replace `a' = subinstr(`a'," ","",.)
	}
	replace prov = "0" + prov if length(prov)<2
	replace kab = "0" + kab if length(kab)<2
	replace kec = "0" + kec if length(kec)<3
	replace desa = "0" + desa if length(desa) < 3
}
g desa_id1=prov+kab+kec+desa
tempfile podes
sa `podes'

* Village-level files
u "1Data/originaldata/TargetingIIData/Baseline/rthead", clear
merge 1:1 hhea using "1Data/originaldata/TargetingIIData/Baseline/distance"
assert _m==3
drop _m
merge 1:1 hhea using "1Data/originaldata/TargetingIIData/Baseline/pctagriculture"
assert _m==3
drop _m
merge 1:1 hhea using `villages'
assert _m!=2
count if _m==1
assert `r(N)'==28
keep if _m==3  // <------------------ Here we're keeping only reporting villages
drop _m

ren hhea desa_id2
gen lognumberhh=log(tothhinRT)

* final preparation
merge 1:1 desa_id1 using `podes'
assert _m!=1
keep if _m==3
drop _m
keep desa_id2 pctagriculturalhh yreducationrthead lognumberhh kecagroup distance /// 
	 logvillagesize religiousbuildingperhh primaryschperhh treatment CTL ENH STD ALL ///
	 B10 PRC NOP CPN NOC t2trm1 t2trm2 t2trm3
	 
	 
replace primaryschperhh = 1000 * primaryschperhh
replace religiousbuildingperhh = 1000  * religiousbuildingperhh

rename religiousbuildingperhh relbperhh
rename yreducationrthead yredrthead
rename primaryschperhh pschperhh
	 
la var lognumberhh      "Log Number of Households in RT"
la var pschperhh  "Number of Primary Schools per 1000 Household"
la var  logvillagesize  "Log village size"
la var  relbperhh "Number of Religious buildings per 1000Household"

compress
sort desa_id2
rename pctagriculturalhh pctagriculture
rename distance distance_kec

rename desa_id2 hhea

saveold "1Data/codeddata/cards_paper/paper/village_data_for_randcheck", replace

* Save village averages for use in other appendix tables **************************************

use "1Data/codeddata/cards_paper/paper/hhdata_for_randcheck", clear

collapse logc PMTSCORE yredhhhead bought_lyr times_bought bought_last2m amtraskin, by(hhea) 

merge m:1 hhea using "1Data/codeddata/cards_paper/paper/village_data_for_randcheck"
assert _m==3
drop _m

drop  kecagroup- treatment

saveold "1Data/codeddata/cards_paper/paper/T2_controls.dta", replace

