
**********************************************
**********************************************
* This do-file is a modification of leakages_and_targeting.do to genereate a new price_hh variable,
* We want to use price paid in the last month instead of average. 
/*	kg to L rice conversion: using .8 kg / L of rice */
**********************************************
**********************************************

clear all

set more off
set mem 250m
set matsize 800
pause off
set seed 5757
set sortseed 5757

cd "$RASKIN"

****************************
* 1. Input data
****************************

*load in data
u "1Data/codeddata/cards_paper/beneficiaries and randomization.dta", clear
ren hhea commid

*merge
merge m:1 commid using "1Data/originaldata/1_CS1/NewUpdate/k_cr.dta"
assert _m==3
drop _m
ren commid hhea

*merge
merge 1:1 hhid using "1Data/originaldata/1_CS1/NewUpdate/hh_c.dta"
count if _m!=3
assert `r(N)'<=1	// there was one case of an unfinished interview
keep if _m==3
drop _m

*merge
merge 1:m hhid using "1Data/originaldata/1_CS1/NewUpdate/hh_b2.dta"	// 4 lines per HH
count if _m!=3
assert `r(N)'<=4	// there was one case of an unfinished interview
keep if _m==3
drop _m

****************************
* 2. Coding outcomes
****************************

** generate month dummies

forv i=1/12{
gen FE`i' = (b22_mth==`i')
}

assert FE1 + FE2 + FE3 + FE4 + FE5 + FE6 + FE7 + FE8 + FE9 + FE10 + FE11 + FE12 == 1

**************************
*** Usable restriction
**************************

* regular restriction
g usable = 1 if (int_day>=25 | (type_b22>=2 & int_day<25)) & b22_mth>=10

g usable2 = 1 if (int_day==30 | (type_b22>=2)) & b22_mth>=10

**************************
*** Raskin Outcomes
**************************

replace b26 = . if b26 > 100	// no more than 100 kg.
replace b26 = b26*.8 if b26x==1
replace b26 = 0 if b25==0
replace b26 = . if b26 > 150 

* outcome 3a: price paid (according to HH) (keep temp to define month from last time)
*g copy = b27
replace b27 = b27 / b26 if b27x==1	// if it's a total price
replace b27 = b27*1.25 if b27x==2	// if it's a liter price
replace b27 = . if b27 < 500 | b27 >10000

bys hhid: egen price_hh = mean(b27) if usable==1
bys hhid: egen price_hh_diffusable = mean(b27) if usable2==1
la var price_hh "Raskin price since October (Rp/kg)"
la var price_hh_diffusable "Price of raskin (Rp/kg, pooled since oct) diffusable"
g price_hh_oct = b27 if b22_mth==10 & usable==1
la var price_hh_oct "Price of raskin (Rp/kg, oct)"
g price_hh_nov = b27 if b22_mth==11 & usable==1
la var price_hh_nov "Price of raskin (Rp/kg, nov)"

** Generate a different price_hh variable using last month's price 

*identify which month is the last month that are "usable" for each household and does not contain missing value  
bys hhid:egen last_usable=min(type_b22) if usable==1 & b27!=.  //type_b22==1 is the last month for each hh 
bys hhid:egen last_usablemonth=mean(last_usable)  
drop last_usable

*get the price for the last month 
gen price_last=b27 if type_b22==last_usablemonth
bys hhid: egen price_hh_last=max(price_last)
drop price_last
la var price_hh_last "Raskin price for the last month (Rp/kg)"

*keep reelvant variables
keep price_hh_last price_hh hhid

******************
**   COLLAPSE   ** 
******************

collapse(mean) price_hh_last price_hh, by (hhid)

*create mark up hh variables 
gen markup_hh		= price_hh - 1600
replace markup_hh 	= 0 if markup_hh < 0
gen markup_hh_last		= price_hh_last - 1600
replace markup_hh_last 	= 0 if markup_hh_last < 0

*rena,e
ren markup_hh      markup_hh_baseline
ren price_hh       price_hh_baseline 
ren markup_hh_last markup_hh_last_baseline
ren price_hh_last  price_hh_last_baseline 

******************
**   SAVE   ** 
******************

saveold  "1Data/codeddata/competition/price_lastmonth_baseline.dta", replace

