**********************************************
**********************************************
* Leakages and targeting
/*	kg to L rice conversion: using .8 kg / L of rice */
**********************************************
**********************************************

clear all

set more off
set mem 250m
set matsize 800
pause off
set seed 5757
set sortseed 5757

cd "$RASKIN"

****************************
* 1. Input data
****************************

u "1Data/codeddata/cards_paper/beneficiaries and randomization.dta", clear
ren hhea commid
merge m:1 commid using "1Data/originaldata/1_CS1/NewUpdate/k_cr.dta"
assert _m==3
drop _m
ren commid hhea
merge 1:1 hhid using "1Data/originaldata/1_CS1/NewUpdate/hh_c.dta"
count if _m!=3
assert `r(N)'<=1	// there was one case of an unfinished interview
pause
keep if _m==3
drop _m
merge 1:m hhid using "1Data/originaldata/1_CS1/NewUpdate/hh_b2.dta"	// 4 lines per HH
count if _m!=3
assert `r(N)'<=4	// there was one case of an unfinished interview
pause
keep if _m==3
drop _m

****************************
* 2. Coding outcomes
****************************

** generate month dummies

forv i=1/12{
gen FE`i' = (b22_mth==`i')
}

assert FE1 + FE2 + FE3 + FE4 + FE5 + FE6 + FE7 + FE8 + FE9 + FE10 + FE11 + FE12 == 1

**************************
*** Usable restriction
**************************

* regular restriction
g usable = 1 if (int_day>=25 | (type_b22>=2 & int_day<25)) & b22_mth>=10

g usable2 = 1 if (int_day==30 | (type_b22>=2)) & b22_mth>=10

**************************
*** Raskin Outcomes
**************************

* outcome 1a: rice in last month. 
recode b25 (3 = 0) (8 = 0) (.=0)
assert b25==0 | b25==1
bys hhid: egen boughtrask = mean(b25) if usable==1
la var boughtrask "Raskin purchase since October"
g boughtrask_oct = b25 if b22_mth==10 & usable==1
la var boughtrask_oct "HH bought raskin (oct)"
g boughtrask_nov = b25 if b22_mth==11 & usable==1
la var boughtrask_nov "HH bought raskin (nov)"

* 6/30/14: Bought_s_oct with correct usability restriction
g bought_s_oct_1 = (boughtrask_oct==1 | boughtrask_nov==1)
bys hhid: egen bought_s_oct = max(bought_s_oct_1)
drop bought_s_oct_1
la var bought_s_oct "Bought raskin since October"

preserve
	keep hhid bought_s_oct
	duplicates drop
	isid hhid
	saveold "1Data/codeddata/cards_paper/bought_s.dta", replace
restore

* outcome 2: amount purchased
replace b26 = . if b26>99 // no more than 100 kg.
replace b26 = b26*.8 if b26x==1
replace b26 = 0 if b25==0
replace b26 = . if b26 > 150
bys hhid: egen amtraskin = mean(b26) if usable==1
bys hhid: egen amtraskin_diffusable = mean(b26) if usable2==1
la var amtraskin "Amount of raskin purchased per month since October (kg)"
la var amtraskin_diffusable "Amount of raskin (kg, pooled since oct) diffusable"
g amtraskin_oct = b26 if b22_mth==10 & usable==1
la var amtraskin_oct "Amount of raskin (kg, oct)"
g amtraskin_nov = b26 if b22_mth==11 & usable==1
la var amtraskin_nov "Amount of raskin (kg, nov)"

g amtraskin_aug = b26 if b22_mth==8
la var amtraskin_aug "Amount of raskin (kg, aug)"
g amtraskin_sept = b26 if b22_mth==9
la var amtraskin_sept "Amount of raskin (kg, sept)"

* amount was 15
g temp = amtraskin==15
bys hhid: egen amtis15 = max(temp)
la var amtis15 "HH bought exactly 15 kg at least once"
drop temp

* outcome 3a: price paid (according to HH) (keep temp to define month from last time)
*g copy = b27
replace b27 = b27 / b26 if b27x==1	// if it's a total price
replace b27 = b27*1.25 if b27x==2	// if it's a liter price
replace b27 = . if b27 < 500 | b27 >10000
pause

bys hhid: egen price_hh = mean(b27) if usable==1
bys hhid: egen price_hh_diffusable = mean(b27) if usable2==1
la var price_hh "Raskin price since October (Rp/kg)"
la var price_hh_diffusable "Price of raskin (Rp/kg, pooled since oct) diffusable"
g price_hh_oct = b27 if b22_mth==10 & usable==1
la var price_hh_oct "Price of raskin (Rp/kg, oct)"
g price_hh_nov = b27 if b22_mth==11 & usable==1
la var price_hh_nov "Price of raskin (Rp/kg, nov)"

ta price_hh

* outcome 3b: price paid (according to leader)
ta cr05

g price_ldr = cr05 if cr05x==1
replace price_ldr = cr05*1.25 if cr05x==2

la var price_ldr "Price of purchased raskin (Rp. / kg) according to leader"
ta price_ldr

replace b23 = 0 if b23==3 | b23==6
replace b23 = . if b23==8
assert inlist(b23,0,1) if b23!=.
bys hhid: egen rask_dist = mean(b23) if usable==1
bys hhid: egen rask_dist_diffusable = mean(b23) if usable2==1
la var rask_dist "Raskin was distributed in month (pooled since oct)"
g rask_dist_oct = b23 if b22_mth==10 & usable==1
la var rask_dist_oct "Raskin was distributed (october)"
g rask_dist_nov = b23 if b22_mth==11 & usable==1
la var rask_dist_nov "Raskin was distributed (november)"

* prep for outcomes 4a and 4b:
gen qty_nonrask = c03 if c03x == 1
replace qty_nonrask = c03 * 0.8 if c03x == 2
replace qty_nonrask = 0 if c03x == 3
replace qty_nonrask = . if qty_nonrask > 35 | qty_nonrask < 0 // absurd values.
la var qty_nonrask "Quantity (kg) of non-Raskin rice in last month"

replace c04 = c04 * 1.25 if c04x == 2
gen price_nonrask = c04
replace price_nonrask = . if price_nonrask < 500 | price_nonrask > 10000 // absurd values.
la var price_nonrask "Price (Rp/kg) of non-Raskin rice in last month"

egen marketprice = mean(c04)
preserve
	collapse marketprice kab_marketprice = c04, by(kab_id)
	la var kab_marketprice "Market price of rice (avg in district)"
	la var marketprice "Market price of rice (avg overall)"
	saveold "1Data/codeddata/cards_paper/marketprices.dta", replace
restore

bys hhea: egen raskprice = mean(b27)
replace b27 = raskprice if b27==. & b26!=0 & b26!=.
drop raskprice
la var marketprice "Market price of rice"
g sub = ((marketprice-b27)*b26)
replace sub = 0 if b26==0


* outcome 4b: subsidy received (rp)
bys hhid: egen subsidy_rcvd = mean(sub) if usable==1
bys hhid: egen subsidy_rcvd_diffusable = mean(sub) if usable2==1
la var subsidy_rcvd_diffusable "Subsidy received (Rp, pooled since oct) diff usable"
la var subsidy_rcvd "Subsidy received (Rp, pooled since oct)"
g subsidy_rcvd_oct = sub if b22_mth==10 & usable==1
la var subsidy_rcvd_oct "Subsidy received (Rp, oct)"
g subsidy_rcvd_nov = sub if b22_mth==11 & usable==1
la var subsidy_rcvd_nov "Subsidy received (Rp, nov)"

drop sub usable* cr01_mth-b27
drop marketprice

****************************
* 3. Collapse
****************************

foreach v of varlist boughtrask-subsidy_rcvd_nov {
local a : var label `v'
ren `v' a`v'
bys hhid: egen `v' = max(a`v')
bys hhid: egen `v'2 = min(a`v')
assert `v'2==`v'
drop a`v' `v'2
la var `v' "`a'"
}

preserve
	keep hhid FE1 - FE12
	collapse (sum) FE1-FE12 , by(hhid)
		forv i=1/12{
			count if FE`i'>1
			assert `r(N)'<=1
			replace FE`i'=1 if FE`i'>1
		}
	tempfile fes
	sa `fes'
restore

drop FE1-FE12

duplicates drop

merge 1:1 hhid using `fes'
assert _m==3
drop _m

****************************
* 4. Village level variable
****************************

**price variance
g price_variance = .
g price_range = .
levelsof hhea
foreach h in `r(levels)' {
	sum price_hh if hhea=="`h'"
	if `r(N)' > 0 replace price_variance = `r(sd)' if hhea=="`h'"
	if `r(N)' > 0 replace price_range = `r(max)' - `r(min)' if hhea=="`h'"
	}
la var price_var "SD of price in village"
la var price_range "Max - min of price in village"

****************************
* 5. Save
****************************

isid hhid
saveold "1Data/codeddata/cards_paper/leakagestargeting.dta", replace

