**********************************************
**********************************************
* Satisfaction variables
**********************************************
**********************************************

clear all

set more off
set mem 250m
set matsize 800
pause off
set seed 5757
set sortseed 5757

cd "$RASKIN"

****************************
* 1. Input data
****************************

u "1Data/codeddata/cards_paper/beneficiaries and randomization.dta", clear
merge 1:1 hhid using "1Data/originaldata/1_CS1/NewUpdate/hh_f.dta"
count if _m!=3
assert `r(N)'<=1	// there was one case of an unfinished interview
pause
keep if _m==3
drop _m
ren hhea commid
merge m:1 commid using "1Data/originaldata/1_CS1/NewUpdate/k_rc.dta"
assert _m==3
drop _m

****************************
* 2. Code variables
****************************

* outcome 1a: complaints (HH)
g complaints_hh = f10a_num if f10a==1 & f10a_num < 995
replace complaints_hh = 0 if f10a==3
tab complaints
sum complaints_hh, d
replace complaints_hh = `r(p99)' if complaints_hh > `r(p99)' & complaints_hh < .
tab complaints
la var complaints_hh "# of complaints according to HH"

* outcome 1b: complaints (leader)
g complaints_ldr = 0 if rc02a==3
replace complaints_ldr = rc02a_num if rc02a==1 & rc02a_num < 995
tab complaints_l
sum complaints_ldr, d
replace complaints_ldr = `r(p99)' if complaints_ldr > `r(p99)' & complaints_ldr < .
tab complaints_l
la var complaints_ldr "# of complaints according to ldr"

* outcome 2a: protests (hh)
g protests_hh = 0 if f10b==3
replace protests_hh = 1 if f10b==1 & f10b_num < 995
la var protests_hh "# of protests according to HH"

* outcome 2b: protests (leader)
g protests_ldr = 0 if rc02b==3
replace protests_ldr = 1 if rc02b==1 & rc02b_num < 995
la var protests_ldr "# of protests according to leader"

* outcome 3a: fighting (hh)
g fighting_hh = 0 if f10c==3
replace fighting_hh = 1 if f10c==1 & f10c_num < 995
la var fighting_hh "# of fights according to HH"

* outcome 3b: fighting (leader)
g fighting_ldr = 0 if rc02c==3
replace fighting_ldr = 1 if rc02c==1 & rc02c_num < 995
la var fighting_ldr "# of fights according to leader"

* outcome 4a: demonstrations (hh)
g demonstrate_hh = 0 if f10d==3
replace demonstrate_hh = 1 if f10d==1 & f10d_num < 995
la var demonstrate_hh "# of demonstrations according to HH"

* outcome 4b: demonstrations (leader)
g demonstrate_ldr = 0 if rc02d==3
replace demonstrate_ldr = 1 if rc02d==1 & rc02d_num < 995
la var demonstrate_ldr "# of demonstrations according to ldr"

* pooled (hh)
g demoprotfight_hh = protests_hh + fighting_hh + demonstrate_hh > 0
la var demoprotfight_hh "Demonstrations, protests, or fighting according to HH"

* pooled (ldr)
g demoprotfight_ldr = protests_ldr + fighting_ldr + demonstrate_ldr > 0
la var demoprotfight_ldr "Demonstrations, protests, or fighting according to ldr"

* outcome 5a: overall satisfaction -- scaled 0-1, 1 being positive
g satis_hh = ((4-f01a)/3) if inrange(f01a,1,4)
la var satis_hh "Overall satisfaction according to household"

* outcome 5b: overall satisfaction -- scaled 0-1, 1 being positive
g satis_ldr = ((rc01-1)/3) if inrange(rc01,1,4)
la var satis_ldr "Overall satisfaction according to village leader"

* outcome 6: satisfaction with beneficiary list -- scaled 0-1, 1 being positive
g satis_list_hh = ((4-f09)/3) if inrange(f09,1,4)
la var satis_list_hh "HH satisfaction with beneficiary list, scaled 0-1"

****************************
* 3. Drop variables and save
****************************

drop f01a-rc04
saveold "1Data/codeddata/cards_paper/satisfaction.dta", replace

