**********************************************
**********************************************
* Socialization variables
**********************************************
**********************************************

clear all

set more off
set mem 250m
set matsize 800
pause off
set seed 5757
set sortseed 5757

cd "$RASKIN"

****************************
* 1. Input data
****************************

u "1Data/codeddata/cards_paper/beneficiaries and randomization.dta", clear
ren hhea commid
merge m:1 commid using "1Data/originaldata/1_CS1/NewUpdate/k_sr.dta"
assert _m==3
drop _m
ren commid hhea
renpfix sr ksr
merge 1:1 hhid using "1Data/originaldata/1_CS1/NewUpdate/hh_sr.dta"
count if _m!=3
assert `r(N)'<=1	// there was one case of an unfinished interview
keep if _m==3
drop _m
renpfix sr hhsr

****************************
* 2. Coding other variables
****************************

* outcome 1: was raskin socialized in the last 3 months
g rasksocialized_ldr = 1 if ksr02==1
replace rasksocialized_ldr = 0 if ksr02==3
la var rasksocialized_ldr "Raskin socialized in last 3 months (ldr)"

* outcome 2a: HH saw raskin poster (don't know = no)
g raskposter = hhsr01==1
la var raskposter "HH reports seeing raskin poster in last 3 months; don't know = no"
tab hhsr01

* outcome 2b: HH heard raskin announcement (don't know = no)
g raskannounce = hhsr03==1
la var raskannounce "HH heard rask announce in last 3 mths; don't know = no"

* outcome 2c: raskin meeting (don't know = no)
g raskmeeting = hhsr09==1
la var raskmeeting "HH went to raskin meeting; don't know = no"

* outcome 2d: HH has seen the list (don't know = no)
g rasklist = hhsr05 == 1
la var rasklist "HH has seen list; don't know = no"
* outcome 2d: HH has seen the list (don't know = drop)
g rasklist_d = rasklist
replace rasklist_d = . if hhsr05==8
la var  rasklist_d "HH has seen list; don't know = drop"

* outcome 3: any socialization
g rasksocialized_hh = (raskposter==1) | (raskannounce==1)
g rasksocialized_hh2 = (rasksocialized_hh==1) | (raskmeeting==1)
la var rasksocialized_hh "HH has seen poster or heard announcement"
la var rasksocialized_hh2 "HH has seen poster, heard annc., or been to mtg."

* outcome 5a: know raskin status
g knowstatus = 1 if (hhsr06==1 & (inrange(type,1,2))) | (hhsr06==3 & type==3)
replace knowstatus = 0 if knowstatus==. & hhsr06!= 9
la var knowstatus "Household correctly identifies beneficiary status; don't know = no"

* outcome 5a: know raskin status, don't know = drop
g knowstatus_d = knowstatus
replace knowstatus_d = . if hhsr06 == 8
la var knowstatus "Household correctly identifies beneficiary status; don't know = drop"

* outcome 7a/b: HH knows correct status of other households
preserve
	u "1Data/originaldata/1_CS1/NewUpdate/hh_sw4.dta", clear
	g temp = substr(hhid,1,3)
	replace sw03_hhid = temp+sw03_hhid
	drop temp
	tempfile sw4
	sa `sw4'
	u "1Data/codeddata/cards_paper/crosswalk_SW.dta", clear
	keep hhid type
	ren hhid sw03_hhid
	merge 1:m sw03_hhid using `sw4'
	pause	// we expect to have few _m==1 (we asked no HHs about a given interviewed HH) and maybe a few of _m==2 (the mentioned non-interviewed HHs).
	keep if _m==3
	drop _m
	g dkstatusoth = sw03==8		
	replace sw03 = 1 if sw03==2
	replace sw03 = 3 if sw03==4
	replace sw03 = 0 if sw03==3
	replace sw03 = . if sw03==8	
	g status = 0 if type==3
	replace status = 1 if type==1 | type==2
	g knowstatusothr = sw03==status
	g knowstatusothr_b = (sw03==status) if status==1
	collapse (mean) knowstatusothr dkstatusoth knowstatusothr_b, by(hhid)
	tempfile knowstatus
	sa `knowstatus'
restore
merge 1:1 hhid using `knowstatus'
count if _m!=3
assert `r(N)'<=1	// there was one case of an unfinished interview
pause
keep if _m==3
drop _m
la var knowstatusothr "% of HHs whose raskin status HH correctly IDs"
la var dkstatusoth "% of HHs whose raskin status HH does not know"
la var knowstatusothr_b "% of true bens. whose raskin status HH correctly IDs"

* outcomes: common knowledge of list
la define commonknow 0 "None" 1 "Few" 2 "Some" 3 "Majority"
forv x = 1/2 {
	local a : word `x' of k hh
	local b : word `x' of ldr hh
	local f : word `x' of leader household
		forv y = 1/4 {
		local c : word `y' of official leader ben nonben
		local d : word `y' of a c e g
		local e : word `y' of b d f h
		local g : word `y' of Official Leader Beneficiary Non-beneficiary

		g `c'_see_`b' = `a'sr07`e' if inrange(`a'sr07`d',1,2) & inrange(`a'sr07`e',1,4)
		replace `c'_see_`b' = 4 if `a'sr07`d'==3
		replace `c'_see_`b' = 4-`c'_see_`b'
		la values `c'_see_`b' commonknow
		la var `c'_see_`b' "`g' has seen list according to `f' (scaled 0-3); DK = drop"

		* Don't know as "has not seen the list"
		g  		`c'_see_`b'_d = `c'_see_`b'
		replace `c'_see_`b'_d = 0 if `a'sr07`d'==8
		la var 	`c'_see_`b'_d "`g' has seen list according to `f' (scaled 0-3); DK = 0"

		* Don't know as "has not seen the list"
		g  		`c'_see_`b'_dd = `c'_see_`b'
		replace `c'_see_`b'_dd = 0 if `a'sr07`d'==8 | `a'sr07`e'==8
		la var 	`c'_see_`b'_dd "`g' has seen list according to `f' (scaled 0-3); DK = 0 both qs"
	}
}

****************************
* 3. Drop variables and save
****************************

drop ksr* hhsr*
saveold "1Data/codeddata/cards_paper/socialization.dta", replace

