**********************************************
**********************************************
* This do-file is a modification of leakages_and_targeting_mid.do to genereate a new price_hh variable,
* We want to use price paid in the last month instead of average. 
/*	kg to L rice conversion: using .8 kg / L of rice */
**********************************************
**********************************************

clear all

set more off
set mem 250m
set matsize 800
pause off
set seed 5757
set sortseed 5757

cd "$RASKIN"

****************************
* 1. Input data
****************************

u "1Data/codeddata/cards_paper/midline/beneficiaries_and_randomization_mid.dta", clear
ren hhea commid
merge m:1 commid using "1Data/originaldata/2_Midline/k_cr.dta"
assert _m==3
drop _m

ren commid hhea
merge 1:1 hhid using "1Data/originaldata/2_Midline/hh_c.dta"
assert _m==3
drop _m 

merge 1:m hhid using "1Data/originaldata/2_Midline/hh_b2.dta"	// 4 lines per HH
assert _m==3
drop _m

****************************
* 2. Coding outcomes
****************************

** generate month dummies

forv i=1/12{
gen FE`i' = (b22_mth==`i')
}

assert FE1 + FE2 + FE3 + FE4 + FE5 + FE6 + FE7 + FE8 + FE9 + FE10 + FE11 + FE12 == 1

**************************
*** Usable restriction
**************************

* regular restriction
g usable = 1 if (int_day >= 25 | (type_b22 >= 2 & int_day < 25))

g usable2 = 1 if (int_day == 30 | int_day == 31 | type_b22 >= 2) // different definition of usable (diff-usable ;-) 


**************************
*** Raskin Outcomes
**************************

* outcome 2: amount purchased
replace b26 = . if b26 == 9995
assert b26 < 100 | b26==.	
* convert Liters to Kg
replace b26 = b26 * 0.8 if b26x == 1 
replace b26 = 0 if b25 == 0

* outcome 3a: price paid (according to HH) (keep temp to define month from last time)
replace b27 = b27 / b26 if b27x == 1	// if it's a total price
replace b27 = b27 * 1.25 if b27x == 2	// if it's a liter price

replace b27 = . if b27 < 500 | b27 >10000

bys hhid: egen price_hh = mean(b27) if usable == 1
bys hhid: egen price_hh_diffusable = mean(b27) if usable2 == 1
la var price_hh "Raskin price since January (Rp/kg)"
la var price_hh_diffusable "Raskin price since January (Rp/kg) diffusable"

// changed the months from October and November to January February, March and April (relevant for the midline)
g price_hh_jan = b27 if b22_mth==1 & usable==1
la var price_hh_jan "Price of raskin (Rp/kg, jan)"
g price_hh_feb = b27 if b22_mth==2 & usable==1
la var price_hh_feb "Price of raskin (Rp/kg, feb)"
g price_hh_mar = b27 if b22_mth==3 & usable==1
la var price_hh_mar "Price of raskin (Rp/kg, mar)"
g price_hh_apr = b27 if b22_mth==4 & usable==1
la var price_hh_apr "Price of raskin (Rp/kg, apr)"

** Generate a different price_hh variable using last month's price 

*identify which month is the last month that are "usable" for each household and does not contain missing value  
bys hhid:egen last_usable=min(type_b22) if usable==1 & b27!=.  //type_b22==1 is the last month for each hh 
bys hhid:egen last_usablemonth=mean(last_usable)  
drop last_usable

*get the price for the last month 
gen price_last=b27 if type_b22==last_usablemonth
bys hhid: egen price_hh_last=max(price_last)
drop price_last
la var price_hh_last "Raskin price for the last month (Rp/kg)"

*keep relevant variables
keep price_hh_last price_hh hhid

******************
**   COLLAPSE   ** 
******************

collapse(mean) price_hh_last price_hh, by (hhid)

*create mark up hh variables using price_hh_last 
gen markup_hh		= price_hh - 1600
replace markup_hh 	= 0 if markup_hh < 0

gen markup_hh_last		= price_hh_last - 1600
replace markup_hh_last 	= 0 if markup_hh_last < 0

ren markup_hh      markup_hh_midline
ren price_hh       price_hh_midline 
ren markup_hh_last markup_hh_last_midline
ren price_hh_last  price_hh_last_midline 

******************
**   SAVE   ** 
******************

saveold  "1Data/codeddata/competition/price_lastmonth_midline.dta", replace


