**********************************************
**********************************************
* Leakages and targeting
/*	kg to L rice conversion: using .8 kg / L of rice */
**********************************************
**********************************************

clear all

set more off
set mem 250m
set matsize 800
pause off
set seed 5757
set sortseed 5757

cd "$RASKIN"

****************************
* 1. Input data
****************************

u "1Data/codeddata/cards_paper/midline/beneficiaries_and_randomization_mid.dta", clear
ren hhea commid
merge m:1 commid using "1Data/originaldata/2_Midline/k_cr.dta"
assert _m==3
drop _m

ren commid hhea
merge 1:1 hhid using "1Data/originaldata/2_Midline/hh_c.dta"
assert _m==3
drop _m 

merge 1:m hhid using "1Data/originaldata/2_Midline/hh_b2.dta"	// 4 lines per HH
assert _m==3
drop _m

****************************
* 2. Coding outcomes
****************************

** generate month dummies

forv i=1/12{
gen FE`i' = (b22_mth==`i')
}
*make sure only one month per observation
assert FE1 + FE2 + FE3 + FE4 + FE5 + FE6 + FE7 + FE8 + FE9 + FE10 + FE11 + FE12 == 1

**************************
*** Usable restriction
**************************

* regular restriction
g usable = 1 if (int_day >= 25 | (type_b22 >= 2 & int_day < 25))
g usable2 = 1 if (int_day == 30 | int_day == 31 | type_b22 >= 2) // different definition of usable 

**************************
*** Raskin Outcomes
**************************

* outcome 1a: rice in last month. 
recode b25 (3 = 0) (8 = 0) (. = 0)
assert b25 == 0 | b25 == 1
bys hhid: egen boughtrask = mean(b25) if usable == 1
la var boughtrask "Raskin purchase since January"

// changed the months from October and November to January, February, March and April (relevant for the midline)
// In theory there should be a single "max" for one household, but this fails because of an error in b22_mth
g temp = b25 if b22_mth == 1 & usable == 1
bys hhid: egen boughtrask_jan = max(temp)
	bys hhid: egen temp2 = min(temp)   
	count if temp2!=boughtrask_jan
	assert `r(N)'<=0   
drop temp temp2
la var boughtrask_jan "HH bought raskin (jan)"

g temp = b25 if b22_mth == 2 & usable == 1
bys hhid: egen boughtrask_feb = max(temp)
	bys hhid: egen temp2 = min(temp)   
	count if temp2!=boughtrask_feb
	assert `r(N)'<=8   // 8 cases where b22_mth has an error (b/c two consecutive months are equal)
drop temp temp2
la var boughtrask_feb "HH bought raskin (feb)"

g temp = b25 if b22_mth == 3 & usable == 1
bys hhid: egen boughtrask_mar = max(temp)
	bys hhid: egen temp2 = min(temp)   
	count if temp2!=boughtrask_mar
	assert `r(N)'<=0 
drop temp temp2
la var boughtrask_mar "HH bought raskin (mar)"

g temp = b25 if b22_mth == 4 & usable == 1
bys hhid: egen boughtrask_apr = max(temp)
	bys hhid: egen temp2 = min(temp)   
	count if temp2!=boughtrask_apr
	assert `r(N)'<=4   
	drop temp temp2
la var boughtrask_apr "HH bought raskin (apr)"

* 6/30/14: Bought_s_jan/march with correct usability restriction
g bought_s_jan1 = (boughtrask_jan==1 | boughtrask_feb==1 | boughtrask_mar==1 | boughtrask_apr==1)
bys hhid: egen bought_s_jan = max(bought_s_jan1)
drop bought_s_jan1
la var bought_s_jan "Bought raskin since January"

g bought_s_mar1 = (boughtrask_mar==1 | boughtrask_apr==1)
bys hhid: egen bought_s_mar = max(bought_s_mar1)
drop bought_s_mar1
la var bought_s_mar "Bought raskin since March"

preserve
	keep hhid bought_s_jan bought_s_mar
	duplicates drop
	isid hhid
	saveold "1Data/codeddata/cards_paper/midline/bought_s.dta", replace
restore

* outcome 2: amount purchased
replace b26 = . if b26 == 9995
assert b26 < 100 | b26==.	
* convert Liters to Kg
replace b26 = b26 * 0.8 if b26x == 1 
replace b26 = 0 if b25 == 0

bys hhid: egen amtraskin = mean(b26) if usable==1
bys hhid: egen amtraskin_diffusable = mean(b26) if usable2==1   
la var amtraskin "Amount of raskin purchased per month since January (kg)"
la var amtraskin_diffusable "Amount of raskin purchased per month since Jan (kg) diffusable"

// changed the months from October and November to January, February, March and April (relevant for the midline)
g temp = b26 if b22_mth==1 & usable==1
bys hhid: egen amtraskin_jan= max(temp)
	bys hhid: egen temp2= min(temp)
	assert temp2==amtraskin_jan 
drop temp temp2
la var amtraskin_jan "Amount of raskin (kg, jan)"

g temp = b26 if b22_mth==2 & usable==1
bys hhid: egen amtraskin_feb= max(temp)
	bys hhid: egen temp2= min(temp)
	count if temp2!=amtraskin_feb 
	assert `r(N)'<=8   // this fails because on ~20 occasions b22_mth has an error (e.g. two consecutive months are =)
drop temp temp2
la var amtraskin_feb "Amount of raskin (kg, feb)"

g temp = b26 if b22_mth==3 & usable==1
bys hhid: egen amtraskin_mar = max(temp)
	bys hhid: egen temp2= min(temp)
	count if temp2!=amtraskin_mar 
	assert `r(N)'<=0 
drop temp temp2
la var amtraskin_mar "Amount of raskin (kg, mar)"

g temp = b26 if b22_mth==4 & usable==1
bys hhid: egen amtraskin_apr = max(temp)
	bys hhid: egen temp2= min(temp)
	count if temp2!=amtraskin_apr 
	assert `r(N)'<=4
drop temp temp2
la var amtraskin_apr "Amount of raskin (kg, apr)"

* amount was 15
g temp = amtraskin == 15
bys hhid: egen amtis15 = max(temp)
la var amtis15 "HH bought exactly 15 kg at least once"
drop temp

* outcome 3a: price paid (according to HH) (keep temp to define month from last time)
replace b27 = b27 / b26 if b27x == 1	// if it's a total price
replace b27 = b27 * 1.25 if b27x == 2	// if it's a liter price
replace b27 = . if b27 < 500 | b27 >10000

bys hhid: egen price_hh = mean(b27) if usable == 1
bys hhid: egen price_hh_diffusable = mean(b27) if usable2 == 1
la var price_hh "Raskin price since January (Rp/kg)"
la var price_hh_diffusable "Raskin price since January (Rp/kg) diffusable"

// changed the months from October and November to January February, March and April (relevant for the midline)
g price_hh_jan = b27 if b22_mth==1 & usable==1
la var price_hh_jan "Price of raskin (Rp/kg, jan)"
g price_hh_feb = b27 if b22_mth==2 & usable==1
la var price_hh_feb "Price of raskin (Rp/kg, feb)"
g price_hh_mar = b27 if b22_mth==3 & usable==1
la var price_hh_mar "Price of raskin (Rp/kg, mar)"
g price_hh_apr = b27 if b22_mth==4 & usable==1
la var price_hh_apr "Price of raskin (Rp/kg, apr)"

* prep for outcomes 4a and 4b:
gen qty_nonrask = c03 if c03x == 1
replace qty_nonrask = c03 * 0.8 if c03x == 2
replace qty_nonrask = 0 if c03x == 3
replace qty_nonrask = . if qty_nonrask > 35 | qty_nonrask < 0
la var qty_nonrask "Quantity (kg) of non-Raskin rice in last month"

replace c04 = c04 * 1.25 if c04x == 2
assert c04 < 20000 | c04==.
gen price_nonrask = c04
replace price_nonrask = . if price_nonrask < 500 | price_nonrask > 10000
la var price_nonrask "Price (Rp/kg) of non-Raskin rice in last month"

* marketprice for rice of similar quality
sum c04 if c05==2
local mprice = `r(mean)'
gen marketprice = `r(mean)'

preserve
	gen c04_v2 = c04 if c05 == 2
	collapse kab_marketprice = c04_v2, by(kab_id)
	la var kab_marketprice "Market price of rice (avg in district)"
	gen marketprice = `mprice'
	la var marketprice "Market price of rice (avg overall)"
	saveold "1Data/codeddata/cards_paper/midline/marketprices_mid.dta", replace
restore

bys hhea: egen raskprice = mean(b27)

replace b27 = raskprice if b27 == . & b26 != 0 & b26 != .   

drop raskprice
la var marketprice "Market price of rice"
g sub = ((marketprice - b27) * b26)

replace sub = 0 if b26 == 0

* outcome 4b: subsidy received (rp)
bys hhid: egen subsidy_rcvd = mean(sub) if usable == 1
bys hhid: egen subsidy_rcvd_diffusable = mean(sub) if usable2 == 1
la var subsidy_rcvd "Subsidy received (Rp./month avg since Jan)"
la var subsidy_rcvd_diffusable "Subsidy received (Rp./month avg since Jan) diff usable"

// changed the months from October and November to February, March and April (relevant for the midline)
g temp = sub if b22_mth == 1 & usable == 1
bys hhid: egen subsidy_rcvd_jan = max(temp)
	bys hhid: egen temp2= min(temp)
	assert temp2==subsidy_rcvd_jan 
drop temp temp2
la var subsidy_rcvd_jan "Subsidy received (Rp. Jan)"

g temp = sub if b22_mth == 2 & usable == 1
bys hhid: egen subsidy_rcvd_feb = max(temp)
	bys hhid: egen temp2= min(temp)
	count if temp2!=subsidy_rcvd_feb 
	assert `r(N)'<=8 // this fails because on ~20 occasions b22_mth has an error (e.g. two consecutive months are =)
drop temp temp2
la var subsidy_rcvd_feb "Subsidy received (Rp. Feb)"

g temp = sub if b22_mth == 3 & usable == 1
bys hhid: egen subsidy_rcvd_mar = max(temp)
	bys hhid: egen temp2= min(temp)
	count if temp2!=subsidy_rcvd_mar 
	assert `r(N)'<=0
drop temp temp2
la var subsidy_rcvd_mar "Subsidy received (Rp. Mar)"

g temp = sub if b22_mth == 4 & usable == 1
bys hhid: egen subsidy_rcvd_apr = max(temp)
	bys hhid: egen temp2= min(temp)
	count if temp2!=subsidy_rcvd_apr
	assert `r(N)'<=4
drop temp temp2
la var subsidy_rcvd_apr "Subsidy received (Rp. Apr)"

drop sub usable* cr01_mth-b27
drop marketprice

****************************
* 3. Collapse
****************************

foreach v of varlist boughtrask-subsidy_rcvd_apr {
	local a : var label `v'
	ren `v' a`v'
	bys hhid: egen `v' = max(a`v')
	bys hhid: egen `v'2 = min(a`v')
	assert `v'2==`v'
	drop a`v' `v'2
	la var `v' "`a'"
}

preserve
	keep hhid FE1 - FE12
	collapse (sum) FE1-FE12 , by(hhid)
	forv i=1/12{
		count if FE`i'>1
		assert `r(N)'<=6
		replace FE`i'=1 if FE`i'>1
	}
	tempfile fes
	sa `fes'
restore

*drop some variables
drop FE1-FE12

*drop duplicates
duplicates drop

*merge
merge 1:1 hhid using `fes'
assert _m==3
drop _m

****************************
* 4. Village level variable
****************************

**price variance
g price_variance = .
g price_range = .
levelsof hhea
foreach h in `r(levels)' {
	sum price_hh if hhea=="`h'"
	if `r(N)' > 0 replace price_variance = `r(sd)' if hhea=="`h'"
	if `r(N)' > 0 replace price_range = `r(max)' - `r(min)' if hhea=="`h'"
}
la var price_var "SD of price in village"
la var price_range "Max - min of price in village"

****************************
* 5. Clean up and save
****************************

isid hhid
saveold "1Data/codeddata/cards_paper/midline/leakagestargeting_mid.dta", replace
