**********************************************
**********************************************
* Socialization variables
**********************************************
**********************************************

clear all

set more off
set mem 250m
set matsize 800
pause off
set seed 5757
set sortseed 5757

cd "$RASKIN"

****************************
* 1. Input data
****************************

u "1Data/codeddata/cards_paper/midline/beneficiaries_and_randomization_mid.dta", clear
ren hhea commid
merge m:1 commid using "1Data/originaldata/2_Midline/k_sr.dta"
assert _m==3
drop _m
ren commid hhea

renpfix sr ksr
merge 1:1 hhid using "1Data/originaldata/2_Midline/hh_sr.dta"
asser _m==3
drop _m
renpfix sr hhsr

****************************
* 2. Coding other variables
****************************

* outcome 1: was raskin socialized in the last 3 months
g rasksocialized_ldr = 1 if ksr02 == 1
replace rasksocialized_ldr = 0 if ksr02 == 3
la var rasksocialized_ldr "Raskin socialized in last 3 months (ldr)"

* outcome 2a: HH saw raskin poster (don't know = no)
g raskposter = hhsr01 == 1
la var raskposter "HH reports seeing raskin poster in last 3 months; don't know = no"

* outcome 2b: HH heard raskin announcement (don't know = no)
g raskannounce = hhsr03 == 1
la var raskannounce "HH heard rask announce in last 3 mths; don't know = no"

* outcome 2d: HH has seen the list (don't know = no)
g rasklist = hhsr05 == 1
la var rasklist "HH has seen list; don't know = no"

* outcome 2d: HH has seen the list (don't know = drop)
g rasklist_d = rasklist
replace rasklist_d = . if hhsr05==8
la var  rasklist_d "HH has seen list; don't know = drop"

* outcome 2c: raskin meeting (don't know = no)
/* looks like this variable doesn't appear in the midline survey. */

* outcome 3: any socialization
g rasksocialized_hh = (raskposter == 1) | (raskannounce == 1)
la var rasksocialized_hh "HH has seen poster or heard announcement"

* outcome 5a: know raskin status, don't know = no
g knowstatus = 1 if (hhsr06 == 1 & inrange(type,1,2)) ///
	| (hhsr06 == 3 & type == 3)
replace knowstatus = 0 if knowstatus==. & hhsr06!= 9
la var knowstatus "Household correctly identifies beneficiary status; don't know = no"

* outcome 5a: know raskin status, don't know = drop
g knowstatus_d = knowstatus
replace knowstatus_d = . if hhsr06 == 8
la var knowstatus_d "Household correctly identifies beneficiary status; don't know = drop"

* outcome 7a/b: HH knows correct status of other households 
* NOTE these variables are *dropped* and re-coded (using the complete SW crosswalk) in Paper/coding_extra_v3.do
preserve
	* get real types
	u "1Data/codeddata/cards_paper/midline/beneficiaries_and_randomization_mid.dta", clear
	keep hhid type jpal_id
	rename hhid sw03_hhid
	rename type realtype
	tempfile types
	sa `types'
	
	* get hhds that respondent doesn't know
	use "1Data/originaldata/2_Midline/hh_sw3.dta" 
	g temp = substr(hhid,1,3)
	replace sw02b_hhid = temp+sw02b_hhid
	drop temp
	rename sw02b_hhid sw03_hhid
	tempfile doesntknow
	save `doesntknow'
	
	* get respondent beliefs about Raskin status of other hhds
	u "1Data/originaldata/2_Midline/hh_sw4.dta", clear
	g temp = substr(hhid,1,3)
	replace sw03_hhid = temp+sw03_hhid
	drop temp
	
	/* we expect to have few _m==1 (we asked no HHs about a given 
	interviewed HH) and maybe a few of _m==2 (the mentioned 
	non-interviewed HHs). */
	
	* merge on both IDs (respondent, and target)
	merge 1:1 hhid sw03_hhid using `doesntknow'
	gen exclude=1 if _m==3
	keep if _m!=2
	drop _m
	
	merge m:1 sw03_hhid using `types'
	drop if jpal_id=="C2"
	keep if _m==3
	drop _m	
	
* generate vars using all matched real types
	g dkstatusoth = sw03==8		
	replace sw03 = 1 if sw03==2
	replace sw03 = 3 if sw03==4
	replace sw03 = 0 if sw03==3
	replace sw03 = . if sw03==8	
	assert sw03==0 | sw03==1 | sw03==.
	
	g status = 0 if realtype==3
	replace status = 1 if realtype==1 | realtype==2
	
	g knowstatusothr = sw03==status
	g knowstatusothr_b = (sw03==status) if status==1
	
	** generate vars counting doesn't know as knowstatusothr=0
	g knowstatusothr_d = knowstatusothr
	replace knowstatusothr_d = . if dkstatusoth==1
	g knowstatusothr_b_d =  knowstatusothr_b
	replace knowstatusothr_b_d = . if dkstatusoth==1
		
	collapse (mean) knowstatusothr knowstatusothr_d dkstatusoth ///
					knowstatusothr_b knowstatusothr_b_d, by(hhid)
					
	tempfile knowstatus
	sa `knowstatus'
restore

merge 1:1 hhid using `knowstatus'
count if _m != 3
assert `r(N)' <= 1
drop if _m == 2
drop _m

la var knowstatusothr "HH correctly IDs raskin status of other HHs (%)"
la var dkstatusoth "HH does not know raskin status of other HHs (%)"
la var knowstatusothr_b "HH correctly IDs raskin status of true bens. HHs (%)"

* outcomes: common knowledge of list
la define commonknow 0 "None" 1 "Few" 2 "Some" 3 "Most"
forv x = 1/2 {
	local a1 : word `x' of k hh
	local b1 : word `x' of ldr hh
	local f1 : word `x' of leader household
	forv y = 1/4 {
		local c1 : word `y' of official leader ben nonben
		local d1 : word `y' of a c e g
		local e1 : word `y' of b d f h
		local g1 : word `y' of Official Leader Beneficiary Non-beneficiary

		g `c1'_see_`b1' = `a1'sr07`e1' if inrange(`a1'sr07`d1',1,2) ///
			& inrange(`a1'sr07`e1',1,3)
		replace `c1'_see_`b1' = 4 if `a1'sr07`d1'==3
		replace `c1'_see_`b1' = 4-`c1'_see_`b1'
		la values `c1'_see_`b1' commonknow
		la var `c1'_see_`b1' "`g1' has seen list according to `f1' (scaled 0-3); DK = drop"
		
		* Don't know as "has not seen the list"
		g  		`c1'_see_`b1'_d = `c1'_see_`b1'
		replace `c1'_see_`b1'_d = 0 if `a1'sr07`d1'==8
		la var 	`c1'_see_`b1'_d "`g1' has seen list according to `f1' (scaled 0-3); DK = 0"
		
		* Don't know as "has not seen the list"
		g  		`c1'_see_`b1'_dd = `c1'_see_`b1'
		replace `c1'_see_`b1'_dd = 0 if `a1'sr07`d1'==8 | `a1'sr07`e1'==8
		la var 	`c1'_see_`b1'_dd "`g1' has seen list according to `f1' (scaled 0-3); DK = 0 both qs"

	}
}

****************************
* 3. Clean up and save
****************************

drop ksr* hhsr*
saveold "1Data/codeddata/cards_paper/midline/socialization_mid.dta", replace

