/*******************************************************************************
RASKIN ENDLINE SURVEY - BASIC CODING
*******************************************************************************/

** SETUP ***********************************************************************

clear all

set more off
set mem 250m
set matsize 800
pause off
set seed 6104691
set sortseed 6104691

cd "$RASKIN"

** INPUT BASELINE DATA *********************************************************

u "1Data/originaldata/TargetingIIData/Baseline/hh_ksr5.dta", clear
keep if ksr3type=="a"
replace ksr11_kg = ksr11_lt*.8 if ksr11_kg==.
replace ksr11_kg = 0 if ksr08==3
replace ksr11_kg = . if ksr11_kg > 100	// trimmed at 100
ren ksr11_kg amtraskin
g hhea = substr(hhid,1,3)
keep hhea amtraskin
la var amtraskin "Raskin purchased (in kg)"
tempfile baseline
sa `baseline'

** INPUT DATA ON # HHs / VILLAGE ***********************************************

u "1Data/originaldata/0_Listing/l_location_clean", clear
tempfile numhh
sa `numhh'

** UDB PREP ********************************************************************

u "1Data/originaldata/0_Listing/120828 randomization_raskin_master_all_clean", clear

** List of beneficiaries by bot10 status
preserve
	keep hhid skesj
	ren hhid hhid_udb
	tempfile udb
	sa `udb'
restore

** Kabupaten
preserve
	keep desa_id2 kab_id
	ren desa_id2 hhea
	duplicates drop
	tempfile kabname
	sa `kabname'
restore

** CREATE CROSSWALK_ENDLINE ****************************************************

u "1Data/originaldata/1_CS1/crosswalk_cs1.dta", clear
replace hhid = hhid + "A"
merge 1:1 hhid using "1Data/originaldata/3_Endline/hh_cov.dta"
keep if _m == 3
keep hhid hhid_udb
tempfile cs1_xw
sa `cs1_xw'

u "1Data/originaldata/2_Midline/crosswalk_midline.dta", clear
rename hhid_midline hhid
replace hhid = hhid + "B"
merge 1:1 hhid using "1Data/originaldata/3_Endline/hh_cov.dta"
keep if _m == 3
keep hhid hhid_udb
tempfile mid_xw
sa `mid_xw'

append using `cs1_xw'
saveold "1Data/originaldata/3_Endline/crosswalk_endline.dta", replace

** 4. COLLECT BASIC DATA *******************************************************

u "1Data/originaldata/3_Endline/hh_cov.dta", clear
keep if hhcov4 == 1	// drop those who didn't finish interview
keep hhid hhea* jpal_id hhivwdd_* hhivwmm_*  hhivwyy_*
ren hhivwdd_1 int_day
la var int_day "Day of interview"
ren hhivwmm_1 int_month
la var int_month "Month of interview"
ren hhivwyy_1 int_year
la var int_year "Year of interview"
ren hhea desa_id2

** Find end of interview; we'll use this later (notably in card_receipt_end.do)
foreach var in day month year{
	gen int_end_`var' = int_`var'
}
forv x = 1/3{
	local xx : word `x' of dd mm yy
	local var : word `x' of day month year
	di "`var'"
	forv y = 2/3{
		di "`y'"
		replace int_end_`var' = hhivw`xx'_`y' if ///
		  mdy(hhivwmm_`y',hhivwdd_`y',hhivwyy_`y') > ///
		  mdy(int_end_month,int_end_day,int_end_year) ///
		  & !mi(mdy(hhivwmm_`y',hhivwdd_`y',hhivwyy_`y'))
	}
}

assert inlist(jpal_id,"E1A","E1B","E2A","E2B","E3A","E3B")

merge m:1 desa_id2 using ///
  "1Data/originaldata/0_Randomization/120716 randomization results for new TR2"
  
assert _m != 1 
keep if _m == 3
drop _m
ren desa_id2 hhea

// note on strata: kec_id and t2treatment already loaded.
encode kec_id, generate(kecagroup)
gen t2trm1 = t2treatment == 1
gen t2trm2 = t2treatment == 2
gen t2trm3 = t2treatment == 3
assert t2trm1 + t2trm2 + t2trm3 == 1

** 5. RECODE BENEFICIARY STATUS ************************************************

/* Merge on hhid_udb, so we can then merge to the file which tells which
	type Sample A people are. */
	
preserve
	use "1Data/originaldata/1_CS1/crosswalk_cs1.dta", clear
	replace hhid = hhid + "A"
	tempfile A
	save `A'
	
	u "1Data/originaldata/2_Midline/crosswalk_midline.dta", clear
	ren hhid_midline hhid
	replace hhid = hhid + "B"
	append using `A'
	tempfile xw
	save `xw'
restore

merge 1:1 hhid using `xw'
assert _m != 1
keep if _m == 3
drop _m

* merge with udb to record everyone's PPLS status
merge m:1 hhid_udb using `udb'

* drop UDB not in the survey
drop if _m == 2

/* assert that everything in the master that has a hhid_udb matches to `udb' */
assert !(_m==1 & hhid_udb!="")
		
** Generate Type (1, 2, 3)
gen type = 1 if skesj == 1 
	// Bottom10: in UDB list and indicated as skesj
replace type = 2 if _m == 3 & skesj != 1
	// PPLS-other: if in UDB list but not indicated as skesj
replace type = 3 if type==.
	// Ineligible (non-PPLS): not in UDB list.
	
tab jpal_id type, m
// pause

la define type 1 "Bottom 10" 2 "Other Beneficiary" 3 "Non-Beneficiary"
la values type type
	
drop _m
tab type, g(t)

** Define the 6 subsamples on which we use weights to force balance 
	
gen sample = .
// Bottom 10
replace sample = 1 if jpal_id == "E1A"
replace sample = 2 if jpal_id == "E1B"
// Other Ben (PPLS-other)
replace sample = 3 if jpal_id == "E2A"	
replace sample = 4 if jpal_id == "E2B"
// Non-Ben
replace sample = 5 if jpal_id == "E3A"
replace sample = 6 if jpal_id == "E3B"

assert sample != .

la define sample_end 		///
	1 "UDB-B10	CS1    " 		///
	2 "UDB-B10	Midline"	///
	3 "UDB-Other	CS1    " 		///
	4 "UDB-Other	Midline" 	///	
	5 "Non-UDB	CS1    " 		///
	6 "Non-UDB	Midline" 
la values sample sample_end


** CODING TREATMENTS ***********************************************************

g ALL = TR1 == 2
g CTL = TR1 == 1
g B10 = TR1 == 3
g PRC = TR1a == 0
g NOP = TR1a == 1
g CPN = TR1b == 0
g NOC = TR1b == 1
g STD = TR1c == 0
g ENH = TR1c == 1
g treatment = B10 + ALL
assert treatment + CTL == 1
g treated = 1 if (type == 1) | (type == 2 & inlist(TR1,1,2))
replace treated = 0 if type== 3
	/*  this variable (which should have been called "eligible") is always 1 for
		hh's that are in the bottom decile, and is also 1 for PPLS-other hh's 
		that are in villages assigned to Control or All treatment (not Bottom
		10 treatment).  The variable is also always 0 for Non-Bens.  It is
		missing for PPLS-other hh's in villages assigned to the B10 treatment. */
		
g type2a = 1 if type == 1
g type2b = 1 if treated == 1 & type == 2
g type2c = 1 if treated == . | (type == 2 & CTL == 1)

** SUNDRY FIXES ****************************************************************

** Kabupaten names
merge m:1 hhea using `kabname'
assert _m!=1
keep if _m==3
drop _m

** Source
gen source = "cs1" if regexm(hhid,"A")
replace source = "mid" if regexm(hhid,"B")
assert source != ""
gen mid = source == "mid"
gen cs1 = source == "cs1"


** Clean up and save ***********************************************************
********************************************************************************

keep hhid hhea* jpal_id kab_id type t* TR1* ///
	kecagroup t2treatment t2trm*  ALL CTL B10 PRC NOP NOC CPN STD ENH treatment ///
	treated kec_id sample int_* source cs1 mid

saveold "1Data/codeddata/cards_paper/endline/beneficiaries_and_randomization_end", replace

