/*******************************************************************************
RASKIN ENDLINE SURVEY - CARD RECEIPT
*******************************************************************************/

** SETUP ***********************************************************************

clear all

set more off
pause off
set seed 6104691
set sortseed 6104691

cd "$RASKIN"

** INPUT DATA ******************************************************************

u "1Data/codeddata/cards_paper/endline/beneficiaries_and_randomization_end.dta", clear
merge 1:1 hhid using "1Data/originaldata/3_Endline/hh_rc.dta"
assert _m==3
drop _m

merge 1:1 hhid using "1Data/originaldata/3_Endline/hh_b1.dta"
assert _m==3
drop _m

merge 1:1 hhid using "1Data/codeddata/cards_paper/endline/bought_s.dta"
assert _m==3
drop _m

************************************
*********** 2. Coding
************************************

* outcome 1a: got card
g gotcard = (rc01==1)
la var gotcard "Raskin card receipt"

* outcome 1b: got card and is green
g gotcard_gr = ((gotcard==1) & ((rc03a==3)|(rc03a==4)))
la var gotcard_gr "Receipt of blue/green raskin card"

** Replace don't knows as missings:
foreach a in a ""{
	replace b01`a'_mth = . if b01`a'_mth == 98
	replace b01`a'_yr = . if b01`a'_yr == 9998
}

* no raskin purchases in the future
assert (mdy(b01_mth,1,b01_yr) > mdy(int_end_month,int_end_day,int_end_year) ///
  & !mi(mdy(b01_mth,1,b01_yr))) == 0
assert (mdy(b01a_mth,1,b01a_yr) > mdy(int_end_month,int_end_day,int_end_year) ///
  & !mi(mdy(b01a_mth,1,b01a_yr))) == 0
  
/* Now in leakages_and_targeting_end.do */
* outcome 2: last bought since September 2013 / November 2013

* outcome 3a: used raskin card
g usedcard = (bought_s_sep13 == 1) & b18 == 1
la var usedcard "Used raskin card"

g usedcard_nov13 = (bought_s_nov13 == 1) & b18 == 1
la var usedcard_nov13 "Used raskin card (since Nov 2013)"

* outcome 3b: used blue/green raskin card
g usedcard_gr = usedcard == 1 & (b19 == 3 | b19 == 4)
la var usedcard_gr "Used blue or green raskin card"

* outcome 4: used coupon
g usedcoup_nov13 = (bought_s_nov13 == 1 & b20 == 1)
la var usedcoup_nov13 "Used raskin coupon (since Nov 13)"

g usedcoup = (bought_s_sep13 == 1 & b20 == 1)
la var usedcoup "Used raskin coupon"

****************************
* 3. Clean up and save
****************************

drop rc01-b21
drop bought_s_sep13 bought_s_nov13 bought_last2m //in leakagesandtargeting.dta

saveold "1Data/codeddata/cards_paper/endline/cardreceipt_end.dta", replace

