/*******************************************************************************
* This do-file is a modification of leakages_and_targeting_end.do but ONLY for the price_hh variable,
* We want to use price paid in the last month instead of average. 
*NOTES:	kg to L rice conversion: .8 kg / L of rice
*******************************************************************************/

** SETUP ***********************************************************************

clear all

set more off
pause off
set seed 6104691
set sortseed 6104691

cd "$RASKIN"

** INPUT DATA ******************************************************************

u "1Data/codeddata/cards_paper/endline/beneficiaries_and_randomization_end.dta", clear
gen kea = hhea
gen kea1 = hhea1
merge m:1 kea kea1 using "1Data/originaldata/3_Endline/k_cr.dta"
assert _m == 3
drop kea kea1
drop _m

merge 1:1 hhid using "1Data/originaldata/3_Endline/hh_c.dta"
assert _m==3
drop _m 

merge 1:m hhid using "1Data/originaldata/3_Endline/hh_b2.dta"	// 4 lines per HH
assert _m==3
drop _m

****************************
* 2. Coding outcomes
****************************

** generate month dummies

forv i = 1/12{
	gen FE`i' = (b22_mth == `i')
}
* confirm only one month per observation
assert FE1 + FE2 + FE3 + FE4 + FE5 + FE6 + FE7 + FE8 + FE9 + FE10 + FE11 + FE12 == 1

**************************
*** Usable restriction
**************************

* regular restriction
g usable = 1 if (int_day >= 25 | type_b22 >= 2)
	/* interview is on or after 25th of the month we're talking about, or we're talking about a previous month. */
* alternate
g usable2 = 1 if (int_day == 30 | int_day == 31 | type_b22 >= 2)

** HERE WE DEFINE A LOCAL SO WE CAN CHANGE THE DEFINITION OF USABLE ************
local usable_lcl usable
local usability_options usable usable2

** AMOUNT PURCHASED ************************************************************
* outcome 2: amount purchased
replace b26 = . if b26 == 9995

*replace b26 = b26 / 10  // *WAS: what's this?
assert b26 < 100 | b26 == .	

* convert Liters to Kg
replace b26 = b26 * 0.8 if b26_x == 1 
replace b26 = 0 if b25 == 0

** Cleaning of odd values for amount.

replace b26 = . if b26 > 35 | b26 < 0

** PRICE PAID ******************************************************************
* (according to HH) (keep temp to define month from last time)

// convert to price per kg
replace b27 = b27 / b26 if b27_x == 1	// if it's a total price
replace b27 = b27 * 1.25 if b27_x == 2	// if it's a liter price

* Clean.
replace b27 = . if b27 < 500 | b27 >10000 // absurd values.

** Generate price_hh variables
bys hhid: egen price_hh = mean(b27) if `usable_lcl' == 1
la var price_hh "Raskin price since Sept 2013 (Rp/kg)"

** Alternative usability criteria
foreach option in `usability_options'{
	bys hhid: egen price_hh_`option' = mean(b27) if `option' == 1
	la var price_hh_`option' "Raskin price since Sept 2013 (Rp/kg) (`option')"
}

** price_hh variables for each month
forv i = 1/5{
	local x : word `i' of 9 10 11 12 1
	local mon : word `i' of sep13 oct13 nov13 dec13 jan14
	g price_hh_`mon' = b27 if b22_mth == `x' & `usable_lcl' == 1
	la var price_hh_`mon' "Price of raskin (Rp/kg, `mon')"
}

** Generate a different price_hh variable using last month's price 

*identify which month is the last month that are "usable" for each household and does not contain missing value  
bys hhid:egen last_usable=min(type_b22) if `usable_lcl'==1 & b27!=.  //type_b22==1 is the last month for each hh 
bys hhid:egen last_usablemonth=mean(last_usable)  
drop last_usable

*get the price for the last month 
gen price_last=b27 if type_b22==last_usablemonth
bys hhid: egen price_hh_last=max(price_last)
drop price_last
la var price_hh_last "Raskin price for the last month (Rp/kg)"

keep price_hh_last price_hh hhid

collapse(mean) price_hh_last price_hh, by (hhid)

*create mark up hh variables using price_hh_last 
gen markup_hh		= price_hh - 1600
replace markup_hh 	= 0 if markup_hh < 0

gen markup_hh_last		= price_hh_last - 1600
replace markup_hh_last 	= 0 if markup_hh_last < 0

rename markup_hh       markup_hh_endline
rename price_hh        price_hh_endline 
rename markup_hh_last  markup_hh_last_endline
rename price_hh_last   price_hh_last_endline

** SAVE.      ******************************************************************
 
saveold  "1Data/codeddata/competition/price_lastmonth.dta", replace



