/*******************************************************************************
RASKIN ENDLINE SURVEY - SATISFACTION
*******************************************************************************/

** SETUP ***********************************************************************

clear all

set more off
pause off
set seed 6104691
set sortseed 6104691

cd "$RASKIN"

** INPUT DATA ******************************************************************

u "1Data/codeddata/cards_paper/endline/beneficiaries_and_randomization_end.dta", clear
merge 1:1 hhid using "1Data/originaldata/3_Endline/hh_f.dta"
assert _m==3
drop _m
gen kea = hhea
gen kea1 = hhea1
merge m:1 kea kea1 using "1Data/originaldata/3_Endline/k_rc.dta"
assert _m == 3
drop kea kea1
drop _m

****************************
* 2. Code variables
****************************

* outcome 1a: complaints (HH)
g complaints_hh = f10_a1 if f10_a == 1 & f10_a1 < 995
replace complaints_hh = 0 if f10_a == 3
tab complaints
sum complaints_hh, d
replace complaints_hh = `r(p99)' if complaints_hh > `r(p99)' & complaints_hh < .
tab complaints
la var complaints_hh "No. of complaints according to HH"

* outcome 1b: complaints (leader)
g complaints_ldr = rc02_a1 if rc02_a == 1 & rc02_a1 < 995
replace complaints_ldr = 0 if rc02_a == 3
tab complaints_l
sum complaints_ldr, d
replace complaints_ldr = `r(p99)' if complaints_ldr > `r(p99)' & complaints_ldr < .
tab complaints_l
la var complaints_ldr "No. of complaints according to ldr"

* outcome 2a: protests (hh)
g protests_hh = 0 if f10_b == 3
replace protests_hh = 1 if f10_b == 1 & f10_b1 < 995
la var protests_hh "Were there protests according to HH"

* outcome 2b: protests (leader)
g protests_ldr = 0 if rc02_b == 3
replace protests_ldr = 1 if rc02_b == 1 & rc02_b1 < 995
la var protests_ldr "Were there protests according to leader"

* outcome 3a: fighting (hh)
g fighting_hh = 0 if f10_c == 3
replace fighting_hh = 1 if f10_c == 1 & f10_c1 < 995
la var fighting_hh "Were there fights according to HH"

* outcome 3b: fighting (leader)
g fighting_ldr = 0 if rc02_c == 3
replace fighting_ldr = 1 if rc02_c == 1 & rc02_c1 < 995
la var fighting_ldr "Were there fights according to leader"

* outcome 4a: demonstrations (hh)
g demonstrate_hh = 0 if f10_d == 3
replace demonstrate_hh = 1 if f10_d == 1 & f10_d1 < 995
la var demonstrate_hh "Were there demonstrations according to HH"

* outcome 4b: demonstrations (leader)
g demonstrate_ldr = 0 if rc02_d == 3
replace demonstrate_ldr = 1 if rc02_d == 1 & rc02_d1 < 995
la var demonstrate_ldr "Were there demonstrations according to ldr"

* pooled (hh)
g 		demoprotfight_hh = protests_hh + fighting_hh + demonstrate_hh 
replace demoprotfight_hh = (demoprotfight_hh  > 0 & demoprotfight_hh != .)
la var  demoprotfight_hh "Demonstrations protests or fighting according to HH (Y/N)"

* pooled (ldr)
g 		demoprotfight_ldr = protests_ldr + fighting_ldr + demonstrate_ldr 
replace demoprotfight_ldr = (demoprotfight_ldr > 0 & demoprotfight_ldr != .)
la var  demoprotfight_ldr "Demonstrations protests or fighting according to ldr (Y/N)"

* outcome 5a: overall satisfaction -- scaled 0-1, 1 being positive
g satis_hh = ((4 - f01a) / 3) if inrange(f01a,1,4)
la var satis_hh "Overall satisfaction according to household, scaled 0-1"

* outcome 5b: overall satisfaction -- scaled 0-1, 1 being positive
g satis_ldr = ((rc01 - 1) / 3) if inrange(rc01,1,4)
la var satis_ldr "Overall satisfaction according to village leader, scaled 0-1"

* outcome 6: satisfaction with beneficiary list -- scaled 0-1, 1 being positive
g satis_list_hh = ((4 - f09) / 3) if inrange(f09,1,4)
la var satis_list_hh "HH satisfaction with beneficiary list, scaled 0-1"

****************************
* 3. Clean up and save
****************************

drop f01a-rc04
saveold "1Data/codeddata/cards_paper/endline/satisfaction_end.dta", replace
