/*******************************************************************************
RASKIN - PREP RASKIN BIDDING FORM DATA
1Data/dofiles/prep/bidding_prep.do

SUMMARY: 
	Prepare bidding meeting data from forms for analysis
*******************************************************************************/

* SETUP AND MACROS *******************************************************
clear all

set more off

** DIRECTORIES
cd "$RASKIN"

* GET DATA, PREP VARIABLES *****************************************************

*** FROM FORMS *****************************************************************

********* FORM 7, B ************************************************************
	
** Number of Bids
	//load in data
	u "1Data/originaldata/4_CE/f7a_b2.dta", clear
	
	//basic cleaning, generating new variable
	recode b06 b07 b08 b09 (9=.)
	rename b06 n_bids
	la var n_bids "Number of prospective dealers who signed up"
	replace b07 = 1 if commid == "309" // correcting a mistake
	gen n_bids_not_disqualified = n_bids - b07
	la var n_bids_not_disqualified "Number of prospective dealers who passed initial selection"

	//create and save temp file for relevant variables
	keep commid n_bids n_bids_not_disqualified
	tempfile f7a_b2
	sa `f7a_b2'

********* FORM 7, C ************************************************************

** From Own Village
	u "1Data/originaldata/4_CE/f7a_c.dta", clear
	rename c00_col column
	gen own_village_dist = c02b == 1 
	replace own_village_dist = . if c02b == 9 | c02b == . 
	la var own_village_dist "Bidder lives in distribution village"

** Current Distributor (At time of bidding process) --> Old Distributor
	recode c05 (9=.)(3=0)
	rename c05 old_dist
	la var old_dist "Bidder is Raskin distributor at time of bidding"

** Bidder is a Trader 
	gen trader_dist = (c04 == 5 | c04 == 6)
	la var trader_dist "Bidder is a trader"

	//create and save temp file for relevant variables
	keep commid column own_village_dist old_dist trader_dist
	tempfile f7a_c
	sa `f7a_c'

********* FORM 8, D ************************************************************

** Promised Price
	u "1Data/originaldata/4_CE/f8a_d.dta", clear
	rename d00_col column
	replace d01 = . 					if d01x == 9	//Price unit unspecified
	replace d01 = d01 * 1.25 			if d01x == 2	//Price/liter --> price/kg
	replace d01 = d01/d01_unit 			if d01x == 3 	//Price/Raskin package (kg) --> price/kg
	replace d01 = d01/d01_unit*1.25 	if d01x == 4 	//Price/Raskin package (liters) --> price/kg
	replace d01 = 2000					if d01 	== 1200 & commid=="774" & column== 2 //typo in data
	//More than one price --> average of max and min price/kg
	recode d01ba_unit d01bb_unit (9=.)
	assert d01ba_unit == 1 | d01ba_unit == .
	assert d01bb_unit == 1 | d01bb_unit == .  
	egen d01bab = rowmean(d01ba d01bb) 	if d01b=="AB" & d01ba_unit==1 & d01bb_unit==1
	replace d01bab = d01ba 				if d01b=="A" & d01ba_unit==1
	replace d01bab = d01bb 				if d01b=="B" & d01bb_unit==1
	replace d01 = d01bab 				if d01x == 5
	rename d01 price_dist
	la var price_dist "Raskin price (Rp/kg) promised by bidder"
	
** Promised Markup
	gen markup_dist 	= price_dist - 1600
	replace markup_dist = 0 if markup_dist < 0
	la var markup_dist "Raskin markup over 1600 (Rp/kg) promised by bidder"
	
** Delivery Location
	replace d02 = "Z" if d02=="V" & commid == "608" & column == 3
	gen deliver_village = regexm(d02, "A|B|C|F")
		replace deliver_village = 1 	if commid == "228" & column == 2
		replace deliver_village = 1 	if commid == "676" & column == 1
		replace deliver_village = 1 	if commid == "676" & column == 2
		replace deliver_village = 1 	if commid == "676" & column == 3
		replace deliver_village = 1 	if commid == "676" & column == 4
		replace deliver_village = 1 	if commid == "224" & column == 1
		replace deliver_village = 1 	if commid == "224" & column == 2
		replace deliver_village = 1 	if commid == "224" & column == 3
		replace deliver_village = 1 	if commid == "318" & column == 1
		replace deliver_village = 1 	if commid == "267" & column == 4
		replace deliver_village = 1 	if commid == "503" & column == 1
		replace deliver_village = 1 	if commid == "503" & column == 2

		replace deliver_village = 1 	if commid == "425" & inlist(column,1,3)
		replace deliver_village = 1 	if commid == "982" & inlist(column,4,5)
		replace deliver_village = 1 	if commid == "560" & inlist(column,1,3)
		replace deliver_village = 1 	if commid == "789" & inlist(column,1,2,3)
		replace deliver_village = 1 	if commid == "543" & inlist(column,3)
		replace deliver_village = 1 	if commid == "880" & inlist(column,1)
		replace deliver_village = 1 	if commid == "738" & inlist(column,1)
		replace deliver_village = 1 	if commid == "397" & inlist(column,1,2,3)
		replace deliver_village = 1 	if commid == "357" & inlist(column,1,2)
		replace deliver_village = 1 	if commid == "368" & inlist(column,1)
		replace deliver_village = 1 	if commid == "267" & inlist(column,2,3)
		replace deliver_village = 1 	if commid == "215" & inlist(column,3)
		replace deliver_village = 1 	if commid == "600" & inlist(column,1)
		replace deliver_village = 1 	if commid == "737" & inlist(column,4)
		replace deliver_village = 1 	if commid == "499" & inlist(column,1,2)

		replace deliver_village = 1 	if commid == "228" & inlist(column,1,3)
		replace deliver_village = 1 	if commid == "942" & inlist(column,1)
		replace deliver_village = 1 	if commid == "989" & inlist(column,1)
		replace deliver_village = 1 	if commid == "982" & inlist(column,1)
		replace deliver_village = 1 	if commid == "543" & inlist(column,1)
		replace deliver_village = 1 	if commid == "287" & inlist(column,1,2,3)
		replace deliver_village = 1 	if commid == "382" & inlist(column,1,2,4)
		replace deliver_village = 1 	if commid == "214" & inlist(column,3)
		replace deliver_village = 1 	if commid == "515" & inlist(column,3)

		replace deliver_village = 1 	if commid == "982" & inlist(column,2,3)
		replace deliver_village = 1 	if commid == "214" & inlist(column,1)
		replace deliver_village = 1 	if commid == "835" & inlist(column,1)

	gen deliver_subvillage = regexm(d02, "D|E|H")
		replace deliver_subvillage = 1 	if commid == "382" & column == 3
		replace deliver_subvillage = 1 	if commid == "876" & column == 1
		replace deliver_subvillage = 1 	if commid == "618" & column == 1
		replace deliver_subvillage = 1 	if commid == "801" & column == 1
		replace deliver_subvillage = 1 	if commid == "900" & column == 1
		replace deliver_subvillage = 1 	if commid == "154" & column == 1
	gen deliver_household = regexm(d02, "G") 
		replace deliver_household = 1 	if commid == "543" & column == 2
	
	foreach location in village subvillage household {
		replace deliver_`location' = . if d02 =="Z"
		la var deliver_`location' "Raskin is distributed at `location' level"
	}
	
** Payment Timing
	replace d03 = ""  					if d03 =="W" | d03=="Z" //missing
	forv i=1/3 {
		local letter : word `i' of "A" "B" "C"
		local var : word `i' of "pay_before" "pay_during" "pay_after"
		local label: word `i' of "Pay Before Receipt" "Pay During Receipt" "Pay After Receipt"
		gen `var' = regexm(d03, "`letter'")
		replace `var' = . if d03 == ""
		la var `var' "`label'" 
		}

** Distributor Provides Credit
	gen dist_credit = regexm(d05, "B|F")
	replace dist_credit = . if d05 == "Z"
	la var dist_credit "Bidder offers credit"

** Means of Transportation
	recode d12 (9=.) (3=0)
	rename d12 vehicle_dist 
	la var vehicle_dist "Bidder has means of transportation supportive of Raskin distribution"
	
	//create and save temp file for relevant variables
	keep commid column price_dist deliver_village deliver_subvillage deliver_household ///
	pay_before pay_during pay_after dist_credit vehicle_dist markup_dist		
	tempfile f8a_d
	sa `f8a_d'
	
********* FORM 8, F ************************************************************

** Multiple Bidders
	u "1Data/originaldata/4_CE/f8a_f.dta", clear
	bys commid: gen n_bidders = _N
	gen multiplebidders = n_bidders > 1
	la var n_bidders "Number of bidders who present"
	la var multiplebidders "Multiple bidders present bids"
	
** Win or lose, according to form F8A
	rename f00_col column
	rename f07 winner
	recode winner (3=0) (9=.)
	
	//Deal with villages that return to status quo
	preserve
		clear
		import excel "1Data/originaldata/4_CE/14.09.02 chk_sq_info.xlsx", ///
			sheet("chk_sq_info") firstrow
		keep commid f08
		tempfile f08
		save `f08'
	restore
	
	merge m:1 commid using `f08'
	keep if _m==3
	drop _m
	replace winner = . if f08 == 1
	replace winner = . if commid == "309" // correcting a mistake	
	la var winner "Bidder won bidding process"
	
	//create and save temp file, for relevant variables
	keep commid column multiplebidders winner n_bidders
	tempfile f8a_f
	sa `f8a_f'
	
********* penyalur_sekarang ****************************************************

** Current Distributor
	/* Now have crosswalk --> can match via column and pr_id1 to see if each
	bidder is a current distributor */
	u "1Data/originaldata/4_CE/crosswalk_f8a_distributor_resp", clear
	rename d00_col column
	drop if column == .

	**** Missing Identifiers
	replace pr_id2 = "0" if pr_id2==""
	replace pr_ea = commid if pr_ea == ""
	drop if pr_id1==""

	**** Make sure data is uniquely identified
	//isid pr_ea pr_id1 pr_id2 //False
	bys pr_ea pr_id1 pr_id2: gen n_id = _n
	levelsof pr_id1 if n_id > 1, sep(,) local(multiple_obs)
	drop if inlist(pr_id1, `multiple_obs') & n_id>1 
		//drop latter duplicate observation
	drop n_id
	isid pr_ea pr_id1 pr_id2
	keep pr_ea pr_id1 pr_id2 commid column
	merge 1:1 pr_ea pr_id1 pr_id2 using ///
		"1Data/originaldata/4_CE/penyalur_sekarang.dta"
	drop if _m!=3
	
	//create and save temp file, for relevant variables
	keep commid column
	tempfile current
	sa `current'

********* COMBINE FORMS DATA ***************************************************

u `f8a_f', clear
merge 1:1 commid column using `current'
	gen current_dist = _m!=1
	la var current_dist "Bidder is current distributor (per penyalur_sekarang)"
	drop if _m==2
	drop _m
merge 1:1 commid column using `f8a_d'
	drop if _m==2
	drop _m
merge 1:1 commid column using `f7a_c'
	drop if _m==2
	drop _m
merge m:1 commid using `f7a_b2'
	*assert n_bids<=1 if _m==2
	drop _m

*** OTHER THINGS WE NEED FOR ANALYSIS ******************************************

** MERGE ON COMPETITION TREATMENT 
gen desa_id2 = commid
merge m:1 desa_id2 using ///
  "1Data/codeddata/competition/treatments.dta"
assert _m != 1
drop if _m != 3
drop desa_id2 _merge

** MERGE ON STRATA VARIABLE 
merge m:1 hhea using "1Data/codeddata/competition/good_strata.dta"
assert 	_m != 1
drop if _m != 3
drop _m

** DEAL WITH MISSING BIDDERS
replace n_bidders = 0 if n_bidders == . 
replace n_bidders = . if inlist(commid, "746", "563", "240", "960", "229", "566") 
replace n_bids = 0 					if n_bids == . & n_bidders == 0
replace n_bids_not_disqualified = 0 if n_bids == . & n_bidders == 0 //Rejected bidding treatment

*** SAVE             ***********************************************************

//order variables
order commid hhea desa_id2 column multiplebidders n_bidders winner

//save
saveold "1Data/codeddata/competition/bidders.dta", replace


