/*******************************************************************************
RASKIN PREP - CS1/MIDLINE
1Data/dofiles/prep/cs1midline_vars.do

SUMMARY: 
	Prepare the variables which exist only in CS1 and Midline waves of the
	survey
OUTLINE:
	This file prepares the variables from just the CS1/Midline waves (i.e.,
	the baseline survey for the competition paper treatment) which are needed for the
	competition paper analysis but weren't needed in the cards paper analysis.
NOTES:
*******************************************************************************/

** SETUP AND MACROS *******************************************************
clear all

set more off

** DIRECTORIES
cd "$RASKIN"

********************************************************************************
** PREP OF VARIABLES IN ALL SURVEY WAVES ***************************************
	/*  generate these variables for all waves of the survey so we can 
		control for a hh's previous responses to the question.*/

forv i = 1/2{
** Set up the loops to do this for each dataset.
	local path : 		word `i' of 1_CS1/NewUpdate 2_Midline
	local village_id : 	word `i' of commid commid kea
	local _suf :	 	word `i' of _cs1 _mid
	local X : 			word `i' of A B
	local a : 			word `i' of "" 1

** HH head years of education **************************************************
	
	/* Education equivalencies: 
	Elementary School & Paket A, Junior High & Packet B, Senior High & Paket C */
	
	u "1Data/originaldata/`path'/hh_ar`a'", clear
	keep if ar02 == 1 // keep HH head
	
	gen 	yredhhhead_f = 0			if inlist(ar06,0,1) | ar07 == 96
	replace yredhhhead_f = ar07			if ar06 == 2 | ar06 == 5
		replace yredhhhead_f = 6			if yredhhhead_f > 6
	replace yredhhhead_f = 6 + ar07		if ar06 == 3 | ar06 == 6
		replace yredhhhead_f = 9 			if yredhhhead_f > 9
	replace yredhhhead_f = 9 + ar07 	if ar06 == 4 | ar06 == 7
		replace yredhhhead_f = 12 			if yredhhhead_f > 12
	replace yredhhhead_f = 12 + ar07 	if ar06 == 8
		replace yredhhhead_f = 15 			if yredhhhead_f > 15
	replace yredhhhead_f = 12 + ar07 	if ar06 == 9
		replace yredhhhead_f = 16 			if yredhhhead_f > 16
	replace yredhhhead_f = 16 + ar07 	if ar06 == 10
		replace yredhhhead_f = 21 			if yredhhhead_f > 21
	replace yredhhhead_f = . 			if ar06 >= 95 | ar07 == 98
	label var yredhhhead_f "Years of education of HH Head (follow-up)"
	
	replace hhid = hhid + "`X'"
	keep hhid yredhhhead_f
	tempfile yredhhhead`_suf'
	sa `yredhhhead`_suf''

}

//confirm unique id
isid hhid

** Combine the two temp files      *********************************************
 
u `yredhhhead_cs1', clear
append using `yredhhhead_mid'
isid hhid

** SAVE.            ************************************************************

saveold "1Data/codeddata/competition/cs1midline_vars.dta", replace

