/*******************************************************************************
RASKIN - PREP RASKIN DISTRIBUTOR SURVEY DATA WRT COSTS -- CURRENT DISTRIBUTORS ONLY
1Data/dofiles/prep/current_distributor_costs.do

SUMMARY: 
	Prepare data on costs of distribution to current distributors. 
*******************************************************************************/

** SETUP AND MACROS *******************************************************
clear all

set more off

** DIRECTORIES
cd "$RASKIN"

** FROM ENDLINE DISTRIBUTOR SURVEY *********************************************
u "1Data/originaldata/3_Endline/pr_pp1.dta", clear
merge 1:1 pr_ea pr_id1 pr_id2 using ///
  "1Data/originaldata/4_CE/penyalur_sekarang.dta", ///
  keepusing(pr* dist penya* old_distributor)
keep if _m==3 //current distributors only
drop _m

** Raskin Amount Village Actually Receives from Bulog
/* Actual condition, rather than what village SHOULD receive */
	replace pp17 = . if pp17 >= 999998
	assert pp17_x==1|pp17_x==.
	gen amtraskin_bulog = pp17
	la var amtraskin_bulog "Actual Amount Raskin Village Receives (kg)"
	
** What price does respondent report?
	/*	1 kg = 0.8 liter
		1 l = 1.25 kg
		so price per liter must be multiplied by 1.25 to become price/kg 	*/
	gen price_dist = pp18 if pp18_x == 1
	replace price_dist = pp18 * 1.25 if pp18_x == 2
	replace price_dist = pp18 / pp18_xx if pp18_x == 3
	replace price_dist = pp18 * 1.25 / pp18_xx if pp18_x == 4
	la var price_dist "Raskin retail price (Rp/kg) for beneficiaries (reported by distributor)"	

** Total Transportation Costs (paid from funds received from Raskin Payment)
	replace pp23 					= . 	if pp23 >= 999999990
	gen total_transport_cost 		= pp23 	if pp23_x==1
	replace total_transport_cost 	= 0 	if pp23_x == 3 | pp23_x == .
	la var total_transport_cost 	"Total transportation costs for distribution (Rp)"
	
** Other costs incurred as distributor
	replace pp26 				= . 	if pp26 >= 999999990	
	gen total_other_cost 		= pp26 	if pp26_x == 1
	replace total_other_cost 	= 0 	if pp26_x == 3 |  pp26_x == .
	la var total_other_cost 	"Total other costs of distribution (Rp)"
	
//create and save tempfile
tempfile pp1
sa `pp1'

** Payments from Distributor
preserve
	u "1Data/originaldata/3_Endline/pr_pp3.dta", clear
	merge m:1 pr_ea pr_id1 pr_id2 using ///
	  "1Data/originaldata/4_CE/penyalur_sekarang.dta", ///
	  keepusing(pr* dist penya* old_distributor)
	keep if _m==3 //current distributors only
	drop _m
	merge m:1 pr_ea pr_id1 pr_id2 using `pp1', ///
		keepusing(total_other_cost total_transport_cost amtraskin_bulog price_dist)
		gen missing = _m==2
		replace missing = 0 if total_transport_cost == . & total_other_cost == .
		drop _m
		
	//Replace Missing
	foreach var of varlist pp24_d_a pp24_d_b pp24_d_c pp24_d_d {
		replace `var' = . if `var'>= 9999990
	}
	//Assert Units ae Kg, not L, if relevant
	foreach var of varlist pp24_d_a_x pp24_d_b_xx pp24_d_d_x {
		assert `var' != 3
	}
	//Make Units Comperable Across Options
	gen pp24_d_A	= pp24_d_a*amtraskin_bulog				//Rp per kg --> Rp
	gen pp24_d_B 	= pp24_d_b/pp24_d_b_x*amtraskin_bulog  	//Rp per package --> Rp
	gen pp24_d_C 	= pp24_d_c								//Rp per distribution
	gen pp24_d_D	= pp24_d_d*price_dist					//Bag of rice --> Rp
	
	//Generate cost (per person being paid)
	gen compensation_cost1 = .
	foreach x in A B C D {
		replace compensation_cost1 = pp24_d_`x' if pp24_d_x == "`x'"
	}
	replace compensation_cost1 = pp24_d_A + pp24_d_C if pp24_d_x == "AC"
	replace compensation_cost1 = pp24_d_C + pp24_d_D if pp24_d_x == "CD"
	replace compensation_cost1 = 0 if missing == 1
	drop total*

	//Create other cost per disributor
		/* All costs (fees/compensation, donations, and community funds) */
	bys pr_ea pr_id1 pr_id2: egen compensation_cost = total(compensation_cost1), missing

	//Final Steps
	keep pr_ea pr_id1 pr_id2 compensation_cost missing
	duplicates drop 
	replace compensation_cost = 0 if missing==1 & compensation_cost == .
	drop if mi(compensation_cost)
	isid pr_ea pr_id1 pr_id2
	la var compensation_cost "Compensation to Others (Rp)"
	
	//create and save tempfile
	tempfile pp3
	sa `pp3'
restore

merge 1:1 pr_ea pr_id1 pr_id2 using `pp3'
assert _m!=2
drop _m

** MERGING/FINAL STEPS *********************************************************
** Keep
	keep pr_ea pr_id1 pr_id2 *cost 
	
** FINAL MERGING 
	gen desa_id2 = pr_ea
	merge m:1 desa_id2 using "1Data/codeddata/competition/treatments.dta"
	drop _m

** SAVE FINAL DATA SET. ********************************************************
	saveold "1Data/codeddata/competition/current_distributor_costs.dta", replace
