/*******************************************************************************
RASKIN - PREP RASKIN DISTRIBUTOR SURVEY DATA
1Data/dofiles/prep/distributors_prep.do

SUMMARY: 
	Prepare raskin distributor survey for competition analysis.
NOTES: 
	EVENTUALLY WE WANT DISTRIBUTOR SURVEY DATA TO BE LINKED WITH FORM COLUMN 
	FOR BIDDING VILLAGES.
		SEE BIDDERS_FORM_SURVEY_CROSSWALK.DO or bid_dist_all.dta FOR THIS
*******************************************************************************/

** SETUP AND MACROS *******************************************************
clear all

set more off

** DIRECTORIES
cd "$RASKIN"

** GET DATA, PREP VARIABLES ****************************************************

** ID **************************************************************************
u "1Data/originaldata/3_Endline/pr_id", clear

** Does distributor live in village?
recode id00 (3=0)
rename id00 own_village_dist
la var own_village_dist "Raskin distributor lives in village"

** Is distributor a trader?
gen trader_dist = id06 ==10 | id06 ==11
la var trader_dist "Raskin distributor is a trader"

** Education Level
gen yred_dist 			= 0				if id02 == 0
replace yred_dist 		= id03			if id02 == 1
	replace yred_dist 	= 6				if yred_dist > 6
replace yred_dist 		= 6 + id03		if id02 == 2
	replace yred_dist 	= 9				if yred_dist > 9
replace yred_dist 		= 9 + id03 		if id02 == 3
	replace yred_dist 	= 12 			if yred_dist > 12
replace yred_dist 		= 12 + id03 	if id02 == 4
	replace yred_dist 	= 15 			if yred_dist > 15
replace yred_dist 		= 12 + id03 	if id02 == 5
	replace yred_dist 	= 16 			if yred_dist > 16
replace yred_dist 		= 16 + id03 	if id02 == 6
	replace yred_dist 	= 21 			if yred_dist > 21
replace yred_dist 		= . 			if id02 > 6 | id03 > 7
label var yred_dist "Years of education of Distributor"

** Distibutor used to be a village official
gen past_off_dist 			= regexm(id08,"A|F") //Village head or other village official
gen past_sub_off_dist 		= regexm(id08,"B|C") //Subvillage or RT official
replace past_off_dist 		= . if id08=="W"
replace past_sub_off_dist 	= . if id08=="W"
la var past_off_dist 		" Distibutor was previously a village official"
la var past_sub_off_dist 	" Distibutor was previously a subvillage official"

//create and save temp file
tempfile id
sa `id'

** KM **************************************************************************
u "1Data/originaldata/3_Endline/pr_km", clear

** Distributor owns truck or boat
gen vehicle_dist = regexm(km11_x,"A|G") //truck or boat/raft
	* Other options include car/pickup (B), motorship (E), motorboat (F) 
replace vehicle_dist = . if km11_x == "Z"
la var vehicle_dist "Distributor owns a truck and/or a boat"

** Savings
recode km02 (3=0) (9=.)
rename km02 savings_dist
la var savings_dist "Distributor has personal savings account that be used for business"

** Credit to Raskin Beneficiary 
gen dist_credit = regexm(km08, "E")
la var dist_credit "Distibutor has given loan to Raskin beneficiary within 2 years"

** Number of People Employed by Distributor for Non-Raskin purposes
egen n_employed_dist = rowtotal(km17 km19)
la var n_employed_dist "Total # employed by distributor in last 3 months"
la var km17 "# non-Raskin laborers employed by distributor in last 3 months"
la var km19 "# permanent employees employeed distributor in last 3 months"

//create and save temp file
tempfile km
sa `km'

** PG **************************************************************************
u "1Data/originaldata/3_Endline/pr_pg", clear

** Distributor had coordinator responsibilities before May 2013
/* According to field observation, pg04 = A, B, and C correspond to 
	distribution coordinator's role */
gen pg04_a 				= regexm(pg04, "A")
la var pg04_a "Distributor was in charge of making Raskin payment to Bulog before May 2013"
gen pg04_b 				= regexm(pg04, "B")
la var pg04_b "Distributor was in charge of coordinating Raskin delivery with Bulog before May 2013"
gen pg04_c 				= regexm(pg04, "C")
la var pg04_c "Distributor was in charge of signing Bulog's letter of Raskin delivery before May 2013"

gen pg04_olddist_any 	= regexm(pg04, "A|B|C")
la var pg04_olddist_any "Distributor was in charge of any coordinator responsibilities before May 2013"
	/* This is the measure of being old distributor that we use when comparing across treatment/control, 
	because we don't have name of old distributor for control villages */

gen pg04_olddist_2		= pg04_a+pg04_b+pg04_c >=2
gen pg04_olddist_all 	= pg04_a+pg04_b+pg04_c ==3
foreach var of varlist pg04_* {
	replace `var' = . if pg04 == "Z"
}

la var pg04_olddist_2 "Distributor had at least 2 coordinator responsibilities before May 2013"
la var pg04_olddist_all "Distributor had all coordinator responsibilities before May 2013"

//create and save temp file
tempfile pg
sa `pg'

** PM **************************************************************************
u "1Data/originaldata/3_Endline/pr_pm2", clear

** Distibutor/spouse is village official
gen current_off_dist = (pm2type=="A" | pm2type=="G") & pm02 == 4 

** Distibutor/spouse is subvillage official
gen current_sub_off_dist = (pm2type=="B" | pm2type=="C") & pm02 == 4 

** Distributor is related to village official
gen relative_off_dist = regexm(pm03,"A|B|C") & (pm2type=="A" | pm2type=="G")

** Distributor is related to subvillage official
gen relative_sub_off_dist = regexm(pm03,"A|B|C") & (pm2type=="B" | pm2type=="C")

foreach var of varlist current_*off_dist relative_*off_dist {
	replace `var' = . if pm02 == 9
}
collapse (max) current_off_dist relative_off_dist current_sub_off_dist relative_sub_off_dist, by(pr_ea pr_id1 pr_id2)
la var current_off_dist 		"Distibutor/spouse is currently a village official"
la var relative_off_dist 		"Distibutor/spouse is related to a village official"
la var current_sub_off_dist 	"Distibutor/spouse is currently a subvillage official"
la var relative_sub_off_dist 	"Distibutor/spouse is related to a subvillage official"

//create and save temp file
tempfile pm
sa `pm'

** TM **************************************************************************
u "1Data/originaldata/3_Endline/pr_tm3", clear

** Digit Span Test: Number correct answers forward
la var tm2_a "Digit Span Forward: Raw # Correct (out of 9)"
rename tm2_a dsf
** Digit Span Test: Number correct answers backward
la var tm2_b "Digit Span Backward: Raw # Correct (out of 9)"
rename tm2_b dsb
** Average Digit Span
egen digitspan_avg = rowmean(dsf dsb)
la var digitspan_avg "Avg # Correct (out of 9) of Digit Span Forward and Backward"
** Above Median Correct Digit Span
summ digitspan_avg, d
gen digitspan_hi = digitspan_avg > `r(p50)' if !mi(digitspan_avg)
la var digitspan_hi "Avg Digit Span above median"

//create and save temp file
tempfile tm
sa `tm'

** DG **************************************************************************
forv i = 1/3{
	local a: word `i' of a b c
	u "1Data/originaldata/3_Endline/pr_dg`i'", clear
	rename dg01_`a' roll
	replace roll = .r if roll == 7
	replace roll = .m if roll == 9
	reshape wide roll, i(pr_ea  pr_id1 pr_id2) j(dg00_`a')
	tempfile file`a'
	sa `file`a''
	count
}

u `filea', clear
foreach x in b c{
	merge 1:1 pr_ea pr_id1 pr_id2 using `file`x''
	assert _m == 3 | mi(roll1)
	drop _m
}


** Generate a total
egen dice_points = rowtotal(roll*) if !mi(roll1)
la var dice_points "Raw dice score"
sum dice_points, d
gen high_points = dice_points > `r(p50)'
replace high_points = . if mi(dice_points)
la var high_points "Raw dice score above median"

gen points_norm = dice_points / 42 // the game is 42 rolls
sum points_norm
local mean_points = `r(mean)'

local n = 42
local mean_normal = `n' * 3.5
local var_normal = `n' * ((2.5^2 + 1.5^2 + 0.5^2)/3)
local sd_normal = sqrt(`var_normal')

local p10 = `mean_normal' - 1.28 * `sd_normal'
local p25 = `mean_normal' - 0.67 * `sd_normal'
local p50 = `mean_normal'
local p75 = `mean_normal' + 0.67 * `sd_normal'
local p95 = `mean_normal' + 1.96 * `sd_normal'
local p99 = `mean_normal' + 2.33 * `sd_normal'

foreach xx in 10 25 50 75 95 99{
	gen above_p`xx' = dice_points > `p`xx'' 
	replace above_p`xx' = . if mi(dice_points)
	la var above_p`xx' "Individual's total is above `xx'th pctile of theoretical distribution"
}

gen diff = points_norm - 3.5
sum diff, d

//create and save temp file
tempfile dg
sa `dg' 

** COMBINE *********************************************************************

u `id', clear
foreach data in km pg pm tm dg{
	merge 1:1 pr_ea pr_id1 pr_id2 using ``data''
	assert _m == 3
	drop _m
}

** Past/Present/Related to Village Official ************************************
egen off_dist 			=	rowmax(past_off_dist current_off_dist) 
egen sub_off_dist 		=	rowmax(past_sub_off_dist current_sub_off_dist) 
replace off_dist 		= . if (past_off_dist==0 & current_off_dist==.)|(current_off_dist==.&past_off_dist==0)
replace sub_off_dist 	= . if (past_sub_off_dist==0 & current_sub_off_dist==.)|(current_sub_off_dist==.&past_sub_off_dist==0)

la var off_dist "Distributor/spouse is/was village official"
la var sub_off_dist "Distributor/spouse is/was subvillage official"

** WHO IS A CURRENT DISTRIBUTOR? ***********************************************
merge 1:1 pr_ea pr_id1 pr_id2 using ///
  "1Data/originaldata/4_CE/penyalur_sekarang.dta", ///
  keepusing(pr* dist penya* old_distributor)
assert _m != 2
gen current_dist = _m == 3
rename old_distributor current_old
la var current_dist "Current distributor"
la var penyalur_status "Old distributor (missing for control villages because unknown)"
la var penyalur_bidding "Bidding Outcome"
la var current_old "Current Distributor is old distributor"
drop _merge

** SOME INFO FROM FORMS ********************************************************
gen commid 	= pr_ea
gen hhea 	= pr_ea
	
** OTHER THINGS WE NEED FOR ANALYSIS *******************************************

** MERGE ON STRATA VARIABLE 
	// strata_simple
merge m:1 hhea using "1Data/codeddata/competition/good_strata"
assert _m == 3
drop _merge

** MERGE ON TREATMENT
cap gen desa_id2 = pr_ea
merge m:1 desa_id2 using "1Data/codeddata/competition/treatments.dta"
drop _m

** Won bidding
merge 1:1 pr_ea pr_id1 pr_id2 using "1Data/originaldata/3_Endline/pr_pp1", ///
	keepusing(pp07* pp10*)
assert _m==3
drop _m

gen winner_survey = pp07x==3
replace winner_survey = . if pp07x==1 | pp07x==2 //appointed, not bidding
replace winner_survey = . if tr_dist != 1
la var winner_survey "Surveyed distributor reports winning bidding process"

** SAVE ************************************************************************
saveold "1Data/codeddata/competition/distributors.dta", replace


exit


