/*******************************************************************************
STRATA - RASKIN COMPETITION PAPER
1Data/dofiles/prep/good_strata.do

SUMMARY: 
	This is a copy of the randomization file, except that it only 
	keeps strata variables and village IDs, and saves the file elsewhere.
*******************************************************************************/

** SETUP AND MACROS *******************************************************

clear all

set more off

cd "$RASKIN"

*************************************
* Table of Contents:
* 1. SET ENVIRONMENT (SEED)
* 2. RANDOMIZATION 
* 3. TREATMENT COUNTS AND STRATA 
* 4. BALANCE CHECK 
*************************************


* This randomization is for COMMUNITY TREATMENTS. Card treatments imported from July randomization.

* STRATEGY:
* 1. Stratification is on kabupaten, Targeting II treatment, Main cards treatment, and socialization treatment, in that order.
* 2. If strata have less than 6, enhanced-vs.-standard-socialization boundary is dissolved. If still have less than 6, All-v-B10 boundary dissolved.
* 3. Leftovers are sorted by kabupaten, TII, Main cards, and socialization, in that order, then put into groups of 6.
* 4. The groups of 6 are split into two groups of 3, and assigned 1/2/3. One village in each 6 assigned 3 is re-assigned 1 (monitoring-->control).
* 5. The last two leftovers are done manually on the same algorithm.
* 6. Subtreatment A is assigned in groups of 2 made from the groups-of-6 (which each have 2 distribution villages). The leftover is assigned randomly.
* 7. Subtreatment B is randomly assigned to the first two villages, then in inverse to those vis-a-vis Subtreatment A in the next two. The leftover is assigned randomly.
* 8. Subtreatment C is randomly assigned to the first four village, then in inverse to thsoe vis-a-vis Subtreatments A and B in the next four. The leftover is assigned randomly.


************************
** 1. SET ENVIRONMENT **
************************

* SET SEED
set sortseed 20130225
set seed 20130226

**********************
** 2. RANDOMIZATION **
**********************

* for main treatments

**************************************************
* TR2: COMMUNITY INVOLVEMENT: CONTROL (300), MONITORING (100), DISTRIBUTION (200)
**************************************************

* IMPORT ORIGINAL RANDOMIZATION
use "1Data/originaldata/0_Randomization/120716 randomization results for new TR2.dta", clear

* DROP DROPPED VILLAGES
preserve
	insheet using "1Data/originaldata/0_Partner_Intervention/120914 List of villages to drop.csv", comma clear
	keep desaid
	tostring desaid, replace
	replace desaid = "0"+desaid if length(desaid)<3
	replace desaid = "0"+desaid if length(desaid)<3
	ren desaid desa_id2
	tempfile drop
	sa `drop'
restore
merge 1:1 desa_id2 using `drop'
drop if _m==3
drop _m

* CREATE STRATA
replace TR1c = 3 if TR1c==. // missing is control, but can't create groups that way
egen strata = group(kab_id t2treatment TR1 TR1c)
la var strata "Main strata, including dissolutions"

* DISSOLVE SOCIALIZATION BOUNDARIES IF UNDER 6
bys strata: g numvillages = _N
g under = numvillages<6
bys kab_id t2treatment TR1: egen temp = max(under)
egen strata_temp = group(kab_id t2treatment TR1) if temp==1
replace strata = strata_temp+300 if temp==1
drop numvillages under temp strata_temp

* DISSOLVE B10/ALL BOUNDARY IF UNDER 6
bys strata: g numvillages = _N
g under = numvillages<6
bys kab_id t2treatment: egen temp = max(under)
egen strata_temp = group(kab_id t2treatment) if temp==1
replace strata = strata_temp+600 if temp==1
drop numvillages under temp strata_temp

** SAVE STRATA AS IT EXISTS HERE
** This is what we'll use for strata FE
gen strata_simple = strata
la var strata_simple "group(kab_id t2treatment TR1 TR1c)"

* CLEAN UP DATASET
keep desa_id2 strata_simple
order desa_id2 strata_simple
so desa_id2
gen hhea = desa_id2
saveold "1Data/codeddata/competition/good_strata.dta", replace


