/*******************************************************************************
COMPETITION - CREATE PROCESS VARIABLES FOR BIDDING MEETINGS
1Data/dofiles/prep/info_meeting_prep.do

SUMMARY: 
	Descriptive info on bidding meetings for bidding villages (meetings held, 
	composition of bidding commitess, meeting quality, etc)
*******************************************************************************/

* SETUP AND MACROS *************************************************************
clear all

set more off

** DIRECTORIES
cd "$RASKIN"

* CREATE/COMPILE VARIABLES *****************************************************
** Meeting length *************************************************************
u "1Data/originaldata/4_CE/f5b_a1", clear
rename commid hhea
replace a05_min = a05_min/60
replace a06_min = a06_min/60
gen start 		= a05_hr + a05_min
gen end 		= a06_hr + a06_min
gen mtg_time 	= end - start
recode mtg_time (0=.)
la var mtg_time "Length of Meeting (Hrs)"

//keep relevant variables, drop observations with missing values
keep hhea mtg_time
drop if mi(mtg_time)

//create and save temp file
tempfile mtg_length
sa `mtg_length'

** Composition of meetings *****************************************************
u "1Data/originaldata/4_CE/f5b_b", clear
rename commid hhea
recode b03_? (99=.)
//Total # Attendees
gen mtg_total = b03_9
la var mtg_total "Attendees"
//# Women Attendees
gen mtg_female = b03_9a
la var mtg_female "Female Attendees" 
//#Male Attendees
gen mtg_male = b03_9b
la var mtg_male "Male Attendees" 
//#Raskin Recipient Attendees
gen mtg_raskin = b03_7
la var mtg_raskin "Raskin Beneficiaries" 
//#Formal Elite
egen mtg_official = rowtotal(b03_1 b03_2 b03_3 b03_4)
replace mtg_official = . if mtg_official > mtg_total 
la var mtg_official "Formal Village Officials (village/hamlet officials)"
//#Non-Raskin Recipient Attendees
gen mtg_nonraskin = b03_9 - b03_7 //because other categories may be double counted
replace mtg_nonraskin = . if mtg_nonraskin < 0
la var mtg_nonraskin "Non Raskin Recipients" 

//keep relevant variables
keep hhea mtg_total mtg_female mtg_male mtg_raskin mtg_nonraskin mtg_official

//create and save temp file
tempfile mtg_female
sa `mtg_female'

** Quality of Meetings *********************************************************
//Comments/Participation
u "1Data/originaldata/4_CE/f5b_f", clear
rename commid hhea
assert f02 == . if f01 !=1
recode f01 (9 = .) (3 = 0)
rename f01 mtg_questions
la var mtg_questions "Did anyone at meeting leave question, comment, etc?"
la def no_yes 0 "No" 1 "Yes"
la val mtg_questions no_yes
rename f02 mtg_questions_n
la var mtg_questions_n "How people left question, comment, etc at mtg?"

//keep relevant variables
keep hhea mtg_questions mtg_questions_n

//create and save temp file
tempfile mtg_q
sa `mtg_q'

* MERGE EVERYTHING.     ********************************************************
use `mtg_length', clear
merge 1:1 hhea using `mtg_female'
assert _m == 3
drop _m

merge 1:1 hhea using `mtg_q'
assert _m == 3
drop _m

merge 1:1 hhea using "1Data/codeddata/competition/treatments.dta", ///
	keepusing(TR2_2013 tr_moni)
keep if tr_moni==1
assert _m==3
drop _m

* SAVE.             ************************************************************

saveold "1Data/codeddata/competition/info_meeting.dta", replace
