/*******************************************************************************
COMPETITION - CREATE PROCESS VARIABLES FOR BIDDING MEETINGS
1Data/dofiles/prep/old_dist_prep_win.do

SUMMARY: 
	Prep variables from old distributor interview (Form 4).
OUTLINE:
NOTES:
*******************************************************************************/

* SETUP AND MACROS *************************************************************
clear all

set more off

** DIRECTORIES
cd "$RASKIN"

* VARIABLES ABOUT DISTRIBUTION, ACCORDING TO OLD DISTRIBUTOR *******************

u "1Data/originaldata/4_CE/f4_b1.dta", clear

** HH Price Reported by Original Distributor
	replace b24 = . 				if b24x == 9	//Missing
	replace b24 = b24 * 1.25 		if b24x == 2	//Price/liter --> price/kg
	replace b24 = b24/b24_unit 		if b24x == 3 	//Price/Raskin package (kg) --> price/kg
	replace b24 = b24/b24_unit*1.25 if b24x == 4 	//Price/Raskin package (liters) --> price/kg
	//More than one price --> average of max and min price/kg
	destring b25a b25b, ignore(_ .) replace
	assert b25a_unit == 1 | b25a_unit == .
	assert b25b_unit == 1 | b25b_unit == .
	egen b25_ab =rowmean(b25a b25b) if b25=="AB"
	replace b25_ab = b25a 			if b25=="A"
	replace b25_ab = b25b 			if b25=="B"
	replace b24 = b25_ab 			if b24x == 5
	//Remove unreasonable values, follow leakagesandtargeting
	replace b24 = . 				if b24 < 500 | b24 > 10000
	rename b24 price_hh_odist
	la var price_hh_odist "Raskin Price for HH (Rp/kg) According to Original Distributor" 

** Maximum Quantity/HH Reported by Original Distributor
	replace b26 = b26*0.8 			if b26x == 3 //Liters --> kg
	rename b26 amtraskin_hh_odist
	la var amtraskin_hh_odist "Max Raskin Quantity per HH (kg) According to Original Distributor"

** How much is the Raskin quota received by this village?
* This is more normative question, how much Raskin is allocated to the village based on the regulation
	assert b02x == 1
	rename b02 amtraskin_allocated
	la var amtraskin_allocated "Raskin/month (kg) allocated to village (based on regulation)"

** How much of Raskin did you (as distributor) received from BULOG at the distribution point last month? 
* Contrary to b02, this asks about the real condition. 
	assert b05x == 1
	rename b05 amtraskin_received
	la var amtraskin_received "Raskin/month (kg) actually received by old distributor"

** Purchase Price of Raskin from BULOG
* It should be Rp 1,600 per kg, referred to the regulation. 
* We asked this question to confirm whether the distributors knew how much the Raskin price supposed to be
	assert b06x == 1
	rename b06 price_dist
	la var price_dist "Purchase Price (Rp/kg) of Raskin (Should be Rp 1600/kg) according to old distributor"

* VARIABLES ABOUT OLD DISTRIBUTOR **********************************************
** Distributor Provides Credit
	gen dist_credit = regexm(b33, "B|F")
	replace dist_credit = . if b33 == "Z"
	la var dist_credit "Bidder provides credit if recipient cannot afford Raskin"

** Costs to Raskin Distributor
	foreach var of varlist b12a-b12v7 b15{
		replace `var' = . if `var' >= 99999996
		}
	replace b12d = b15 if (b12d == .) | (b15 > b12d & b15 !=.)
		/*replaces cost of labor with amount paid to people who help distribute 
		if the latter is larger */

	//Transportation Costs
	egen transport_cost = rowtotal(b12a b12b)
	la var transport_cost "Costs of Rental Vehicle and/or Fuel to Old Distributor"

	//Other Costs
	egen other_cost = rowtotal (b12c b12d b12e b12f b12v1 b12v2 b12v3 b12v4 b12v5 b12v6 b12v7)
	la var other_cost "Non-Transportation Costs to Old Distributor"

	//Total Cost
	egen total_cost = rowtotal(transport_cost other_cost), mi
	la var total_cost "Total Costs to Old Distributor"
	
	//Topcode 
	foreach x in transport_cost other_cost total_cost {
		summ `x', d
		replace `x' = `r(p99)' if `x' >= `r(p99)'
	}
	
	//Costs/kg
	foreach var of varlist transport_cost other_cost total_cost {
		gen `var'_kg = `var'/amtraskin_received 
		local `var'_lbl : variable label `var'
		la var `var'_kg "``var'_lbl'/Raskin received (Kg)"
	}

** Rent = Price - Costs
	gen rents = price_hh_odist - total_cost_kg
	la var rents "Raskin Price - Total Cost (Rp/kg)"
	replace rents = . if rents <0

* FINAL STEPS ******************************************************************
gen hhea = commid
merge 1:1 hhea using "1Data/codeddata/competition/treatments.dta", ///
	keepusing(TR2* tr_dist tr_any tr_moni)
assert tr_any == 0 if _m!=3
drop if _m!=3
drop _m
drop b*
order hhea commid

saveold "1Data/codeddata/competition/old_dist_vars_win.dta", replace
