/*******************************************************************************
COMPETITION - CREATE PROCESS VARIABLES FOR BIDDING MEETINGS
1Data/dofiles/prep/pricelastmonth_combined.do

SUMMARY: 
	Combines price data
*******************************************************************************/

* SETUP AND MACROS *************************************************************
clear all

set more off

** DIRECTORIES
cd "$RASKIN"

* Clean data.                    ***********************************************

//load in data
use "1Data/codeddata/competition/price_lastmonth.dta", clear

//gen hhid variabl
gen temp=substr(hhid,8,1)
ren hhid hhid_real
gen hhid=substr(hhid,1,7)

//create and save temp file
tempfile all
save `all'

//merge with obs which has CS1 as baseline
keep if temp=="A"
merge 1:1 hhid using "1Data/codeddata/competition/price_lastmonth_baseline.dta"
keep if _merge==3
drop _merge

//create and save temp file
tempfile A
save `A'

//merge with obs which has Midline as baseline
use `all'
keep if temp=="B"

//load in midline data
merge 1:1 hhid using "1Data/codeddata/competition/price_lastmonth_midline.dta"
keep if _merge==3
drop _merge

//append in baseline data
append using `A'

//rename variables
rename hhid hhid_match
rename hhid_real hhid

//generate variables
gen     price_hh_f    =price_hh_midline  if temp=="B"
replace price_hh_f    =price_hh_baseline if temp=="A"

gen     price_hh_last_f=price_hh_last_midline  if temp=="B"
replace price_hh_last_f=price_hh_last_baseline if temp=="A" 

gen     markup_hh_f    =markup_hh_midline  if temp=="B"
replace markup_hh_f    =markup_hh_baseline if temp=="A"

gen     markup_hh_last_f=markup_hh_last_midline  if temp=="B"
replace markup_hh_last_f=markup_hh_last_baseline if temp=="A" 

//rename variables
rename price_hh_endline  price_hh 
rename markup_hh_endline markup_hh
rename price_hh_last_endline   price_hh_last
rename markup_hh_last_endline  markup_hh_last 

//keep relevant variables
keep hhid price_hh price_hh_f price_hh_last price_hh_last_f markup_hh markup_hh_f markup_hh_last markup_hh_last_f

** NOW MAKE A VERSION WHICH IS FILLED IN WITH THE AVERAGE WHEN BASELINE MISSING
** ALSO MAKE DUMMIES FOR WHETHER THE BASELINE IS MISSING
ds, not(type string)
foreach v in `r(varlist)'{
	cap conf v `v'_f
	if !_rc{
		cap conf v `v'_f_mis
		if _rc gen `v'_f_mis = mi(`v'_f)
		cap conf v `v'_f2
		if _rc{
			sum `v'_f
			if `r(N)' == 0 continue // skip variables with no observations.
			gen `v'_f2 = `v'_f
			replace `v'_f2 = `r(mean)' if mi(`v'_f)
			assert `v'_f2 != .
		}
	}
}

*as a sanity check, price_hh, price_hh_f, price_hh_f2, markup_hh, markup_hh_f & markup_hh_f2 has to be same with the ones in endmidcs1.dta 
local list price_hh price_hh_last  markup_hh  markup_hh_last
foreach x of local list {
sum `x' `x'_f  `x'_f2
} 

** SAVE FINAL DATA SET. ********************************************************

saveold "1Data/codeddata/competition/price_lastmonth_combined.dta", replace
