/*******************************************************************************
VILLAGE-LEVEL PRICES
1Data/dofiles/prep/village_prices.do

SUMMARY: 
	Raskin price data at the village level from CS1, Midline, and Endline
	surveys, for competition analysis.
*******************************************************************************/

** SETUP AND MACROS *******************************************************
clear all

set more off

** DIRECTORIES
cd "$RASKIN"

********************************************************************************
	
** Dummy: average baseline price in village is higher than median village's baseline avg price *********

//load in data
u "1Data/codeddata/cards_paper/paper/combined_pooled", clear

//generate variable for markup (any amount over 1600)
gen markup_hh = price_hh - 1600
replace markup_hh = 0 if markup_hh < 0 // markup cannot be negative (replace with 0 if no markup)

//generate subsidy variable
gen subsidy1 = subsidy_rcvd if treated == 1

//collapse by hhea
collapse (mean) price_hhea_f 	 	= price_hh 	///
				markup_hhea_f 	 	= markup_hh ///
				subavg_hhea_f 	 	= subsidy1 	///
				meanprice_hhea_f 	= price_hh 	///
				meanmarkup_hhea_f 	= markup_hh ///
		(max)	maxprice_hhea_f 	= price_hh 	///
				maxmarkup_hhea_f 	= markup_hh ///
		(min)	minprice_hhea_f 	= price_hh 	///
				minmarkup_hhea_f 	= markup_hh ///
				, by(hhea)

** Dummy: is the mean baseline price above that of the median baseline village? **********

//summarize mean price
sum meanprice_hhea_f, d

//generate dummy if above mean and not missing
gen hiprice_hhea_f = price_hhea_f > `r(p50)' if !mi(price_hhea_f)
la var hiprice_hhea_f "Dummy: Avg baseline price in village > avg baseline price in median village"

//duplicate
gen p50_f = hiprice_hhea_f /* this is the same variable, we just need it to 
	have different names at different times. */
la var p50_f "Dummy: Avg baseline price in village > avg baseline price in median village"

//label variables
foreach var in mean max min{
	la var `var'price_hhea_f "Baseline `var' price in village"
	la var `var'markup_hhea_f "Baseline `var' markup in village"
}

//create mean price and mean markup variables, but with mean if missing and a dummy to denote missing
gen meanprice_hhea_f2 = meanprice_hhea_f
replace meanprice_hhea_f2 = `r(mean)' if mi(meanprice_hhea_f)
gen meanprice_hhea_f_mis = mi(meanprice_hhea_f) // dummy
gen meanmarkup_hhea_f2 = meanmarkup_hhea_f
replace meanmarkup_hhea_f2 = `r(mean)' if mi(markup_hhea_f)
gen meanmarkup_hhea_f_mis = mi(meanmarkup_hhea_f) // dummy

//create dummies for low, medium, or high price (split into terciles)
centile meanprice_hhea_f, centile(33 66)
gen lo_f = meanprice_hhea_f < `r(c_1)' if !mi(meanprice_hhea_f)
gen med_f = meanprice_hhea_f > `r(c_1)' & meanprice_hhea_f < `r(c_2)' ///
  if !mi(meanprice_hhea_f)
gen hi_f = meanprice_hhea_f > `r(c_2)' if !mi(meanprice_hhea_f)
la var lo_f "Dummy: Baseline village price < 33rd pctile"
la var med_f "Dummy: 33rd pctile < Baseline village price < 66th pctile"
la var hi_f "Baseline village price > 66th pctile"

//create and save tempfile
tempfile village_prices_base
sa `village_prices_base'
	 
	 
** village-level mean, max, min price (endline -- 18 mo)      ******************

//load in data
u "1Data/codeddata/competition/cards_combined_all", clear

//generate markup and make 0 if negative
gen markup_hh = price_hh - 1600
replace markup_hh = 0 if markup_hh < 0

//create mean, max, and min price/markup variables, by hhea
collapse (mean)	meanprice_hhea 	= price_hh 	///
				meanmarkup_hhea = markup_hh ///
		(max)	maxprice_hhea 	= price_hh 	///
				maxmarkup_hhea 	= markup_hh ///
		(min)	minprice_hhea 	= price_hh 	///
				minmarkup_hhea 	= markup_hh ///
				, by(hhea)

//label variables from right above
foreach var in mean max min{
	la var `var'price_hhea 	"Endline `var' price in village"
	la var `var'markup_hhea "Endline `var' markup in village"
}

** COMBINE *********************************************************************

merge 1:1 hhea using `village_prices_base'
assert _m == 3
drop _m

** SAVE FINAL DATA SET. ********************************************************

saveold "1Data/codeddata/competition/village_prices.dta", replace


