/*******************************************************************************
RASKIN PREP - WINNERS WHO DON'T DISTRIBUTE
1Data/dofiles/prep/winners_notdistributing.do

SUMMARY: 
	For bidding villages, look at winners: 
	Who was blocked from distributing vs. who dropped out after winning?
	Get responses from both village survey (i.e. what village head says) and 
	distributor survey (i.e. what winner says). 
*******************************************************************************/

********************************************************************************
* SETUP AND MACROS *************************************************************
********************************************************************************

clear all

set more off

** DIRECTORIES
cd "$RASKIN"

********************************************************************************
* CODING ***********************************************************************
********************************************************************************

* 1. DATA PREP *****************************************************************
** Bidder won or lost, according to form F8A
	import excel "1Data/originaldata/4_CE/14.09.02 chk_sq_info.xlsx", sheet("chk_sq_info") firstrow
	merge 1:m commid using "1Data/originaldata/4_CE/f8a_f.dta"
	drop if _m!=3
	drop _m
	rename f00_col c00_col
	rename f07 winner
	recode winner (3=0) (9=.)
	replace winner = . if f08==1 //village returned to status quo
	replace winner = . if commid == "309" // correcting a mistake		
	gen return_sq = f08 == 1
	replace return_sq = . if f08==9	
	keep if winner==1
	keep commid c00_col winner

** Current Distributor (At time of bidding process) --> Old Distributor
	merge 1:1 commid c00_col using "1Data/originaldata/4_CE/f7a_c.dta"
	rename c00_col column
	keep if _m!=2
	drop _m
	recode c05 (9=.)(3=0)
	rename c05 old_dist
	la var old_dist "Bidder is Raskin distributor at time of bidding"	
	
	//create and save tempfile
	tempfile winners
	sa `winners'

** Crosswalk to Distributor Survey
	u "1Data/originaldata/4_CE/crosswalk_f8a_distributor_resp.dta", clear
	drop if pr_id1==""
	drop if pr_id1=="81231" & d00_col==3 //duplicate of column==2
	merge 1:1 pr_id1 pr_id2 using "1Data/originaldata/3_Endline/pr_pp1.dta"
	drop if _m!=3
	drop _m
	rename d00_col column
	drop if column == .
	merge 1:1 commid column using `winners'
	drop if _m==1
	assert inlist(commid, "554", "510", "515", "690", "770") if _m!=3
	drop _m
	
** Current Distributor	
	replace pr_ea = commid if mi(pr_ea) & inlist(commid, "554", "510", "515", "690", "770")
	replace pr_id1 = "9999" if mi(pr_id1) & inlist(commid, "554", "510", "515", "690", "770")
	replace pr_id2 = "0" if mi(pr_id2) & inlist(commid, "554", "510", "515", "690", "770")
	merge 1:1 pr_ea pr_id1 pr_id2 using ///
		"1Data/originaldata/4_CE/penyalur_sekarang.dta"
	drop if _m == 2
	gen current_dist = _m==3
	la var current_dist "Winner is current distributor"
	drop _m
	
	//create and save tempfile
	tempfile sample
	sa 	`sample'
	
** Bidding Villages
	u "1Data/codeddata/competition/treatments.dta", clear 
	gen commid = desa_id2
	keep commid tr_dist kab_name
	merge 1:1 commid using `sample'
	keep if tr_dist==1
	tab _m
	drop if _m!=3
	drop _m
	
** All of BANDAR LAMPUNG ordered to cancel bidding results
	gen kab_reject = inlist(kab_name, "KOTA BANDAR LAMPUNG")
	la var kab_reject " All of BANDAR LAMPUNG ordered to cancel bidding results"
	
	//create and save tempfile
	tempfile tr
	sa `tr'

** Merge with Village Head Survey
	u "1Data/originaldata/3_Endline/k_rd1.dta", clear
	gen commid = kea
	gen pr_id2 = kea1
	merge 1:1 commid pr_id2 using `tr'
	assert _m!=2
	keep if _m==3 
	drop _m	
	
	//create and save tempfile
	tempfile data
	sa `data'
	
* 2. VILLAGE HEAD SURVEY *******************************************************

** Did winner ever organize raskin after bidding?
	gen never_dist_vh = rd01d==3 if !mi(rd01d)
	la var never_dist_vh "VH: Elected coordinator never organized Raskin distribution"
	
** Coordinator distributed, but no longer
	gen some_dist_vh = rd01f==3 if !mi(rd01f)
	la var some_dist_vh "VH: Elected coordinator organized distribution, but no longer"

** Reason for no longer distributing
	forv i = 1/4 {
		local var : word `i' of moved health ability govt
		local opt : word `i' of A 		B 		C 		D
		local lbl : word `i' of "Moved fr village" "Fell ill/died" ///
					"Couldn't handle responsibility" "Decided by others"
		gen reason_`var'_vh = regexm(rd01g, "`opt'") if some_dist_vh==1|never_dist_vh==1
		la var reason_`var'_vh "VH: Reason for no longer distributing: `lbl'"
	}
	
	
** If Terminated by others, by Whom?
	forv i=1/4 {
		local letter 	: word `i' of A B C D
		local group  	: word `i' of forum vill kec kab
		local label		: word `i' of "village-level forum" "village-level government" ///
							"kecamatan government" "kabupaten/kota government"
		gen reason_govt_`group'_vh = regexm(rd01h, "`letter'") & reason_govt_vh==1 if some_dist_vh==1|never_dist_vh==1
		la var reason_govt_`group'_vh "VH: Bidding winner blocked by `label'"
	}
	
	
* 3. DISTRIBUTOR SURVEY ********************************************************

** Have you organized Raskin in last 9 months?
	gen never_dist_d = pp11==3 if !mi(pp11)
	la var never_dist_d "Winner: Winner has not distributed Raskin since bidding"

** Coordinator distributed, but no longer
	gen some_dist_d = current_dist==0 & never_dist_d==0 if !mi(pp11)
	la var some_dist_d "Winner: Elected coordinator organized distribution, but no longer"
	
** Reason for no longer distributing
	forv i = 1/4 {
		local var : word `i' of moved health ability govt
		local opt : word `i' of A 		B 		C 		D
		local lbl : word `i' of "Moved fr village" "Fell ill/died" ///
					"Couldn't handle responsibility" "Decided by others"
		gen reason_`var'_d = regexm(pp33, "`opt'") if some_dist_d==1|never_dist_d==1
		la var reason_`var'_d "Winner: Reason for no longer distributing: `lbl'"
	}
	
	
** If Terminated, by Whom?
	forv i=1/5 {
		local letter 	: word `i' of A B C D E
		local group  	: word `i' of forum bid vill kec kab
		local label		: word `i' of "village-level forum" "bidding committee" /// 
							"village-level government" ///
							"kecamatan government" "kabupaten/kota government"
		gen reason_govt_`group'_d = regexm(pp34, "`letter'") & reason_govt_d==1 if some_dist_d==1|never_dist_d==1
		la var reason_govt_`group'_d "Winner: Bidding winner blocked by `label'"
	}
	

* 4. ADMINISTRATIVE DATA - i.e. emails, etc about winner data ******************

** Missing distributor survey for given reason - commid: "095", "297", "388", "425", "542"
	gen reason_moved_a 		= 1 	if commid=="425" | commid=="095"
	gen reason_health_a 	= 1 	if commid=="388"
	gen reason_govt_a 		= 1 	if kab_reject==1 & old_dist!=1
	gen reason_govt_kab_a 	= 1 	if kab_reject==1 & old_dist!=1
	gen never_dist_a 		= 1		if kab_reject==1 & old_dist!=1
	forv i = 1/4 {
		local var : word `i' of moved health govt govt_kab
		local lbl : word `i' of "Moved fr village" "Fell ill/died" ///
					"Decided by others" "Bidding winner blocked by kabupaten/kota government"
		la var reason_`var'_a "Admin Data: Reason for no longer distributing: `lbl'"
	}
	
** Create versions of VH/Winner variables that account for admin data
	local varlist never_dist some_dist reason_moved reason_health reason_ability reason_govt ///
		reason_govt_forum reason_govt_bid reason_govt_vill reason_govt_kec reason_govt_kab	
	
	foreach x in vh d {
		local lbl_`x' : var la some_dist_`x'
		gen some_dist_`x'2 = some_dist_`x'
		la var some_dist_`x'2 "`lbl_`x''"
		
		foreach var in never_dist reason_moved reason_health reason_govt reason_govt_kab {
			local lbl_`var'_`x' : var la `var'_`x'
			gen `var'_`x'2 = `var'_`x'
			replace `var'_`x'2 = 1 if `var'_a == 1
			la var `var'_`x'2 "`lbl_`var'_`x'' (Accounting for notes)"
		}
		foreach y in `varlist' {
		cap gen `y'_`x'2 = `y'_`x'
		}
	}

* SAVE.             ************************************************************

//keep relevant variables, drop variables, order variables
keep commid kea1 never_dist* some_dist* reason* current_dist old_dist
drop never_dist_a
order commid kea1 current_dist old_dist *_a

//save
saveold "1Data/codeddata/competition/winners_notdistributing.dta", replace
